@@ -6,6 +6,7 @@
 //
 // See LICENSE and AUTHORS for more information.
 
+// clang-format off
 #include "headers.h"
 
 namespace config {
@@ -24,7 +25,7 @@ namespace config {
         const std::string death_royal = "data/death_royal.txt";
         const std::string scores = "scores.dat";
         std::string save_game = "game.sav";
-    }
+    } // namespace files
 
     // Game options as set on startup and with `=` set options command -CJS-
     namespace options {
@@ -39,7 +40,7 @@ namespace config {
         bool use_roguelike_keys = false;     // Use classic Roguelike keys
         bool show_inventory_weights = false; // Display weights in inventory
         bool error_beep_sound = true;        // Beep for invalid characters
-    }
+    } // namespace options
 
     // Dungeon generation values
     // Note: The entire design of dungeon can be changed by only slight adjustments here.
@@ -75,13 +76,13 @@ namespace config {
             const uint16_t OBJ_WIZARD = 419;
 
             const uint8_t MAX_GOLD_TYPES = 18; // Number of different types of gold
-            const uint8_t MAX_TRAPS = 18; // Number of defined traps
+            const uint8_t MAX_TRAPS = 18;      // Number of defined traps
 
             const uint8_t LEVEL_OBJECTS_PER_ROOM = 7;     // Amount of objects for rooms
             const uint8_t LEVEL_OBJECTS_PER_CORRIDOR = 2; // Amount of objects for corridors
             const uint8_t LEVEL_TOTAL_GOLD_AND_GEMS = 2;  // Amount of gold (and gems)
-        }
-    }
+        } // namespace objects
+    } // namespace dungeon
 
     // Note: Number of special objects, and degree of enchantments can be adjusted here.
     namespace treasure {
@@ -140,7 +141,7 @@ namespace config {
             const uint32_t TR_TUNNEL = 0x20000000L;
             const uint32_t TR_INFRA = 0x40000000L;
             const uint32_t TR_CURSED = 0x80000000L;
-        }
+        } // namespace flags
 
         // definitions for chests
         namespace chests {
@@ -151,8 +152,8 @@ namespace config {
             const uint32_t CH_PARALYSED = 0x00000040L;
             const uint32_t CH_EXPLODE = 0x00000080L;
             const uint32_t CH_SUMMON = 0x00000100L;
-        }
-    }
+        } // namespace chests
+    } // namespace treasure
 
     namespace monsters {
         const uint8_t MON_CHANCE_OF_NEW = 160;            // 1/x chance of new monster each round
@@ -202,7 +203,7 @@ namespace config {
             const uint32_t CM_2D2_OBJ = 0x20000000L;
             const uint32_t CM_4D2_OBJ = 0x40000000L;
             const uint32_t CM_WIN = 0x80000000L;
-        }
+        } // namespace move
 
         // creature spell definitions
         namespace spells {
@@ -228,7 +229,7 @@ namespace config {
             const uint32_t CS_BR_ACID = 0x00200000L;
             const uint32_t CS_BR_FROST = 0x00400000L;
             const uint32_t CS_BR_FIRE = 0x00800000L;
-        }
+        } // namespace spells
 
         // creature defense flags
         namespace defense {
@@ -246,8 +247,8 @@ namespace config {
             const uint16_t CD_NO_SLEEP = 0x1000;
             const uint16_t CD_INFRA = 0x2000;
             const uint16_t CD_MAX_HP = 0x4000;
-        }
-    }
+        } // namespace defense
+    } // namespace monsters
 
     namespace player {
         const int32_t PLAYER_MAX_EXP = 9999999L;        // Maximum amount of experience -CJS-
@@ -300,8 +301,8 @@ namespace config {
 
             const uint32_t PY_HP = 0x40000000L;
             const uint32_t PY_MANA = 0x80000000L;
-        }
-    }
+        } // namespace status
+    } // namespace player
 
     namespace identification {
         // id's used for object description, stored in objects_identified array
@@ -317,7 +318,7 @@ namespace config {
         const uint8_t ID_SHOW_HIT_DAM = 0x20;
         const uint8_t ID_NO_SHOW_P1 = 0x40;
         const uint8_t ID_SHOW_P1 = 0x80;
-    }
+    } // namespace identification
 
     namespace spells {
         // Class spell types
@@ -328,11 +329,11 @@ namespace config {
         // offsets to spell names in spell_names[] array
         const uint8_t NAME_OFFSET_SPELLS = 0;
         const uint8_t NAME_OFFSET_PRAYERS = 31;
-    }
+    } // namespace spells
 
     namespace stores {
         const uint8_t STORE_MAX_AUTO_BUY_ITEMS = 18;  // Max diff objects in stock for auto buy
         const uint8_t STORE_MIN_AUTO_SELL_ITEMS = 10; // Min diff objects in stock for auto sell
         const uint8_t STORE_STOCK_TURN_AROUND = 9;    // Amount of buying and selling normally
-    }
-}
+    } // namespace stores
+} // namespace config
