@@ -7,12 +7,15 @@
 // See LICENSE and AUTHORS for more information.
 
 // Sets up curses for the correct system.
+
 // clang-format off
 
 #ifdef _WIN32
   // this is defined in Windows and also in ncurses
   #undef KEY_EVENT
   #include <ncurses/ncurses.h>
+#elif __NetBSD__
+  #include <curses.h>
 #else
   #include <ncurses.h>
 #endif
