@@ -7,8 +7,8 @@
 // See LICENSE and AUTHORS for more information.
 
 // Player character data
-// clang-format off
 
+// clang-format off
 #include "headers.h"
 
 // Class rank titles for different levels
@@ -322,7 +322,7 @@ Spell_t magic_spells[PLAYER_MAX_CLASSES - 1][31] = {
         { 25, 12, 65,  63},
         { 29, 18, 65,  88},
         { 33, 21, 80, 125},
-        { 37, 25, 95, 200}
+        { 37, 25, 95, 200},
     },
     {
         // Priest
@@ -356,7 +356,7 @@ Spell_t magic_spells[PLAYER_MAX_CLASSES - 1][31] = {
         { 21, 16, 60,  38},
         { 25, 20, 70,  75},
         { 33, 24, 90, 125},
-        { 39, 32, 80, 200}
+        { 39, 32, 80, 200},
     },
     {
         // Rogue
@@ -424,7 +424,7 @@ Spell_t magic_spells[PLAYER_MAX_CLASSES - 1][31] = {
         { 33, 25, 75,  38},
         { 35, 25, 80,  50},
         { 37, 30, 95, 100},
-        { 99, 99,  0,   0}
+        { 99, 99,  0,   0},
     },
     {
         // Paladin
@@ -458,7 +458,7 @@ Spell_t magic_spells[PLAYER_MAX_CLASSES - 1][31] = {
         { 33, 28, 60,  31},
         { 35, 32, 70,  38},
         { 37, 36, 90,  50},
-        { 39, 38, 90, 100}
+        { 39, 38, 90, 100},
     }
 };
 
@@ -500,5 +500,5 @@ uint16_t class_base_provisions[PLAYER_MAX_CLASSES][5] = {
     {344, 365, 123, 30, 322}, // Priest
     {344, 365, 123, 30, 318}, // Rogue
     {344, 365, 123, 30, 318}, // Ranger
-    {344, 365, 123, 30, 322}  // Paladin
+    {344, 365, 123, 30, 322},  // Paladin
 };
