@@ -21,16 +21,15 @@ void dungeonDisplayMap() {
     clearScreen();
 
     int16_t priority[256] = {0};
-    priority[60] = 5;    // char '<'
-    priority[62] = 5;    // char '>'
-    priority[64] = 10;   // char '@'
-    priority[35] = -5;   // char '#'
-    priority[46] = -10;  // char '.'
-    priority[92] = -3;   // char '\'
-    priority[32] = -15;  // char ' '
+    priority[60] = 5;   // char '<'
+    priority[62] = 5;   // char '>'
+    priority[64] = 10;  // char '@'
+    priority[35] = -5;  // char '#'
+    priority[46] = -10; // char '.'
+    priority[92] = -3;  // char '\'
+    priority[32] = -15; // char ' '
 
     // Display highest priority object in the RATIO, by RATIO area
-    constexpr uint8_t RATIO = 3;
     uint8_t panel_width = MAX_WIDTH / RATIO;
     uint8_t panel_height = MAX_HEIGHT / RATIO;
 
@@ -162,7 +161,7 @@ int coordCorridorWallsNextTo(Coord_t const &coord) {
             int treasure_id = dg.floor[y][x].treasure_id;
 
             // should fail if there is already a door present
-            if (tile_id == TILE_CORR_FLOOR && (treasure_id == 0 || treasure_list[treasure_id].category_id < TV_MIN_DOORS)) {
+            if (tile_id == TILE_CORR_FLOOR && (treasure_id == 0 || game.treasure.list[treasure_id].category_id < TV_MIN_DOORS)) {
                 walls++;
             }
         }
@@ -184,7 +183,7 @@ char caveGetTileSymbol(Coord_t const &coord) {
     }
 
     if (py.flags.image > 0 && randomNumber(12) == 1) {
-        return (uint8_t) (randomNumber(95) + 31);
+        return (uint8_t)(randomNumber(95) + 31);
     }
 
     if (tile.creature_id > 1 && monsters[tile.creature_id].lit) {
@@ -195,8 +194,8 @@ char caveGetTileSymbol(Coord_t const &coord) {
         return ' ';
     }
 
-    if (tile.treasure_id != 0 && treasure_list[tile.treasure_id].category_id != TV_INVIS_TRAP) {
-        return treasure_list[tile.treasure_id].sprite;
+    if (tile.treasure_id != 0 && game.treasure.list[tile.treasure_id].category_id != TV_INVIS_TRAP) {
+        return game.treasure.list[tile.treasure_id].sprite;
     }
 
     if (tile.feature_id <= MAX_CAVE_FLOOR) {
@@ -221,7 +220,7 @@ bool caveTileVisible(Coord_t const &coord) {
 void dungeonSetTrap(Coord_t const &coord, int sub_type_id) {
     int free_treasure_id = popt();
     dg.floor[coord.y][coord.x].treasure_id = (uint8_t) free_treasure_id;
-    inventoryItemCopyTo(config::dungeon::objects::OBJ_TRAP_LIST + sub_type_id, treasure_list[free_treasure_id]);
+    inventoryItemCopyTo(config::dungeon::objects::OBJ_TRAP_LIST + sub_type_id, game.treasure.list[free_treasure_id]);
 }
 
 // Change a trap from invisible to visible -RAK-
@@ -229,7 +228,7 @@ void dungeonSetTrap(Coord_t const &coord, int sub_type_id) {
 void trapChangeVisibility(Coord_t const &coord) {
     uint8_t treasure_id = dg.floor[coord.y][coord.x].treasure_id;
 
-    Inventory_t &item = treasure_list[treasure_id];
+    Inventory_t &item = game.treasure.list[treasure_id];
 
     if (item.category_id == TV_INVIS_TRAP) {
         item.category_id = TV_VIS_TRAP;
@@ -251,7 +250,7 @@ void dungeonPlaceRubble(Coord_t const &coord) {
     int free_treasure_id = popt();
     dg.floor[coord.y][coord.x].treasure_id = (uint8_t) free_treasure_id;
     dg.floor[coord.y][coord.x].feature_id = TILE_BLOCKED_FLOOR;
-    inventoryItemCopyTo(config::dungeon::objects::OBJ_RUBBLE, treasure_list[free_treasure_id]);
+    inventoryItemCopyTo(config::dungeon::objects::OBJ_RUBBLE, game.treasure.list[free_treasure_id]);
 }
 
 // Places a treasure (Gold or Gems) at given row, column -RAK-
@@ -269,8 +268,8 @@ void dungeonPlaceGold(Coord_t const &coord) {
     }
 
     dg.floor[coord.y][coord.x].treasure_id = (uint8_t) free_treasure_id;
-    inventoryItemCopyTo(config::dungeon::objects::OBJ_GOLD_LIST + gold_type_id, treasure_list[free_treasure_id]);
-    treasure_list[free_treasure_id].cost += (8L * (int32_t) randomNumber((int) treasure_list[free_treasure_id].cost)) + randomNumber(8);
+    inventoryItemCopyTo(config::dungeon::objects::OBJ_GOLD_LIST + gold_type_id, game.treasure.list[free_treasure_id]);
+    game.treasure.list[free_treasure_id].cost += (8L * (int32_t) randomNumber((int) game.treasure.list[free_treasure_id].cost)) + randomNumber(8);
 
     if (dg.floor[coord.y][coord.x].creature_id == 1) {
         printMessage("You feel something roll beneath your feet.");
@@ -284,7 +283,7 @@ void dungeonPlaceRandomObjectAt(Coord_t const &coord, bool must_be_small) {
     dg.floor[coord.y][coord.x].treasure_id = (uint8_t) free_treasure_id;
 
     int object_id = itemGetRandomObjectId(dg.current_level, must_be_small);
-    inventoryItemCopyTo(sorted_objects[object_id], treasure_list[free_treasure_id]);
+    inventoryItemCopyTo(sorted_objects[object_id], game.treasure.list[free_treasure_id]);
 
     magicTreasureMagicalAbility(free_treasure_id, dg.current_level);
 
@@ -295,31 +294,31 @@ void dungeonPlaceRandomObjectAt(Coord_t const &coord, bool must_be_small) {
 
 // Allocates an object for tunnels and rooms -RAK-
 void dungeonAllocateAndPlaceObject(bool (*set_function)(int), int object_type, int number) {
-    int y, x;
+    Coord_t coord = Coord_t{0, 0};
 
     for (int i = 0; i < number; i++) {
         // don't put an object beneath the player, this could cause
         // problems if player is standing under rubble, or on a trap.
         do {
-            y = randomNumber(dg.height) - 1;
-            x = randomNumber(dg.width) - 1;
-        } while (!(*set_function)(dg.floor[y][x].feature_id) || dg.floor[y][x].treasure_id != 0 || (y == py.row && x == py.col));
+            coord.y = randomNumber(dg.height) - 1;
+            coord.x = randomNumber(dg.width) - 1;
+        } while (!(*set_function)(dg.floor[coord.y][coord.x].feature_id) || dg.floor[coord.y][coord.x].treasure_id != 0 || (coord.y == py.pos.y && coord.x == py.pos.x));
 
         switch (object_type) {
             case 1:
-                dungeonSetTrap(Coord_t{y, x}, randomNumber(config::dungeon::objects::MAX_TRAPS) - 1);
+                dungeonSetTrap(coord, randomNumber(config::dungeon::objects::MAX_TRAPS) - 1);
                 break;
             case 2:
                 // NOTE: object_type == 2 is no longer used - it used to be visible traps.
                 // FIXME: there was no `break` here so `case 3` catches it? -MRC-
             case 3:
-                dungeonPlaceRubble(Coord_t{y, x});
+                dungeonPlaceRubble(coord);
                 break;
             case 4:
-                dungeonPlaceGold(Coord_t{y, x});
+                dungeonPlaceGold(coord);
                 break;
             case 5:
-                dungeonPlaceRandomObjectAt(Coord_t{y, x}, false);
+                dungeonPlaceRandomObjectAt(coord, false);
                 break;
             default:
                 break;
@@ -332,8 +331,8 @@ void dungeonPlaceRandomObjectNear(Coord_t coord, int tries) {
     do {
         for (int i = 0; i <= 10; i++) {
             Coord_t at = Coord_t{
-                    coord.y - 3 + randomNumber(5),
-                    coord.x - 4 + randomNumber(7)
+                coord.y - 3 + randomNumber(5),
+                coord.x - 4 + randomNumber(7),
             };
 
             if (coordInBounds(at) && dg.floor[at.y][at.x].feature_id <= MAX_CAVE_FLOOR && dg.floor[at.y][at.x].treasure_id == 0) {
@@ -368,9 +367,11 @@ void dungeonLightRoom(Coord_t const &coord) {
     int bottom = top + height_middle - 1;
     int right = left + width_middle - 1;
 
-    for (int y = top; y <= bottom; y++) {
-        for (int x = left; x <= right; x++) {
-            Tile_t &tile = dg.floor[y][x];
+    Coord_t location = Coord_t{0, 0};
+
+    for (location.y = top; location.y <= bottom; location.y++) {
+        for (location.x = left; location.x <= right; location.x++) {
+            Tile_t &tile = dg.floor[location.y][location.x];
 
             if (tile.perma_lit_room && !tile.permanent_light) {
                 tile.permanent_light = true;
@@ -379,12 +380,12 @@ void dungeonLightRoom(Coord_t const &coord) {
                     tile.feature_id = TILE_LIGHT_FLOOR;
                 }
                 if (!tile.field_mark && tile.treasure_id != 0) {
-                    int treasure_id = treasure_list[tile.treasure_id].category_id;
+                    int treasure_id = game.treasure.list[tile.treasure_id].category_id;
                     if (treasure_id >= TV_MIN_VISIBLE && treasure_id <= TV_MAX_VISIBLE) {
                         tile.field_mark = true;
                     }
                 }
-                panelPutTile(caveGetTileSymbol(Coord_t{y, x}), Coord_t{y, x});
+                panelPutTile(caveGetTileSymbol(location), location);
             }
         }
     }
@@ -402,7 +403,7 @@ void dungeonLiteSpot(Coord_t const &coord) {
 
 // Normal movement
 // When FIND_FLAG,  light only permanent features
-static void sub1_move_light(Coord_t const &from, Coord_t const &to) {
+static void sub1MoveLight(Coord_t const &from, Coord_t const &to) {
     if (py.temporary_light_only) {
         // Turn off lamp light
         for (int y = from.y - 1; y <= from.y + 1; y++) {
@@ -429,7 +430,7 @@ static void sub1_move_light(Coord_t const &from, Coord_t const &to) {
             if (tile.feature_id >= MIN_CAVE_WALL) {
                 tile.permanent_light = true;
             } else if (!tile.field_mark && tile.treasure_id != 0) {
-                int tval = treasure_list[tile.treasure_id].category_id;
+                int tval = game.treasure.list[tile.treasure_id].category_id;
 
                 if (tval >= TV_MIN_VISIBLE && tval <= TV_MAX_VISIBLE) {
                     tile.field_mark = true;
@@ -456,22 +457,25 @@ static void sub1_move_light(Coord_t const &from, Coord_t const &to) {
         right = from.x + 1;
     }
 
-    for (int y = top; y <= bottom; y++) {
+    Coord_t coord = Coord_t{0, 0};
+    for (coord.y = top; coord.y <= bottom; coord.y++) {
         // Leftmost to rightmost do
-        for (int x = left; x <= right; x++) {
-            panelPutTile(caveGetTileSymbol(Coord_t{y, x}), Coord_t{y, x});
+        for (coord.x = left; coord.x <= right; coord.x++) {
+            panelPutTile(caveGetTileSymbol(coord), coord);
         }
     }
 }
 
 // When blinded,  move only the player symbol.
 // With no light,  movement becomes involved.
-static void sub3_move_light(Coord_t const &from, Coord_t const &to) {
+static void sub3MoveLight(Coord_t const &from, Coord_t const &to) {
     if (py.temporary_light_only) {
-        for (int y = from.y - 1; y <= from.y + 1; y++) {
-            for (int x = from.x - 1; x <= from.x + 1; x++) {
-                dg.floor[y][x].temporary_light = false;
-                panelPutTile(caveGetTileSymbol(Coord_t{y, x}), Coord_t{y, x});
+        Coord_t coord = Coord_t{0, 0};
+
+        for (coord.y = from.y - 1; coord.y <= from.y + 1; coord.y++) {
+            for (coord.x = from.x - 1; coord.x <= from.x + 1; coord.x++) {
+                dg.floor[coord.y][coord.x].temporary_light = false;
+                panelPutTile(caveGetTileSymbol(coord), coord);
             }
         }
 
@@ -489,9 +493,9 @@ static void sub3_move_light(Coord_t const &from, Coord_t const &to) {
 // Four cases : Normal, Finding, Blind, and No light -RAK-
 void dungeonMoveCharacterLight(Coord_t const &from, Coord_t const &to) {
     if (py.flags.blind > 0 || !py.carrying_light) {
-        sub3_move_light(from, to);
+        sub3MoveLight(from, to);
     } else {
-        sub1_move_light(from, to);
+        sub1MoveLight(from, to);
     }
 }
 
@@ -499,17 +503,17 @@ void dungeonMoveCharacterLight(Coord_t const &from, Coord_t const &to) {
 void dungeonDeleteMonster(int id) {
     Monster_t *monster = &monsters[id];
 
-    dg.floor[monster->y][monster->x].creature_id = 0;
+    dg.floor[monster->pos.y][monster->pos.x].creature_id = 0;
 
     if (monster->lit) {
-        dungeonLiteSpot(Coord_t{monster->y, monster->x});
+        dungeonLiteSpot(Coord_t{monster->pos.y, monster->pos.x});
     }
 
     int last_id = next_free_monster_id - 1;
 
     if (id != last_id) {
         monster = &monsters[last_id];
-        dg.floor[monster->y][monster->x].creature_id = (uint8_t) id;
+        dg.floor[monster->pos.y][monster->pos.x].creature_id = (uint8_t) id;
         monsters[id] = monsters[last_id];
     }
 
@@ -538,10 +542,10 @@ void dungeonDeleteMonsterFix1(int id) {
     // hit points
     monster.hp = -1;
 
-    dg.floor[monster.y][monster.x].creature_id = 0;
+    dg.floor[monster.pos.y][monster.pos.x].creature_id = 0;
 
     if (monster.lit) {
-        dungeonLiteSpot(Coord_t{monster.y, monster.x});
+        dungeonLiteSpot(Coord_t{monster.pos.y, monster.pos.x});
     }
 
     if (monster_multiply_total > 0) {
@@ -555,8 +559,8 @@ void dungeonDeleteMonsterFix2(int id) {
     int last_id = next_free_monster_id - 1;
 
     if (id != last_id) {
-        int y = monsters[last_id].y;
-        int x = monsters[last_id].x;
+        int y = monsters[last_id].pos.y;
+        int x = monsters[last_id].pos.x;
         dg.floor[y][x].creature_id = (uint8_t) id;
 
         monsters[id] = monsters[last_id];
@@ -571,7 +575,7 @@ int dungeonSummonObject(Coord_t coord, int amount, int object_type) {
     int real_type;
 
     if (object_type == 1 || object_type == 5) {
-        real_type = 1;   // object_type == 1 -> objects
+        real_type = 1; // object_type == 1 -> objects
     } else {
         real_type = 256; // object_type == 2 -> gold
     }
@@ -581,11 +585,11 @@ int dungeonSummonObject(Coord_t coord, int amount, int object_type) {
     do {
         for (int tries = 0; tries <= 20; tries++) {
             Coord_t at = Coord_t{
-                    coord.y - 3 + randomNumber(5),
-                    coord.x - 3 + randomNumber(5),
+                coord.y - 3 + randomNumber(5),
+                coord.x - 3 + randomNumber(5),
             };
 
-            if (coordInBounds(at) && los(coord.y, coord.x, at.y, at.x)) {
+            if (coordInBounds(at) && los(coord, at)) {
                 if (dg.floor[at.y][at.x].feature_id <= MAX_OPEN_SPACE && dg.floor[at.y][at.x].treasure_id == 0) {
                     // object_type == 3 -> 50% objects, 50% gold
                     if (object_type == 3 || object_type == 7) {
