@@ -25,9 +25,9 @@
 
 // Because this function uses (short) ints for all calculations, overflow may
 // occur if deltaX and deltaY exceed 90.
-bool los(int from_y, int from_x, int to_y, int to_x) {
-    int delta_x = to_x - from_x;
-    int delta_y = to_y - from_y;
+bool los(Coord_t from, Coord_t to) {
+    int delta_x = to.x - from.x;
+    int delta_y = to.y - from.y;
 
     // Adjacent?
     if (delta_x < 2 && delta_x > -2 && delta_y < 2 && delta_y > -2) {
@@ -37,13 +37,13 @@ bool los(int from_y, int from_x, int to_y, int to_x) {
     // Handle the cases where delta_x or delta_y == 0.
     if (delta_x == 0) {
         if (delta_y < 0) {
-            int tmp = from_y;
-            from_y = to_y;
-            to_y = tmp;
+            int tmp = from.y;
+            from.y = to.y;
+            to.y = tmp;
         }
 
-        for (int yy = from_y + 1; yy < to_y; yy++) {
-            if (dg.floor[yy][from_x].feature_id >= MIN_CLOSED_SPACE) {
+        for (int yy = from.y + 1; yy < to.y; yy++) {
+            if (dg.floor[yy][from.x].feature_id >= MIN_CLOSED_SPACE) {
                 return false;
             }
         }
@@ -53,13 +53,13 @@ bool los(int from_y, int from_x, int to_y, int to_x) {
 
     if (delta_y == 0) {
         if (delta_x < 0) {
-            int tmp = from_x;
-            from_x = to_x;
-            to_x = tmp;
+            int tmp = from.x;
+            from.x = to.x;
+            to.x = tmp;
         }
 
-        for (int xx = from_x + 1; xx < to_x; xx++) {
-            if (dg.floor[from_y][xx].feature_id >= MIN_CLOSED_SPACE) {
+        for (int xx = from.x + 1; xx < to.x; xx++) {
+            if (dg.floor[from.y][xx].feature_id >= MIN_CLOSED_SPACE) {
                 return false;
             }
         }
@@ -71,13 +71,13 @@ bool los(int from_y, int from_x, int to_y, int to_x) {
     // In the computations below, dy (or dx) and m are multiplied by a scale factor,
     // scale = abs(delta_x * delta_y * 2), so that we can use integer arithmetic.
     {
-        int xx;          // x position
-        int yy;          // y position
-        int scale;       // above scale factor
-        int scale_half;  // above scale factor / 2
-        int x_sign;      // sign of delta_x
-        int y_sign;      // sign of delta_y
-        int slope;       // slope or 1/slope of LOS
+        int xx;         // x position
+        int yy;         // y position
+        int scale;      // above scale factor
+        int scale_half; // above scale factor / 2
+        int x_sign;     // sign of delta_x
+        int y_sign;     // sign of delta_y
+        int slope;      // slope or 1/slope of LOS
 
         int delta_multiply = delta_x * delta_y;
         scale_half = (int) std::abs((std::intmax_t) delta_multiply);
@@ -101,17 +101,17 @@ bool los(int from_y, int from_x, int to_y, int to_x) {
 
             dy = delta_y * delta_y;
             slope = dy << 1;
-            xx = from_x + x_sign;
+            xx = from.x + x_sign;
 
             // Consider the special case where slope == 1.
             if (dy == scale_half) {
-                yy = from_y + y_sign;
+                yy = from.y + y_sign;
                 dy -= scale;
             } else {
-                yy = from_y;
+                yy = from.y;
             }
 
-            while ((to_x - xx) != 0) {
+            while ((to.x - xx) != 0) {
                 if (dg.floor[yy][xx].feature_id >= MIN_CLOSED_SPACE) {
                     return false;
                 }
@@ -143,16 +143,16 @@ bool los(int from_y, int from_x, int to_y, int to_x) {
         dx = delta_x * delta_x;
         slope = dx << 1;
 
-        yy = from_y + y_sign;
+        yy = from.y + y_sign;
 
         if (dx == scale_half) {
-            xx = from_x + x_sign;
+            xx = from.x + x_sign;
             dx -= scale;
         } else {
-            xx = from_x;
+            xx = from.x;
         }
 
-        while ((to_y - yy) != 0) {
+        while ((to.y - yy) != 0) {
             if (dg.floor[yy][xx].feature_id >= MIN_CLOSED_SPACE) {
                 return false;
             }
@@ -224,8 +224,8 @@ bool los(int from_y, int from_x, int to_y, int to_x) {
 
   The others map coords in the ray frame to dungeon coords.
 
-  dungeon y = py.row   + los_fyx * (ray x)  + los_fyy * (ray y)
-  dungeon x = py.col   + los_fxx * (ray x)  + los_fxy * (ray y)
+  dungeon y = py.pos.y + los_fyx * (ray x) + los_fyy * (ray y)
+  dungeon x = py.pos.x + los_fxx * (ray x) + los_fxy * (ray y)
 */
 static int los_fxx, los_fxy, los_fyx, los_fyy;
 static int los_num_places_seen;
@@ -246,7 +246,7 @@ static int los_map_diagonals2[] = {2, 1, 0, 4, 3};
 #define GRADF 10000 // Any sufficiently big number will do
 
 static bool lookRay(int y, int from, int to);
-static bool lookSee(int x, int y, bool &transparent);
+static bool lookSee(Coord_t coord, bool &transparent);
 
 // Look at what we can see. This is a free move.
 //
@@ -281,7 +281,7 @@ void look() {
     los_hack_no_query = false;
 
     bool dummy;
-    if (lookSee(0, 0, dummy)) {
+    if (lookSee(Coord_t{0, 0}, dummy)) {
         return;
     }
 
@@ -337,7 +337,9 @@ void look() {
                 abort = lookRay(1, 2 * GRADF - 1, GRADF);
             }
         }
-    } while (!abort && config::options::highlight_seams && (++los_rocks_and_objects < 2));
+
+        los_rocks_and_objects++;
+    } while (!abort && config::options::highlight_seams && (los_rocks_and_objects < 2));
 
     if (abort) {
         printMessage("--Aborting look--");
@@ -407,7 +409,7 @@ static bool lookRay(int y, int from, int to) {
 
     bool transparent;
 
-    if (lookSee(x, y, transparent)) {
+    if (lookSee(Coord_t{y, x}, transparent)) {
         return true;
     }
 
@@ -440,12 +442,12 @@ static bool lookRay(int y, int from, int to) {
 
             x++;
 
-            if (lookSee(x, y, transparent)) {
+            if (lookSee(Coord_t{y, x}, transparent)) {
                 return true;
             }
         } while (!transparent);
 
-        init_transparent:
+    init_transparent:
 
         // Find the end of this window of visibility.
         do {
@@ -456,37 +458,37 @@ static bool lookRay(int y, int from, int to) {
 
             x++;
 
-            if (lookSee(x, y, transparent)) {
+            if (lookSee(Coord_t{y, x}, transparent)) {
                 return true;
             }
         } while (transparent);
     }
 }
 
-static bool lookSee(int x, int y, bool &transparent) {
-    if (x < 0 || y < 0 || y > x) {
-        obj_desc_t errorMessage = {'\0'};
-        (void) sprintf(errorMessage, "Illegal call to lookSee(%d, %d)", x, y);
-        printMessage(errorMessage);
+static bool lookSee(Coord_t coord, bool &transparent) {
+    if (coord.x < 0 || coord.y < 0 || coord.y > coord.x) {
+        obj_desc_t error_message = {'\0'};
+        (void) sprintf(error_message, "Illegal call to lookSee(%d, %d)", coord.y, coord.x);
+        printMessage(error_message);
     }
 
     const char *description = nullptr;
-    if (x == 0 && y == 0) {
+    if (coord.x == 0 && coord.y == 0) {
         description = "You are on";
     } else {
         description = "You see";
     }
 
-    int j = py.col + los_fxx * x + los_fxy * y;
-    y = py.row + los_fyx * x + los_fyy * y;
-    x = j;
+    int j = py.pos.x + los_fxx * coord.x + los_fxy * coord.y;
+    coord.y = py.pos.y + los_fyx * coord.x + los_fyy * coord.y;
+    coord.x = j;
 
-    if (!coordInsidePanel(Coord_t{y, x})) {
+    if (!coordInsidePanel(coord)) {
         transparent = false;
         return false;
     }
 
-    Tile_t const &tile = dg.floor[y][x];
+    Tile_t const &tile = dg.floor[coord.y][coord.x];
     transparent = tile.feature_id <= MAX_OPEN_SPACE;
 
     if (los_hack_no_query) {
@@ -505,7 +507,7 @@ static bool lookSee(int x, int y, bool &transparent) {
         description = "It is on";
         putStringClearToEOL(msg, Coord_t{0, 0});
 
-        panelMoveCursor(Coord_t{y, x});
+        panelMoveCursor(coord);
         query = getKeyInput();
 
         if (query == 'r' || query == 'R') {
@@ -519,19 +521,19 @@ static bool lookSee(int x, int y, bool &transparent) {
         const char *wall_description;
 
         if (tile.treasure_id != 0) {
-            if (treasure_list[tile.treasure_id].category_id == TV_SECRET_DOOR) {
+            if (game.treasure.list[tile.treasure_id].category_id == TV_SECRET_DOOR) {
                 goto granite;
             }
 
-            if (los_rocks_and_objects == 0 && treasure_list[tile.treasure_id].category_id != TV_INVIS_TRAP) {
+            if (los_rocks_and_objects == 0 && game.treasure.list[tile.treasure_id].category_id != TV_INVIS_TRAP) {
                 obj_desc_t obj_string = {'\0'};
-                itemDescription(obj_string, treasure_list[tile.treasure_id], true);
+                itemDescription(obj_string, game.treasure.list[tile.treasure_id], true);
 
                 (void) sprintf(msg, "%s %s ---pause---", description, obj_string);
                 description = "It is in";
                 putStringClearToEOL(msg, Coord_t{0, 0});
 
-                panelMoveCursor(Coord_t{y, x});
+                panelMoveCursor(coord);
                 query = getKeyInput();
             }
         }
@@ -562,7 +564,7 @@ static bool lookSee(int x, int y, bool &transparent) {
             if (wall_description != nullptr) {
                 (void) sprintf(msg, "%s %s ---pause---", description, wall_description);
                 putStringClearToEOL(msg, Coord_t{0, 0});
-                panelMoveCursor(Coord_t{y, x});
+                panelMoveCursor(coord);
                 query = getKeyInput();
             }
         }
