@@ -28,7 +28,11 @@ static void dungeonGoDownLevel();
 static void dungeonJamDoor();
 static void inventoryRefillLamp();
 
-void startMoria(int seed, bool start_new_game, bool use_roguelike_keys) {
+void startMoria(int seed, bool start_new_game) {
+    // Enable roguelike keys by default - this will be overridden by the
+    // setting in the game save file.
+    config::options::use_roguelike_keys = true;
+
     priceAdjust();
 
     // Show the game splash screen
@@ -67,11 +71,6 @@ void startMoria(int seed, bool start_new_game, bool use_roguelike_keys) {
         result = true;
     }
 
-    // Executing after game load to override saved game settings
-    if (use_roguelike_keys) {
-        config::options::use_roguelike_keys = true;
-    }
-
     // enter wizard mode before showing the character display, but must wait
     // until after loadGame() in case it was just a resurrection
     if (game.to_be_wizard) {
@@ -100,18 +99,18 @@ void startMoria(int seed, bool start_new_game, bool use_roguelike_keys) {
         // Spell and Mana based on class: Mage or Clerical realm.
         if (classes[py.misc.class_id].class_to_use_mage_spells == config::spells::SPELL_TYPE_MAGE) {
             clearScreen(); // makes spell list easier to read
-            playerCalculateAllowedSpellsCount(py_attrs::A_INT);
-            playerGainMana(py_attrs::A_INT);
+            playerCalculateAllowedSpellsCount(PlayerAttr::A_INT);
+            playerGainMana(PlayerAttr::A_INT);
         } else if (classes[py.misc.class_id].class_to_use_mage_spells == config::spells::SPELL_TYPE_PRIEST) {
-            playerCalculateAllowedSpellsCount(py_attrs::A_WIS);
+            playerCalculateAllowedSpellsCount(PlayerAttr::A_WIS);
             clearScreen(); // force out the 'learn prayer' message
-            playerGainMana(py_attrs::A_WIS);
+            playerGainMana(PlayerAttr::A_WIS);
         }
 
         // Set some default values -MRC-
         py.temporary_light_only = false;
         py.weapon_is_heavy = false;
-        py.pack_heaviness = 0;
+        py.pack.heaviness = 0;
 
         // prevent ^c quit from entering score into scoreboard,
         // and prevent signal from creating panic save until this
@@ -126,6 +125,7 @@ void startMoria(int seed, bool start_new_game, bool use_roguelike_keys) {
     // Begin the game
     //
     clearScreen();
+    putString("Press ? for help", Coord_t{0, 63});
     printCharacterStatsBlock();
 
     if (generate) {
@@ -164,7 +164,7 @@ static void initializeCharacterInventory() {
     Inventory_t item{};
 
     // this is needed for bash to work right, it can't hurt anyway
-    for (auto &entry : inventory) {
+    for (auto &entry : py.inventory) {
         inventoryItemCopyTo(config::dungeon::objects::OBJ_NOTHING, entry);
     }
 
@@ -256,14 +256,14 @@ static void resetDungeonFlags() {
     game.command_count = 0;
     dg.generate_new_level = false;
     py.running_tracker = 0;
-    teleport_player = false;
+    game.teleport_player = false;
     monster_multiply_total = 0;
-    dg.floor[py.row][py.col].creature_id = 1;
+    dg.floor[py.pos.y][py.pos.x].creature_id = 1;
 }
 
 // Check light status for dungeon setup
 static void playerInitializePlayerLight() {
-    py.carrying_light = (inventory[player_equipment::EQUIPMENT_LIGHT].misc_use > 0);
+    py.carrying_light = (py.inventory[PlayerEquipment::Light].misc_use > 0);
 }
 
 // Check for a maximum level
@@ -275,7 +275,7 @@ static void playerUpdateMaxDungeonDepth() {
 
 // Check light status
 static void playerUpdateLightStatus() {
-    Inventory_t &item = inventory[player_equipment::EQUIPMENT_LIGHT];
+    Inventory_t &item = py.inventory[PlayerEquipment::Light];
 
     if (py.carrying_light) {
         if (item.misc_use > 0) {
@@ -931,19 +931,17 @@ static void playerUpdateStatusFlags() {
 // Allow for a slim chance of detect enchantment -CJS-
 static void playerDetectEnchantment() {
     for (int i = 0; i < PLAYER_INVENTORY_SIZE; i++) {
-        if (i == py.unique_inventory_items) {
+        if (i == py.pack.unique_items) {
             i = 22;
         }
 
-        Inventory_t &item = inventory[i];
+        Inventory_t &item = py.inventory[i];
 
         // if in inventory, succeed 1 out of 50 times,
         // if in equipment list, success 1 out of 10 times
         int chance = (i < 22 ? 50 : 10);
 
         if (item.category_id != TV_NOTHING && itemEnchanted(item) && randomNumber(chance) == 1) {
-            // extern const char *describe_use(int); // FIXME: Why here? We have it in externs.
-
             vtype_t tmp_str = {'\0'};
             (void) sprintf(tmp_str, "There's something about what you are %s...", playerItemWearingDescription(i));
             playerDisturb(0, 0);
@@ -953,33 +951,33 @@ static void playerDetectEnchantment() {
     }
 }
 
-static int getCommandRepeatCount(char &lastInputCommand) {
+static int getCommandRepeatCount(char &last_input_command) {
     putStringClearToEOL("Repeat count:", Coord_t{0, 0});
 
-    if (lastInputCommand == '#') {
-        lastInputCommand = '0';
+    if (last_input_command == '#') {
+        last_input_command = '0';
     }
 
     char text_buffer[8];
     int repeat_count = 0;
 
     while (true) {
-        if (lastInputCommand == DELETE || lastInputCommand == CTRL_KEY('H')) {
+        if (last_input_command == DELETE || last_input_command == CTRL_KEY('H')) {
             repeat_count /= 10;
             (void) sprintf(text_buffer, "%d", (int16_t) repeat_count);
             putStringClearToEOL(text_buffer, Coord_t{0, 14});
-        } else if (lastInputCommand >= '0' && lastInputCommand <= '9') {
+        } else if (last_input_command >= '0' && last_input_command <= '9') {
             if (repeat_count > 99) {
                 terminalBellSound();
             } else {
-                repeat_count = repeat_count * 10 + lastInputCommand - '0';
+                repeat_count = repeat_count * 10 + last_input_command - '0';
                 (void) sprintf(text_buffer, "%d", repeat_count);
                 putStringClearToEOL(text_buffer, Coord_t{0, 14});
             }
         } else {
             break;
         }
-        lastInputCommand = getKeyInput();
+        last_input_command = getKeyInput();
     }
 
     if (repeat_count == 0) {
@@ -989,38 +987,38 @@ static int getCommandRepeatCount(char &lastInputCommand) {
     }
 
     // a special hack to allow numbers as commands
-    if (lastInputCommand == ' ') {
+    if (last_input_command == ' ') {
         putStringClearToEOL("Command:", Coord_t{0, 20});
-        lastInputCommand = getKeyInput();
+        last_input_command = getKeyInput();
     }
 
     return repeat_count;
 }
 
-static char parseAlternateCtrlInput(char lastInputCommand) {
+static char parseAlternateCtrlInput(char last_input_command) {
     if (game.command_count > 0) {
         printCharacterMovementState();
     }
 
-    if (getCommand("Control-", lastInputCommand)) {
-        if (lastInputCommand >= 'A' && lastInputCommand <= 'Z') {
-            lastInputCommand -= 'A' - 1;
-        } else if (lastInputCommand >= 'a' && lastInputCommand <= 'z') {
-            lastInputCommand -= 'a' - 1;
+    if (getCommand("Control-", last_input_command)) {
+        if (last_input_command >= 'A' && last_input_command <= 'Z') {
+            last_input_command -= 'A' - 1;
+        } else if (last_input_command >= 'a' && last_input_command <= 'z') {
+            last_input_command -= 'a' - 1;
         } else {
-            lastInputCommand = ' ';
+            last_input_command = ' ';
             printMessage("Type ^ <letter> for a control char");
         }
     } else {
-        lastInputCommand = ' ';
+        last_input_command = ' ';
     }
 
-    return lastInputCommand;
+    return last_input_command;
 }
 
 // Accept a command and execute it
 static void executeInputCommands(char &command, int &find_count) {
-    char lastInputCommand = command;
+    char last_input_command = command;
 
     // Accept a command and execute it
     do {
@@ -1049,38 +1047,38 @@ static void executeInputCommands(char &command, int &find_count) {
         }
 
         // move the cursor to the players character
-        panelMoveCursor(Coord_t{py.row, py.col});
+        panelMoveCursor(py.pos);
 
         message_ready_to_print = false;
 
         if (game.command_count > 0) {
             game.use_last_direction = true;
         } else {
-            lastInputCommand = getKeyInput();
+            last_input_command = getKeyInput();
 
             // Get a count for a command.
             int repeat_count = 0;
-            if ((config::options::use_roguelike_keys && lastInputCommand >= '0' && lastInputCommand <= '9') || (!config::options::use_roguelike_keys && lastInputCommand == '#')) {
-                repeat_count = getCommandRepeatCount(lastInputCommand);
+            if ((config::options::use_roguelike_keys && last_input_command >= '0' && last_input_command <= '9') || (!config::options::use_roguelike_keys && last_input_command == '#')) {
+                repeat_count = getCommandRepeatCount(last_input_command);
             }
 
             // Another way of typing control codes -CJS-
-            if (lastInputCommand == '^') {
-                lastInputCommand = parseAlternateCtrlInput(lastInputCommand);
+            if (last_input_command == '^') {
+                last_input_command = parseAlternateCtrlInput(last_input_command);
             }
 
             // move cursor to player char again, in case it moved
-            panelMoveCursor(Coord_t{py.row, py.col});
+            panelMoveCursor(py.pos);
 
             // Commands are always converted to rogue form. -CJS-
             if (!config::options::use_roguelike_keys) {
-                lastInputCommand = originalCommands(lastInputCommand);
+                last_input_command = originalCommands(last_input_command);
             }
 
             if (repeat_count > 0) {
-                if (!validCountCommand(lastInputCommand)) {
+                if (!validCountCommand(last_input_command)) {
                     game.player_free_turn = true;
-                    lastInputCommand = ' ';
+                    last_input_command = ' ';
                     printMessage("Invalid command with a count.");
                 } else {
                     game.command_count = repeat_count;
@@ -1091,10 +1089,10 @@ static void executeInputCommands(char &command, int &find_count) {
 
         // Flash the message line.
         messageLineClear();
-        panelMoveCursor(Coord_t{py.row, py.col});
+        panelMoveCursor(py.pos);
         putQIO();
 
-        doCommand(lastInputCommand);
+        doCommand(last_input_command);
 
         // Find is counted differently, as the command changes.
         if (py.running_tracker != 0) {
@@ -1107,7 +1105,7 @@ static void executeInputCommands(char &command, int &find_count) {
         }
     } while (game.player_free_turn && !dg.generate_new_level && (eof_flag == 0));
 
-    command = lastInputCommand;
+    command = last_input_command;
 }
 
 static char originalCommands(char command) {
@@ -1213,7 +1211,6 @@ static char originalCommands(char command) {
             command = 'W';
             break;
         case 'M':
-            break;
         case 'R':
             break;
         case 'S':
@@ -1336,56 +1333,56 @@ static char originalCommands(char command) {
 }
 
 static bool moveWithoutPickup(char *command) {
-    char com_val = *command;
+    char cmd = *command;
 
     // hack for move without pickup.  Map '-' to a movement command.
-    if (com_val != '-') {
+    if (cmd != '-') {
         return true;
     }
 
-    int dir_val;
+    int direction;
 
     // Save current game.command_count as getDirectionWithMemory() may change it
-    int countSave = game.command_count;
+    int count_save = game.command_count;
 
-    if (getDirectionWithMemory(CNIL, dir_val)) {
+    if (getDirectionWithMemory(CNIL, direction)) {
         // Restore game.command_count
-        game.command_count = countSave;
+        game.command_count = count_save;
 
-        switch (dir_val) {
+        switch (direction) {
             case 1:
-                com_val = 'b';
+                cmd = 'b';
                 break;
             case 2:
-                com_val = 'j';
+                cmd = 'j';
                 break;
             case 3:
-                com_val = 'n';
+                cmd = 'n';
                 break;
             case 4:
-                com_val = 'h';
+                cmd = 'h';
                 break;
             case 6:
-                com_val = 'l';
+                cmd = 'l';
                 break;
             case 7:
-                com_val = 'y';
+                cmd = 'y';
                 break;
             case 8:
-                com_val = 'k';
+                cmd = 'k';
                 break;
             case 9:
-                com_val = 'u';
+                cmd = 'u';
                 break;
             default:
-                com_val = '~';
+                cmd = '~';
                 break;
         }
     } else {
-        com_val = ' ';
+        cmd = ' ';
     }
 
-    *command = com_val;
+    *command = cmd;
 
     return false;
 }
@@ -1428,7 +1425,7 @@ static void commandPreviousMessage() {
 
     terminalSaveScreen();
 
-    uint8_t lineNumber = max_messages;
+    uint8_t line_number = max_messages;
     int16_t msg_id = last_message_id;
 
     while (max_messages > 0) {
@@ -1443,8 +1440,8 @@ static void commandPreviousMessage() {
         }
     }
 
-    eraseLine(Coord_t{lineNumber, 0});
-    waitForContinueKey(lineNumber);
+    eraseLine(Coord_t{line_number, 0});
+    waitForContinueKey(line_number);
     terminalRestoreScreen();
 }
 
@@ -1486,32 +1483,33 @@ static void commandLocateOnMap() {
         return;
     }
 
-    int y = py.row;
-    int x = py.col;
-    if (coordOutsidePanel(Coord_t{y, x}, true)) {
+    Coord_t player_coord = py.pos;
+    if (coordOutsidePanel(player_coord, true)) {
         drawDungeonPanel();
     }
 
-    int cy, cx, p_y, p_x;
-
-    cy = dg.panel.row;
-    cx = dg.panel.col;
-
     int dir_val;
     vtype_t out_val = {'\0'};
     vtype_t tmp_str = {'\0'};
 
-    while (true) {
-        p_y = dg.panel.row;
-        p_x = dg.panel.col;
+    Coord_t old_panel = Coord_t{dg.panel.row, dg.panel.col};
+    Coord_t panel = Coord_t{0, 0};
 
-        if (p_y == cy && p_x == cx) {
+    while (true) {
+        panel.y = dg.panel.row;
+        panel.x = dg.panel.col;
+
+        if (panel.y == old_panel.y && panel.x == old_panel.x) {
             tmp_str[0] = '\0';
         } else {
-            (void) sprintf(tmp_str, "%s%s of", p_y < cy ? " North" : p_y > cy ? " South" : "", p_x < cx ? " West" : p_x > cx ? " East" : "");
+            (void) sprintf(tmp_str,                                                                  //
+                           "%s%s of",                                                                //
+                           panel.y < old_panel.y ? " North" : panel.y > old_panel.y ? " South" : "", //
+                           panel.x < old_panel.x ? " West" : panel.x > old_panel.x ? " East" : ""    //
+            );
         }
 
-        (void) sprintf(out_val, "Map sector [%d,%d], which is%s your sector. Look which direction?", p_y, p_x, tmp_str);
+        (void) sprintf(out_val, "Map sector [%d,%d], which is%s your sector. Look which direction?", panel.y, panel.x, tmp_str);
 
         if (!getDirectionWithMemory(out_val, dir_val)) {
             break;
@@ -1522,19 +1520,19 @@ static void commandLocateOnMap() {
         // is nicer, as it moves exactly to the same place in another
         // section. The direction calculation is not intuitive. Sorry.
         while (true) {
-            x += ((dir_val - 1) % 3 - 1) * SCREEN_WIDTH / 2;
-            y -= ((dir_val - 1) / 3 - 1) * SCREEN_HEIGHT / 2;
+            player_coord.x += ((dir_val - 1) % 3 - 1) * SCREEN_WIDTH / 2;
+            player_coord.y -= ((dir_val - 1) / 3 - 1) * SCREEN_HEIGHT / 2;
 
-            if (x < 0 || y < 0 || x >= dg.width || y >= dg.width) {
+            if (player_coord.x < 0 || player_coord.y < 0 || player_coord.x >= dg.width || player_coord.y >= dg.width) {
                 printMessage("You've gone past the end of your map.");
 
-                x -= ((dir_val - 1) % 3 - 1) * SCREEN_WIDTH / 2;
-                y += ((dir_val - 1) / 3 - 1) * SCREEN_HEIGHT / 2;
+                player_coord.x -= ((dir_val - 1) % 3 - 1) * SCREEN_WIDTH / 2;
+                player_coord.y += ((dir_val - 1) / 3 - 1) * SCREEN_HEIGHT / 2;
 
                 break;
             }
 
-            if (coordOutsidePanel(Coord_t{y, x}, true)) {
+            if (coordOutsidePanel(player_coord, true)) {
                 drawDungeonPanel();
                 break;
             }
@@ -1542,7 +1540,7 @@ static void commandLocateOnMap() {
     }
 
     // Move to a new panel - but only if really necessary.
-    if (coordOutsidePanel(Coord_t{py.row, py.col}, false)) {
+    if (coordOutsidePanel(py.pos, false)) {
         drawDungeonPanel();
     }
 }
@@ -1555,30 +1553,11 @@ static void commandToggleSearch() {
     }
 }
 
-static void doWizardCommands(char com_val) {
-    int i, y, x;
-
-    switch (com_val) {
+static void doWizardCommands(char command) {
+    switch (command) {
         case CTRL_KEY('A'):
             // Cure all!
-            (void) spellRemoveCurseFromAllItems();
-            (void) playerCureBlindness();
-            (void) playerCureConfusion();
-            (void) playerCurePoison();
-            (void) playerRemoveFear();
-            (void) playerStatRestore(py_attrs::A_STR);
-            (void) playerStatRestore(py_attrs::A_INT);
-            (void) playerStatRestore(py_attrs::A_WIS);
-            (void) playerStatRestore(py_attrs::A_CON);
-            (void) playerStatRestore(py_attrs::A_DEX);
-            (void) playerStatRestore(py_attrs::A_CHR);
-
-            if (py.flags.slow > 1) {
-                py.flags.slow = 1;
-            }
-            if (py.flags.image > 1) {
-                py.flags.image = 1;
-            }
+            wizardCureAll();
             break;
         case CTRL_KEY('E'):
             // Edit Character
@@ -1591,45 +1570,11 @@ static void doWizardCommands(char com_val) {
             break;
         case CTRL_KEY('G'):
             // Generate random items
-            if (game.command_count > 0) {
-                i = game.command_count;
-                game.command_count = 0;
-            } else {
-                i = 1;
-            }
-            dungeonPlaceRandomObjectNear(Coord_t{py.row, py.col}, i);
-
-            drawDungeonPanel();
+            wizardDropRandomItems();
             break;
         case CTRL_KEY('D'):
             // Go up/down to specified depth
-            if (game.command_count > 0) {
-                if (game.command_count > 99) {
-                    i = 0;
-                } else {
-                    i = game.command_count;
-                }
-                game.command_count = 0;
-            } else {
-                i = -1;
-                vtype_t input = {0};
-
-                putStringClearToEOL("Go to which level (0-99) ? ", Coord_t{0, 0});
-
-                if (getStringInput(input, Coord_t{0, 27}, 10)) {
-                    (void) stringToNumber(input, i);
-                }
-            }
-
-            if (i >= 0) {
-                dg.current_level = (int16_t) i;
-                if (dg.current_level > 99) {
-                    dg.current_level = 99;
-                }
-                dg.generate_new_level = true;
-            } else {
-                messageLineClear();
-            }
+            wizardJumpLevel();
             break;
         case CTRL_KEY('O'):
             // Print random level object to a file
@@ -1666,23 +1611,11 @@ static void doWizardCommands(char com_val) {
             break;
         case '+':
             // Increase Experience
-            if (game.command_count > 0) {
-                py.misc.exp = game.command_count;
-                game.command_count = 0;
-            } else if (py.misc.exp == 0) {
-                py.misc.exp = 1;
-            } else {
-                py.misc.exp = py.misc.exp * 2;
-            }
-            displayCharacterExperience();
+            wizardGainExperience();
             break;
         case '&':
             // Summon a random monster
-            y = py.row;
-            x = py.col;
-            (void) monsterSummon(y, x, true);
-
-            updateMonsters(false);
+            wizardSummonMonster();
             break;
         case '@':
             // Generate an object
@@ -1736,11 +1669,8 @@ static void doCommand(char command) {
             itemInscribe();
             game.player_free_turn = true;
             break;
-        case '!': // (!) escape to the shell
-        case '$':
-            // escaping to shell disabled -MRC-
-            game.player_free_turn = true;
-            break;
+        case '!':    // (!) escape to the shell
+        case '$':    // escaping to shell disabled -MRC-
         case ESCAPE: // (ESC)   do nothing.
         case ' ':    // (space) do nothing.
             game.player_free_turn = true;
@@ -1931,7 +1861,7 @@ static void doCommand(char command) {
             scrollRead();
             break;
         case 's': // (s)earch for a turn
-            playerSearch(py.row, py.col, py.misc.chance_in_search);
+            playerSearch(py.pos, py.misc.chance_in_search);
             break;
         case 'T': // (T)ake off something  (t)ake off
             inventoryExecuteCommand('t');
@@ -2063,14 +1993,14 @@ static void playerRegenerateHitPoints(int percent) {
 
     // check for overflow
     if (py.misc.current_hp < 0 && old_chp > 0) {
-        py.misc.current_hp = MAX_SHORT;
+        py.misc.current_hp = SHRT_MAX;
     }
 
     // mod 65536
     int32_t new_chp_fraction = (new_chp & 0xFFFF) + py.misc.current_hp_fraction;
 
     if (new_chp_fraction >= 0x10000L) {
-        py.misc.current_hp_fraction = (uint16_t) (new_chp_fraction - 0x10000L);
+        py.misc.current_hp_fraction = (uint16_t)(new_chp_fraction - 0x10000L);
         py.misc.current_hp++;
     } else {
         py.misc.current_hp_fraction = (uint16_t) new_chp_fraction;
@@ -2097,14 +2027,14 @@ static void playerRegenerateMana(int percent) {
 
     // check for overflow
     if (py.misc.current_mana < 0 && old_cmana > 0) {
-        py.misc.current_mana = MAX_SHORT;
+        py.misc.current_mana = SHRT_MAX;
     }
 
     // mod 65536
     int32_t new_mana_fraction = (new_mana & 0xFFFF) + py.misc.current_mana_fraction;
 
     if (new_mana_fraction >= 0x10000L) {
-        py.misc.current_mana_fraction = (uint16_t) (new_mana_fraction - 0x10000L);
+        py.misc.current_mana_fraction = (uint16_t)(new_mana_fraction - 0x10000L);
         py.misc.current_mana++;
     } else {
         py.misc.current_mana_fraction = (uint16_t) new_mana_fraction;
@@ -2144,11 +2074,7 @@ static bool itemEnchanted(Inventory_t const &item) {
         return true;
     }
 
-    if ((0x07ffe980L & item.flags) != 0) {
-        return true;
-    }
-
-    return false;
+    return (0x07ffe980L & item.flags) != 0;
 }
 
 // Examine a Book -RAK-
@@ -2179,7 +2105,7 @@ static void examineBook() {
         int spell_index[31];
         bool can_read = true;
 
-        uint8_t treasure_type = inventory[item_id].category_id;
+        uint8_t treasure_type = py.inventory[item_id].category_id;
 
         if (classes[py.misc.class_id].class_to_use_mage_spells == config::spells::SPELL_TYPE_MAGE) {
             if (treasure_type != TV_MAGIC_BOOK) {
@@ -2198,7 +2124,7 @@ static void examineBook() {
             return;
         }
 
-        uint32_t item_flags = inventory[item_id].flags;
+        uint32_t item_flags = py.inventory[item_id].flags;
 
         int spell_id = 0;
         while (item_flags != 0u) {
@@ -2219,9 +2145,9 @@ static void examineBook() {
 
 // Go up one level -RAK-
 static void dungeonGoUpLevel() {
-    uint8_t tile_id = dg.floor[py.row][py.col].treasure_id;
+    uint8_t tile_id = dg.floor[py.pos.y][py.pos.x].treasure_id;
 
-    if (tile_id != 0 && treasure_list[tile_id].category_id == TV_UP_STAIR) {
+    if (tile_id != 0 && game.treasure.list[tile_id].category_id == TV_UP_STAIR) {
         dg.current_level--;
 
         printMessage("You enter a maze of up staircases.");
@@ -2236,9 +2162,9 @@ static void dungeonGoUpLevel() {
 
 // Go down one level -RAK-
 static void dungeonGoDownLevel() {
-    uint8_t tile_id = dg.floor[py.row][py.col].treasure_id;
+    uint8_t tile_id = dg.floor[py.pos.y][py.pos.x].treasure_id;
 
-    if (tile_id != 0 && treasure_list[tile_id].category_id == TV_DOWN_STAIR) {
+    if (tile_id != 0 && game.treasure.list[tile_id].category_id == TV_DOWN_STAIR) {
         dg.current_level++;
 
         printMessage("You enter a maze of down staircases.");
@@ -2255,23 +2181,22 @@ static void dungeonGoDownLevel() {
 static void dungeonJamDoor() {
     game.player_free_turn = true;
 
-    int y = py.row;
-    int x = py.col;
+    Coord_t coord = py.pos;
 
     int direction;
     if (!getDirectionWithMemory(CNIL, direction)) {
         return;
     }
-    (void) playerMovePosition(direction, y, x);
+    (void) playerMovePosition(direction, coord);
 
-    Tile_t const &tile = dg.floor[y][x];
+    Tile_t const &tile = dg.floor[coord.y][coord.x];
 
     if (tile.treasure_id == 0) {
         printMessage("That isn't a door!");
         return;
     }
 
-    Inventory_t &item = treasure_list[tile.treasure_id];
+    Inventory_t &item = game.treasure.list[tile.treasure_id];
 
     uint8_t item_id = item.category_id;
     if (item_id != TV_CLOSED_DOOR && item_id != TV_OPEN_DOOR) {
@@ -2302,9 +2227,9 @@ static void dungeonJamDoor() {
             // Series is: 0 20 30 37 43 48 52 56 60 64 67 70 ...
             item.misc_use -= 1 + 190 / (10 - item.misc_use);
 
-            if (inventory[item_pos_start].items_count > 1) {
-                inventory[item_pos_start].items_count--;
-                py.inventory_weight -= inventory[item_pos_start].weight;
+            if (py.inventory[item_pos_start].items_count > 1) {
+                py.inventory[item_pos_start].items_count--;
+                py.pack.weight -= py.inventory[item_pos_start].weight;
             } else {
                 inventoryDestroyItem(item_pos_start);
             }
@@ -2324,7 +2249,7 @@ static void dungeonJamDoor() {
 static void inventoryRefillLamp() {
     game.player_free_turn = true;
 
-    if (inventory[player_equipment::EQUIPMENT_LIGHT].sub_category_id != 0) {
+    if (py.inventory[PlayerEquipment::Light].sub_category_id != 0) {
         printMessage("But you are not using a lamp.");
         return;
     }
@@ -2337,8 +2262,8 @@ static void inventoryRefillLamp() {
 
     game.player_free_turn = false;
 
-    Inventory_t &item = inventory[player_equipment::EQUIPMENT_LIGHT];
-    item.misc_use += inventory[item_pos_start].misc_use;
+    Inventory_t &item = py.inventory[PlayerEquipment::Light];
+    item.misc_use += py.inventory[item_pos_start].misc_use;
 
     if (item.misc_use > config::treasure::OBJECT_LAMP_MAX_CAPACITY) {
         item.misc_use = config::treasure::OBJECT_LAMP_MAX_CAPACITY;
@@ -2387,7 +2312,7 @@ static void playDungeon() {
 
     // Note: yes, this last input command needs to be persisted
     // over different iterations of the main loop below -MRC-
-    char lastInputCommand = {0};
+    char last_input_command = {0};
 
     // Loop until dead,  or new level
     // Exit when `dg.generate_new_level` and `eof_flag` are both set
@@ -2477,16 +2402,16 @@ static void playDungeon() {
 
         // Accept a command?
         if (py.flags.paralysis < 1 && py.flags.rest == 0 && !game.character_is_dead) {
-            executeInputCommands(lastInputCommand, find_count);
+            executeInputCommands(last_input_command, find_count);
         } else {
             // if paralyzed, resting, or dead, flush output
             // but first move the cursor onto the player, for aesthetics
-            panelMoveCursor(Coord_t{py.row, py.col});
+            panelMoveCursor(py.pos);
             putQIO();
         }
 
         // Teleport?
-        if (teleport_player) {
+        if (game.teleport_player) {
             playerTeleport(100);
         }
 
