@@ -10,13 +10,11 @@
 
 #include "headers.h"
 
-Inventory_t inventory[PLAYER_INVENTORY_SIZE];
-
 uint32_t inventoryCollectAllItemFlags() {
     uint32_t flags = 0;
 
-    for (int i = player_equipment::EQUIPMENT_WIELD; i < player_equipment::EQUIPMENT_LIGHT; i++) {
-        flags |= inventory[i].flags;
+    for (int i = PlayerEquipment::Wield; i < PlayerEquipment::Light; i++) {
+        flags |= py.inventory[i].flags;
     }
 
     return flags;
@@ -24,20 +22,20 @@ uint32_t inventoryCollectAllItemFlags() {
 
 // Destroy an item in the inventory -RAK-
 void inventoryDestroyItem(int item_id) {
-    Inventory_t &item = inventory[item_id];
+    Inventory_t &item = py.inventory[item_id];
 
     if (item.items_count > 1 && item.sub_category_id <= ITEM_SINGLE_STACK_MAX) {
         item.items_count--;
-        py.inventory_weight -= item.weight;
+        py.pack.weight -= item.weight;
     } else {
-        py.inventory_weight -= item.weight * item.items_count;
+        py.pack.weight -= item.weight * item.items_count;
 
-        for (int i = item_id; i < py.unique_inventory_items - 1; i++) {
-            inventory[i] = inventory[i + 1];
+        for (int i = item_id; i < py.pack.unique_items - 1; i++) {
+            py.inventory[i] = py.inventory[i + 1];
         }
 
-        inventoryItemCopyTo(config::dungeon::objects::OBJ_NOTHING, inventory[py.unique_inventory_items - 1]);
-        py.unique_inventory_items--;
+        inventoryItemCopyTo(config::dungeon::objects::OBJ_NOTHING, py.inventory[py.pack.unique_items - 1]);
+        py.pack.unique_items--;
     }
 
     py.flags.status |= config::player::status::PY_STR_WGT;
@@ -55,39 +53,39 @@ void inventoryTakeOneItem(Inventory_t *to_item, Inventory_t *from_item) {
 
 // Drops an item from inventory to given location -RAK-
 void inventoryDropItem(int item_id, bool drop_all) {
-    if (dg.floor[py.row][py.col].treasure_id != 0) {
-        (void) dungeonDeleteObject(Coord_t{py.row, py.col});;
+    if (dg.floor[py.pos.y][py.pos.x].treasure_id != 0) {
+        (void) dungeonDeleteObject(py.pos);
     }
 
-    int treasureID = popt();
+    int treasure_id = popt();
 
-    Inventory_t &item = inventory[item_id];
-    treasure_list[treasureID] = item;
+    Inventory_t &item = py.inventory[item_id];
+    game.treasure.list[treasure_id] = item;
 
-    dg.floor[py.row][py.col].treasure_id = (uint8_t) treasureID;
+    dg.floor[py.pos.y][py.pos.x].treasure_id = (uint8_t) treasure_id;
 
-    if (item_id >= player_equipment::EQUIPMENT_WIELD) {
+    if (item_id >= PlayerEquipment::Wield) {
         playerTakeOff(item_id, -1);
     } else {
         if (drop_all || item.items_count == 1) {
-            py.inventory_weight -= item.weight * item.items_count;
-            py.unique_inventory_items--;
+            py.pack.weight -= item.weight * item.items_count;
+            py.pack.unique_items--;
 
-            while (item_id < py.unique_inventory_items) {
-                inventory[item_id] = inventory[item_id + 1];
+            while (item_id < py.pack.unique_items) {
+                py.inventory[item_id] = py.inventory[item_id + 1];
                 item_id++;
             }
 
-            inventoryItemCopyTo(config::dungeon::objects::OBJ_NOTHING, inventory[py.unique_inventory_items]);
+            inventoryItemCopyTo(config::dungeon::objects::OBJ_NOTHING, py.inventory[py.pack.unique_items]);
         } else {
-            treasure_list[treasureID].items_count = 1;
-            py.inventory_weight -= item.weight;
+            game.treasure.list[treasure_id].items_count = 1;
+            py.pack.weight -= item.weight;
             item.items_count--;
         }
 
         obj_desc_t prt1 = {'\0'};
         obj_desc_t prt2 = {'\0'};
-        itemDescription(prt1, treasure_list[treasureID], true);
+        itemDescription(prt1, game.treasure.list[treasure_id], true);
         (void) sprintf(prt2, "Dropped %s", prt1);
         printMessage(prt2);
     }
@@ -99,8 +97,8 @@ void inventoryDropItem(int item_id, bool drop_all) {
 static int inventoryDamageItem(bool (*item_type)(Inventory_t *), int chance_percentage) {
     int damage = 0;
 
-    for (int i = 0; i < py.unique_inventory_items; i++) {
-        if ((*item_type)(&inventory[i]) && randomNumber(100) < chance_percentage) {
+    for (int i = 0; i < py.pack.unique_items; i++) {
+        if ((*item_type)(&py.inventory[i]) && randomNumber(100) < chance_percentage) {
             inventoryDestroyItem(i);
             damage++;
         }
@@ -110,7 +108,7 @@ static int inventoryDamageItem(bool (*item_type)(Inventory_t *), int chance_perc
 }
 
 bool inventoryDiminishLightAttack(bool noticed) {
-    Inventory_t &item = inventory[player_equipment::EQUIPMENT_LIGHT];
+    Inventory_t &item = py.inventory[PlayerEquipment::Light];
 
     if (item.misc_use > 0) {
         item.misc_use -= (250 + randomNumber(250));
@@ -132,7 +130,7 @@ bool inventoryDiminishLightAttack(bool noticed) {
 }
 
 bool inventoryDiminishChargesAttack(uint8_t creature_level, int16_t &monster_hp, bool noticed) {
-    Inventory_t &item = inventory[randomNumber(py.unique_inventory_items) - 1];
+    Inventory_t &item = py.inventory[randomNumber(py.pack.unique_items) - 1];
 
     bool has_charges = item.category_id == TV_STAFF || item.category_id == TV_WAND;
 
@@ -155,32 +153,32 @@ bool executeDisenchantAttack() {
 
     switch (randomNumber(7)) {
         case 1:
-            item_id = player_equipment::EQUIPMENT_WIELD;
+            item_id = PlayerEquipment::Wield;
             break;
         case 2:
-            item_id = player_equipment::EQUIPMENT_BODY;
+            item_id = PlayerEquipment::Body;
             break;
         case 3:
-            item_id = player_equipment::EQUIPMENT_ARM;
+            item_id = PlayerEquipment::Arm;
             break;
         case 4:
-            item_id = player_equipment::EQUIPMENT_OUTER;
+            item_id = PlayerEquipment::Outer;
             break;
         case 5:
-            item_id = player_equipment::EQUIPMENT_HANDS;
+            item_id = PlayerEquipment::Hands;
             break;
         case 6:
-            item_id = player_equipment::EQUIPMENT_HEAD;
+            item_id = PlayerEquipment::Head;
             break;
         case 7:
-            item_id = player_equipment::EQUIPMENT_FEET;
+            item_id = PlayerEquipment::Feet;
             break;
         default:
             return false;
     }
 
     bool success = false;
-    Inventory_t &item = inventory[item_id];
+    Inventory_t &item = py.inventory[item_id];
 
     if (item.to_hit > 0) {
         item.to_hit -= randomNumber(2);
@@ -215,7 +213,7 @@ bool executeDisenchantAttack() {
 
 // this code must be identical to the inventoryCarryItem() code below
 bool inventoryCanCarryItemCount(Inventory_t const &item) {
-    if (py.unique_inventory_items < player_equipment::EQUIPMENT_WIELD) {
+    if (py.pack.unique_items < PlayerEquipment::Wield) {
         return true;
     }
 
@@ -223,19 +221,20 @@ bool inventoryCanCarryItemCount(Inventory_t const &item) {
         return false;
     }
 
-    for (int i = 0; i < py.unique_inventory_items; i++) {
-        bool same_character = inventory[i].category_id == item.category_id;
-        bool same_category = inventory[i].sub_category_id == item.sub_category_id;
+    for (int i = 0; i < py.pack.unique_items; i++) {
+        bool same_character = py.inventory[i].category_id == item.category_id;
+        bool same_category = py.inventory[i].sub_category_id == item.sub_category_id;
 
         // make sure the number field doesn't overflow
-        bool same_number = inventory[i].items_count + item.items_count < 256;
+        // NOTE: convert to bigger types before addition -MRC-
+        bool same_number = uint16_t(py.inventory[i].items_count) + uint16_t(item.items_count) < 256;
 
         // they always stack (sub_category_id < 192), or else they have same `misc_use`
-        bool same_group = item.sub_category_id < ITEM_GROUP_MIN || inventory[i].misc_use == item.misc_use;
+        bool same_group = item.sub_category_id < ITEM_GROUP_MIN || py.inventory[i].misc_use == item.misc_use;
 
         // only stack if both or neither are identified
         // TODO(cook): is it correct that they should be equal to each other, regardless of true/false value?
-        bool inventory_item_is_colorless = itemSetColorlessAsIdentified(inventory[i].category_id, inventory[i].sub_category_id, inventory[i].identification);
+        bool inventory_item_is_colorless = itemSetColorlessAsIdentified(py.inventory[i].category_id, py.inventory[i].sub_category_id, py.inventory[i].identification);
         bool item_is_colorless = itemSetColorlessAsIdentified(item.category_id, item.sub_category_id, item.identification);
         bool identification = inventory_item_is_colorless == item_is_colorless;
 
@@ -250,15 +249,15 @@ bool inventoryCanCarryItemCount(Inventory_t const &item) {
 // return false if picking up an object would change the players speed
 bool inventoryCanCarryItem(Inventory_t const &item) {
     int limit = playerCarryingLoadLimit();
-    int newWeight = item.items_count * item.weight + py.inventory_weight;
+    int new_weight = item.items_count * item.weight + py.pack.weight;
 
-    if (limit < newWeight) {
-        limit = newWeight / (limit + 1);
+    if (limit < new_weight) {
+        limit = new_weight / (limit + 1);
     } else {
         limit = 0;
     }
 
-    return py.pack_heaviness == limit;
+    return py.pack.heaviness == limit;
 }
 
 // Add an item to players inventory.  Return the
@@ -272,7 +271,7 @@ int inventoryCarryItem(Inventory_t &new_item) {
 
     // Now, check to see if player can carry object
     for (slot_id = 0; slot_id < PLAYER_INVENTORY_SIZE; slot_id++) {
-        Inventory_t &item = inventory[slot_id];
+        Inventory_t &item = py.inventory[slot_id];
 
         bool is_same_category = new_item.category_id == item.category_id && new_item.sub_category_id == item.sub_category_id;
         bool not_too_many_items = int(item.items_count + new_item.items_count) < 256;
@@ -289,16 +288,16 @@ int inventoryCarryItem(Inventory_t &new_item) {
         if ((is_same_category && is_always_known) || new_item.category_id > item.category_id) {
             // For items which are always `is_known`, i.e. never have a 'color',
             // insert them into the inventory in sorted order.
-            for (int i = py.unique_inventory_items - 1; i >= slot_id; i--) {
-                inventory[i + 1] = inventory[i];
+            for (int i = py.pack.unique_items - 1; i >= slot_id; i--) {
+                py.inventory[i + 1] = py.inventory[i];
             }
-            inventory[slot_id] = new_item;
-            py.unique_inventory_items++;
+            py.inventory[slot_id] = new_item;
+            py.pack.unique_items++;
             break;
         }
     }
 
-    py.inventory_weight += new_item.items_count * new_item.weight;
+    py.pack.weight += new_item.items_count * new_item.weight;
     py.flags.status |= config::player::status::PY_STR_WGT;
 
     return slot_id;
@@ -311,8 +310,8 @@ bool inventoryFindRange(int item_id_start, int item_id_end, int &j, int &k) {
 
     bool at_end_of_range = false;
 
-    for (int i = 0; i < py.unique_inventory_items; i++) {
-        auto item_id = (int) inventory[i].category_id;
+    for (int i = 0; i < py.pack.unique_items; i++) {
+        auto item_id = (int) py.inventory[i].category_id;
 
         if (!at_end_of_range) {
             if (item_id == item_id_start || item_id == item_id_end) {
@@ -328,7 +327,7 @@ bool inventoryFindRange(int item_id_start, int item_id_end, int &j, int &k) {
     }
 
     if (at_end_of_range && k == -1) {
-        k = py.unique_inventory_items - 1;
+        k = py.pack.unique_items - 1;
     }
 
     return at_end_of_range;
@@ -338,7 +337,7 @@ void inventoryItemCopyTo(int from_item_id, Inventory_t &to_item) {
     DungeonObject_t const &from = game_objects[from_item_id];
 
     to_item.id = (uint16_t) from_item_id;
-    to_item.special_name_id = special_name_ids::SN_NULL;
+    to_item.special_name_id = SpecialNameIds::SN_NULL;
     to_item.inscription[0] = '\0';
     to_item.flags = from.flags;
     to_item.category_id = from.category_id;
@@ -362,65 +361,65 @@ void inventoryItemCopyTo(int from_item_id, Inventory_t &to_item) {
 // Note: This routine affects magical AC bonuses so
 // that stores can detect the damage.
 static bool damageMinusAC(uint32_t typ_dam) {
-    int itemsCount = 0;
-    int items[6];
+    int items_count = 0;
+    uint8_t items[6];
 
-    if (inventory[player_equipment::EQUIPMENT_BODY].category_id != TV_NOTHING) {
-        items[itemsCount] = player_equipment::EQUIPMENT_BODY;
-        itemsCount++;
+    if (py.inventory[PlayerEquipment::Body].category_id != TV_NOTHING) {
+        items[items_count] = PlayerEquipment::Body;
+        items_count++;
     }
 
-    if (inventory[player_equipment::EQUIPMENT_ARM].category_id != TV_NOTHING) {
-        items[itemsCount] = player_equipment::EQUIPMENT_ARM;
-        itemsCount++;
+    if (py.inventory[PlayerEquipment::Arm].category_id != TV_NOTHING) {
+        items[items_count] = PlayerEquipment::Arm;
+        items_count++;
     }
 
-    if (inventory[player_equipment::EQUIPMENT_OUTER].category_id != TV_NOTHING) {
-        items[itemsCount] = player_equipment::EQUIPMENT_OUTER;
-        itemsCount++;
+    if (py.inventory[PlayerEquipment::Outer].category_id != TV_NOTHING) {
+        items[items_count] = PlayerEquipment::Outer;
+        items_count++;
     }
 
-    if (inventory[player_equipment::EQUIPMENT_HANDS].category_id != TV_NOTHING) {
-        items[itemsCount] = player_equipment::EQUIPMENT_HANDS;
-        itemsCount++;
+    if (py.inventory[PlayerEquipment::Hands].category_id != TV_NOTHING) {
+        items[items_count] = PlayerEquipment::Hands;
+        items_count++;
     }
 
-    if (inventory[player_equipment::EQUIPMENT_HEAD].category_id != TV_NOTHING) {
-        items[itemsCount] = player_equipment::EQUIPMENT_HEAD;
-        itemsCount++;
+    if (py.inventory[PlayerEquipment::Head].category_id != TV_NOTHING) {
+        items[items_count] = PlayerEquipment::Head;
+        items_count++;
     }
 
     // also affect boots
-    if (inventory[player_equipment::EQUIPMENT_FEET].category_id != TV_NOTHING) {
-        items[itemsCount] = player_equipment::EQUIPMENT_FEET;
-        itemsCount++;
+    if (py.inventory[PlayerEquipment::Feet].category_id != TV_NOTHING) {
+        items[items_count] = PlayerEquipment::Feet;
+        items_count++;
     }
 
     bool minus = false;
 
-    if (itemsCount == 0) {
+    if (items_count == 0) {
         return minus;
     }
 
-    int itemID = items[randomNumber(itemsCount) - 1];
+    uint8_t item_id = items[randomNumber(items_count) - 1];
 
     obj_desc_t description = {'\0'};
     obj_desc_t msg = {'\0'};
 
-    if ((inventory[itemID].flags & typ_dam) != 0u) {
+    if ((py.inventory[item_id].flags & typ_dam) != 0u) {
         minus = true;
 
-        itemDescription(description, inventory[itemID], false);
+        itemDescription(description, py.inventory[item_id], false);
         (void) sprintf(msg, "Your %s resists damage!", description);
         printMessage(msg);
-    } else if (inventory[itemID].ac + inventory[itemID].to_ac > 0) {
+    } else if (py.inventory[item_id].ac + py.inventory[item_id].to_ac > 0) {
         minus = true;
 
-        itemDescription(description, inventory[itemID], false);
+        itemDescription(description, py.inventory[item_id], false);
         (void) sprintf(msg, "Your %s is damaged!", description);
         printMessage(msg);
 
-        inventory[itemID].to_ac--;
+        py.inventory[item_id].to_ac--;
         playerRecalculateBonuses();
     }
 
@@ -549,7 +548,7 @@ bool setFireDestroyableItems(Inventory_t *item) {
 
 // Corrode the unsuspecting person's armor -RAK-
 void damageCorrodingGas(const char *creature_name) {
-    if (!damageMinusAC((uint32_t) config::treasure::flags::TR_RES_ACID)) {
+    if (!damageMinusAC(config::treasure::flags::TR_RES_ACID)) {
         playerTakesHit(randomNumber(8), creature_name);
     }
 
@@ -616,7 +615,7 @@ void damageLightningBolt(int damage, const char *creature_name) {
 void damageAcid(int damage, const char *creature_name) {
     int flag = 0;
 
-    if (damageMinusAC((uint32_t) config::treasure::flags::TR_RES_ACID)) {
+    if (damageMinusAC(config::treasure::flags::TR_RES_ACID)) {
         flag = 1;
     }
 
