@@ -19,7 +19,7 @@ static bool executeAttackOnPlayer(uint8_t creature_level, int16_t &monster_hp, i
 static bool monsterIsVisible(Monster_t const &monster) {
     bool visible = false;
 
-    Tile_t const &tile = dg.floor[monster.y][monster.x];
+    Tile_t const &tile = dg.floor[monster.pos.y][monster.pos.x];
     Creature_t const &creature = creatures_list[monster.creature_id];
 
     if (tile.permanent_light || tile.temporary_light || ((py.running_tracker != 0) && monster.distance_from_player < 2 && py.carrying_light)) {
@@ -44,11 +44,12 @@ void monsterUpdateVisibility(int monster_id) {
     bool visible = false;
     Monster_t &monster = monsters[monster_id];
 
-    if (monster.distance_from_player <= config::monsters::MON_MAX_SIGHT && ((py.flags.status & config::player::status::PY_BLIND) == 0u) && coordInsidePanel(Coord_t{monster.y, monster.x})) {
+    if (monster.distance_from_player <= config::monsters::MON_MAX_SIGHT && ((py.flags.status & config::player::status::PY_BLIND) == 0u) &&
+        coordInsidePanel(Coord_t{monster.pos.y, monster.pos.x})) {
         if (game.wizard_mode) {
             // Wizard sight.
             visible = true;
-        } else if (los(py.row, py.col, monster.y, monster.x)) {
+        } else if (los(py.pos, monster.pos)) {
             visible = monsterIsVisible(monster);
         }
     }
@@ -58,7 +59,7 @@ void monsterUpdateVisibility(int monster_id) {
         if (!monster.lit) {
             playerDisturb(1, 0);
             monster.lit = true;
-            dungeonLiteSpot(Coord_t{monster.y, monster.x});
+            dungeonLiteSpot(Coord_t{monster.pos.y, monster.pos.x});
 
             // notify inventoryExecuteCommand()
             screen_has_changed = true;
@@ -66,7 +67,7 @@ void monsterUpdateVisibility(int monster_id) {
     } else if (monster.lit) {
         // Turn it off.
         monster.lit = false;
-        dungeonLiteSpot(Coord_t{monster.y, monster.x});
+        dungeonLiteSpot(Coord_t{monster.pos.y, monster.pos.x});
 
         // notify inventoryExecuteCommand()
         screen_has_changed = true;
@@ -88,14 +89,14 @@ static int monsterMovementRate(int16_t speed) {
     int rate = 0;
     if ((dg.game_turn % (2 - speed)) == 0) {
         rate = 1;
-    };
+    }
 
     return rate;
 }
 
 // Makes sure a new creature gets lit up. -CJS-
-static bool monsterMakeVisible(int y, int x) {
-    int monster_id = dg.floor[y][x].creature_id;
+static bool monsterMakeVisible(Coord_t coord) {
+    int monster_id = dg.floor[coord.y][coord.x].creature_id;
     if (monster_id <= 1) {
         return false;
     }
@@ -108,8 +109,8 @@ static bool monsterMakeVisible(int y, int x) {
 static void monsterGetMoveDirection(int monster_id, int *directions) {
     int ay, ax, movement;
 
-    int y = monsters[monster_id].y - py.row;
-    int x = monsters[monster_id].x - py.col;
+    int y = monsters[monster_id].pos.y - py.pos.y;
+    int x = monsters[monster_id].pos.x - py.pos.x;
 
     if (y < 0) {
         movement = 8;
@@ -356,7 +357,6 @@ static void monsterPrintAttackDescription(char *msg, int attack_id) {
     }
 }
 
-
 static void monsterConfuseOnAttack(Creature_t const &creature, Monster_t &monster, int attack_type, vtype_t monster_name, bool visible) {
     if (py.flags.confuse_monster && attack_type != 99) {
         printMessage("Your hands stop glowing.");
@@ -371,7 +371,7 @@ static void monsterConfuseOnAttack(Creature_t const &creature, Monster_t &monste
             if (monster.confused_amount != 0u) {
                 monster.confused_amount += 3;
             } else {
-                monster.confused_amount = (uint8_t) (2 + randomNumber(16));
+                monster.confused_amount = (uint8_t)(2 + randomNumber(16));
             }
         }
 
@@ -381,7 +381,6 @@ static void monsterConfuseOnAttack(Creature_t const &creature, Monster_t &monste
             creature_recall[monster.creature_id].defenses |= creature.defenses & config::monsters::defense::CD_NO_SLEEP;
         }
     }
-
 }
 
 // Make an attack on the player (chuckle.) -RAK-
@@ -406,7 +405,9 @@ static void monsterAttackPlayer(int monster_id) {
 
     int attack_counter = 0;
     for (auto &damage_type_id : creature.damage) {
-        if (damage_type_id == 0 || game.character_is_dead) break;
+        if (damage_type_id == 0 || game.character_is_dead) {
+            break;
+        }
 
         uint8_t attack_type = monster_attacks[damage_type_id].type_id;
         uint8_t attack_desc = monster_attacks[damage_type_id].description_id;
@@ -450,11 +451,12 @@ static void monsterAttackPlayer(int monster_id) {
             // had previously noticed the attack (in which case all this does
             // is help player learn damage), note that in the second case do
             // not increase attacks if creature repelled (no damage done)
-            if ((notice || (visible && creature_recall[monster.creature_id].attacks[attack_counter] != 0 && attack_type != 99)) && creature_recall[monster.creature_id].attacks[attack_counter] < MAX_UCHAR) {
+            if ((notice || (visible && creature_recall[monster.creature_id].attacks[attack_counter] != 0 && attack_type != 99)) &&
+                creature_recall[monster.creature_id].attacks[attack_counter] < UCHAR_MAX) {
                 creature_recall[monster.creature_id].attacks[attack_counter]++;
             }
 
-            if (game.character_is_dead && creature_recall[monster.creature_id].deaths < MAX_SHORT) {
+            if (game.character_is_dead && creature_recall[monster.creature_id].deaths < SHRT_MAX) {
                 creature_recall[monster.creature_id].deaths++;
             }
         } else {
@@ -475,8 +477,8 @@ static void monsterAttackPlayer(int monster_id) {
     }
 }
 
-static void monsterOpenDoor(Tile_t &tile, int16_t monster_hp, uint32_t move_bits, bool &do_turn, bool &do_move, uint32_t &rcmove, int y, int x) {
-    Inventory_t &item = treasure_list[tile.treasure_id];
+static void monsterOpenDoor(Tile_t &tile, int16_t monster_hp, uint32_t move_bits, bool &do_turn, bool &do_move, uint32_t &rcmove, Coord_t coord) {
+    Inventory_t &item = game.treasure.list[tile.treasure_id];
 
     // Creature can open doors.
     if ((move_bits & config::monsters::move::CM_OPEN_DOOR) != 0u) {
@@ -515,10 +517,10 @@ static void monsterOpenDoor(Tile_t &tile, int16_t monster_hp, uint32_t move_bits
 
             // 50% chance of breaking door
             if (door_is_stuck) {
-                item.misc_use = (int16_t) (1 - randomNumber(2));
+                item.misc_use = (int16_t)(1 - randomNumber(2));
             }
             tile.feature_id = TILE_CORR_FLOOR;
-            dungeonLiteSpot(Coord_t{y, x});
+            dungeonLiteSpot(coord);
             rcmove |= config::monsters::move::CM_OPEN_DOOR;
             do_move = false;
         }
@@ -531,21 +533,21 @@ static void monsterOpenDoor(Tile_t &tile, int16_t monster_hp, uint32_t move_bits
             inventoryItemCopyTo(config::dungeon::objects::OBJ_OPEN_DOOR, item);
 
             // 50% chance of breaking door
-            item.misc_use = (int16_t) (1 - randomNumber(2));
+            item.misc_use = (int16_t)(1 - randomNumber(2));
             tile.feature_id = TILE_CORR_FLOOR;
-            dungeonLiteSpot(Coord_t{y, x});
+            dungeonLiteSpot(coord);
             printMessage("You hear a door burst open!");
             playerDisturb(1, 0);
         }
     }
 }
 
-static void glyphOfWardingProtection(uint16_t creature_id, uint32_t move_bits, bool &do_move, bool &do_turn, int y, int x) {
+static void glyphOfWardingProtection(uint16_t creature_id, uint32_t move_bits, bool &do_move, bool &do_turn, Coord_t coord) {
     if (randomNumber(config::treasure::OBJECTS_RUNE_PROTECTION) < creatures_list[creature_id].level) {
-        if (y == py.row && x == py.col) {
+        if (coord.y == py.pos.y && coord.x == py.pos.x) {
             printMessage("The rune of protection is broken!");
         }
-        (void) dungeonDeleteObject(Coord_t{y, x});;
+        (void) dungeonDeleteObject(coord);
         return;
     }
 
@@ -558,7 +560,7 @@ static void glyphOfWardingProtection(uint16_t creature_id, uint32_t move_bits, b
     }
 }
 
-static void monsterMovesOnPlayer(Monster_t const &monster, uint8_t creature_id, int monster_id, uint32_t move_bits, bool &do_move, bool &do_turn, uint32_t &rcmove, int y, int x) {
+static void monsterMovesOnPlayer(Monster_t const &monster, uint8_t creature_id, int monster_id, uint32_t move_bits, bool &do_move, bool &do_turn, uint32_t &rcmove, Coord_t coord) {
     if (creature_id == 1) {
         // if the monster is not lit, must call monsterUpdateVisibility, it
         // may be faster than character, and hence could have
@@ -569,11 +571,12 @@ static void monsterMovesOnPlayer(Monster_t const &monster, uint8_t creature_id,
         monsterAttackPlayer(monster_id);
         do_move = false;
         do_turn = true;
-    } else if (creature_id > 1 && (y != monster.y || x != monster.x)) {
+    } else if (creature_id > 1 && (coord.y != monster.pos.y || coord.x != monster.pos.x)) {
         // Creature is attempting to move on other creature?
 
         // Creature eats other creatures?
-        if (((move_bits & config::monsters::move::CM_EATS_OTHER) != 0u) && creatures_list[monster.creature_id].kill_exp_value >= creatures_list[monsters[creature_id].creature_id].kill_exp_value) {
+        if (((move_bits & config::monsters::move::CM_EATS_OTHER) != 0u) &&
+            creatures_list[monster.creature_id].kill_exp_value >= creatures_list[monsters[creature_id].creature_id].kill_exp_value) {
             if (monsters[creature_id].lit) {
                 rcmove |= config::monsters::move::CM_EATS_OTHER;
             }
@@ -593,28 +596,28 @@ static void monsterMovesOnPlayer(Monster_t const &monster, uint8_t creature_id,
     }
 }
 
-static void monsterAllowedToMove(Monster_t &monster, uint32_t move_bits, bool &do_turn, uint32_t &rcmove, int y, int x) {
+static void monsterAllowedToMove(Monster_t &monster, uint32_t move_bits, bool &do_turn, uint32_t &rcmove, Coord_t coord) {
     // Pick up or eat an object
     if ((move_bits & config::monsters::move::CM_PICKS_UP) != 0u) {
-        uint8_t treasure_id = dg.floor[y][x].treasure_id;
+        uint8_t treasure_id = dg.floor[coord.y][coord.x].treasure_id;
 
-        if (treasure_id != 0 && treasure_list[treasure_id].category_id <= TV_MAX_OBJECT) {
+        if (treasure_id != 0 && game.treasure.list[treasure_id].category_id <= TV_MAX_OBJECT) {
             rcmove |= config::monsters::move::CM_PICKS_UP;
-            (void) dungeonDeleteObject(Coord_t{y, x});;
+            (void) dungeonDeleteObject(coord);
         }
     }
 
     // Move creature record
-    dungeonMoveCreatureRecord(Coord_t{monster.y, monster.x}, Coord_t{y, x});
+    dungeonMoveCreatureRecord(Coord_t{monster.pos.y, monster.pos.x}, coord);
 
     if (monster.lit) {
         monster.lit = false;
-        dungeonLiteSpot(Coord_t{monster.y, monster.x});
+        dungeonLiteSpot(Coord_t{monster.pos.y, monster.pos.x});
     }
 
-    monster.y = (uint8_t) y;
-    monster.x = (uint8_t) x;
-    monster.distance_from_player = (uint8_t) coordDistanceBetween(Coord_t{py.row, py.col}, Coord_t{y, x});
+    monster.pos.y = coord.y;
+    monster.pos.x = coord.x;
+    monster.distance_from_player = (uint8_t) coordDistanceBetween(py.pos, coord);
 
     do_turn = true;
 }
@@ -628,13 +631,15 @@ static void makeMove(int monster_id, int *directions, uint32_t &rcmove) {
     uint32_t move_bits = creatures_list[monster.creature_id].movement;
 
     // Up to 5 attempts at moving, give up.
+    Coord_t coord = Coord_t{0, 0};
     for (int i = 0; !do_turn && i < 5; i++) {
         // Get new position
-        int y = monster.y;
-        int x = monster.x;
-        (void) playerMovePosition(directions[i], y, x);
+        coord.y = monster.pos.y;
+        coord.x = monster.pos.x;
 
-        Tile_t &tile = dg.floor[y][x];
+        (void) playerMovePosition(directions[i], coord);
+
+        Tile_t &tile = dg.floor[coord.y][coord.x];
 
         if (tile.feature_id == TILE_BOUNDARY_WALL) {
             continue;
@@ -649,22 +654,22 @@ static void makeMove(int monster_id, int *directions, uint32_t &rcmove) {
             rcmove |= config::monsters::move::CM_PHASE;
         } else if (tile.treasure_id != 0) {
             // Creature can open doors?
-            monsterOpenDoor(tile, monster.hp, move_bits, do_turn, do_move, rcmove, y, x);
+            monsterOpenDoor(tile, monster.hp, move_bits, do_turn, do_move, rcmove, coord);
         }
 
         // Glyph of warding present?
-        if (do_move && tile.treasure_id != 0 && treasure_list[tile.treasure_id].category_id == TV_VIS_TRAP && treasure_list[tile.treasure_id].sub_category_id == 99) {
-            glyphOfWardingProtection(monster.creature_id, move_bits, do_move, do_turn, y, x);
+        if (do_move && tile.treasure_id != 0 && game.treasure.list[tile.treasure_id].category_id == TV_VIS_TRAP && game.treasure.list[tile.treasure_id].sub_category_id == 99) {
+            glyphOfWardingProtection(monster.creature_id, move_bits, do_move, do_turn, coord);
         }
 
         // Creature has attempted to move on player?
         if (do_move) {
-            monsterMovesOnPlayer(monster, tile.creature_id, monster_id, move_bits, do_move, do_turn, rcmove, y, x);
+            monsterMovesOnPlayer(monster, tile.creature_id, monster_id, move_bits, do_move, do_turn, rcmove, coord);
         }
 
         // Creature has been allowed move.
         if (do_move) {
-            monsterAllowedToMove(monster, move_bits, do_turn, rcmove, y, x);
+            monsterAllowedToMove(monster, move_bits, do_turn, rcmove, coord);
         }
     }
 }
@@ -679,13 +684,13 @@ static bool monsterCanCastSpells(Monster_t const &monster, uint32_t spells) {
     bool within_range = monster.distance_from_player <= config::monsters::MON_MAX_SPELL_CAST_DISTANCE;
 
     // Must have unobstructed Line-Of-Sight
-    bool unobstructed = los(py.row, py.col, monster.y, monster.x);
+    bool unobstructed = los(py.pos, monster.pos);
 
     return within_range && unobstructed;
 }
 
 void monsterExecuteCastingOfSpell(Monster_t &monster, int monster_id, int spell_id, uint8_t level, vtype_t monster_name, vtype_t death_description) {
-    int y, x;
+    Coord_t coord = py.pos; //  only used for cases 14 and 15.
 
     // Cast the spell.
     switch (spell_id) {
@@ -696,7 +701,7 @@ void monsterExecuteCastingOfSpell(Monster_t &monster, int monster_id, int spell_
             spellTeleportAwayMonster(monster_id, config::monsters::MON_MAX_SIGHT);
             break;
         case 7: // Teleport To
-            spellTeleportPlayerTo((int) monster.y, (int) monster.x);
+            spellTeleportPlayerTo(Coord_t{monster.pos.y, monster.pos.x});
             break;
         case 8: // Light Wound
             if (playerSavingThrow()) {
@@ -720,7 +725,7 @@ void monsterExecuteCastingOfSpell(Monster_t &monster, int monster_id, int spell_
             } else if (py.flags.paralysis > 0) {
                 py.flags.paralysis += 2;
             } else {
-                py.flags.paralysis = (int16_t) (randomNumber(5) + 4);
+                py.flags.paralysis = (int16_t)(randomNumber(5) + 4);
             }
             break;
         case 11: // Cause Blindness
@@ -738,7 +743,7 @@ void monsterExecuteCastingOfSpell(Monster_t &monster, int monster_id, int spell_
             } else if (py.flags.confused > 0) {
                 py.flags.confused += 2;
             } else {
-                py.flags.confused = (int16_t) (randomNumber(5) + 3);
+                py.flags.confused = (int16_t)(randomNumber(5) + 3);
             }
             break;
         case 13: // Cause Fear
@@ -747,32 +752,32 @@ void monsterExecuteCastingOfSpell(Monster_t &monster, int monster_id, int spell_
             } else if (py.flags.afraid > 0) {
                 py.flags.afraid += 2;
             } else {
-                py.flags.afraid = (int16_t) (randomNumber(5) + 3);
+                py.flags.afraid = (int16_t)(randomNumber(5) + 3);
             }
             break;
         case 14: // Summon Monster
             (void) strcat(monster_name, "magically summons a monster!");
             printMessage(monster_name);
-            y = py.row;
-            x = py.col;
+            coord.y = py.pos.y;
+            coord.x = py.pos.x;
 
             // in case compact_monster() is called,it needs monster_id
             hack_monptr = monster_id;
-            (void) monsterSummon(y, x, false);
+            (void) monsterSummon(coord, false);
             hack_monptr = -1;
-            monsterUpdateVisibility((int) dg.floor[y][x].creature_id);
+            monsterUpdateVisibility((int) dg.floor[coord.y][coord.x].creature_id);
             break;
         case 15: // Summon Undead
             (void) strcat(monster_name, "magically summons an undead!");
             printMessage(monster_name);
-            y = py.row;
-            x = py.col;
+            coord.y = py.pos.y;
+            coord.x = py.pos.x;
 
             // in case compact_monster() is called,it needs monster_id
             hack_monptr = monster_id;
-            (void) monsterSummonUndead(y, x);
+            (void) monsterSummonUndead(coord);
             hack_monptr = -1;
-            monsterUpdateVisibility((int) dg.floor[y][x].creature_id);
+            monsterUpdateVisibility((int) dg.floor[coord.y][coord.x].creature_id);
             break;
         case 16: // Slow Person
             if (py.flags.free_action) {
@@ -782,7 +787,7 @@ void monsterExecuteCastingOfSpell(Monster_t &monster, int monster_id, int spell_
             } else if (py.flags.slow > 0) {
                 py.flags.slow += 2;
             } else {
-                py.flags.slow = (int16_t) (randomNumber(5) + 3);
+                py.flags.slow = (int16_t)(randomNumber(5) + 3);
             }
             break;
         case 17: // Drain Mana
@@ -798,42 +803,42 @@ void monsterExecuteCastingOfSpell(Monster_t &monster, int monster_id, int spell_
                     printMessage(msg);
                 }
 
-                int r1 = (randomNumber((int) level) >> 1) + 1;
-                if (r1 > py.misc.current_mana) {
-                    r1 = py.misc.current_mana;
+                int num = (randomNumber((int) level) >> 1) + 1;
+                if (num > py.misc.current_mana) {
+                    num = py.misc.current_mana;
                     py.misc.current_mana = 0;
                     py.misc.current_mana_fraction = 0;
                 } else {
-                    py.misc.current_mana -= r1;
+                    py.misc.current_mana -= num;
                 }
                 printCharacterCurrentMana();
-                monster.hp += 6 * (r1);
+                monster.hp += 6 * (num);
             }
             break;
         case 20: // Breath Light
             (void) strcat(monster_name, "breathes lightning.");
             printMessage(monster_name);
-            spellBreath(py.row, py.col, monster_id, (monster.hp / 4), magic_spell_flags::GF_LIGHTNING, death_description);
+            spellBreath(py.pos, monster_id, (monster.hp / 4), MagicSpellFlags::Lightning, death_description);
             break;
         case 21: // Breath Gas
             (void) strcat(monster_name, "breathes gas.");
             printMessage(monster_name);
-            spellBreath(py.row, py.col, monster_id, (monster.hp / 3), magic_spell_flags::GF_POISON_GAS, death_description);
+            spellBreath(py.pos, monster_id, (monster.hp / 3), MagicSpellFlags::PoisonGas, death_description);
             break;
         case 22: // Breath Acid
             (void) strcat(monster_name, "breathes acid.");
             printMessage(monster_name);
-            spellBreath(py.row, py.col, monster_id, (monster.hp / 3), magic_spell_flags::GF_ACID, death_description);
+            spellBreath(py.pos, monster_id, (monster.hp / 3), MagicSpellFlags::Acid, death_description);
             break;
         case 23: // Breath Frost
             (void) strcat(monster_name, "breathes frost.");
             printMessage(monster_name);
-            spellBreath(py.row, py.col, monster_id, (monster.hp / 3), magic_spell_flags::GF_FROST, death_description);
+            spellBreath(py.pos, monster_id, (monster.hp / 3), MagicSpellFlags::Frost, death_description);
             break;
         case 24: // Breath Fire
             (void) strcat(monster_name, "breathes fire.");
             printMessage(monster_name);
-            spellBreath(py.row, py.col, monster_id, (monster.hp / 3), magic_spell_flags::GF_FIRE, death_description);
+            spellBreath(py.pos, monster_id, (monster.hp / 3), MagicSpellFlags::Fire, death_description);
             break;
         default:
             (void) strcat(monster_name, "cast unknown spell.");
@@ -874,7 +879,7 @@ static bool monsterCastSpell(int monster_id) {
 
     // Extract all possible spells into spell_choice
     int spell_choice[30];
-    auto spell_flags = (uint32_t) (creature.spells & ~config::monsters::spells::CS_FREQ);
+    auto spell_flags = (uint32_t)(creature.spells & ~config::monsters::spells::CS_FREQ);
 
     int id = 0;
     while (spell_flags != 0) {
@@ -904,7 +909,7 @@ static bool monsterCastSpell(int monster_id) {
         if ((creature_recall[monster.creature_id].spells & config::monsters::spells::CS_FREQ) != config::monsters::spells::CS_FREQ) {
             creature_recall[monster.creature_id].spells++;
         }
-        if (game.character_is_dead && creature_recall[monster.creature_id].deaths < MAX_SHORT) {
+        if (game.character_is_dead && creature_recall[monster.creature_id].deaths < SHRT_MAX) {
             creature_recall[monster.creature_id].deaths++;
         }
     }
@@ -914,15 +919,17 @@ static bool monsterCastSpell(int monster_id) {
 
 // Places creature adjacent to given location -RAK-
 // Rats and Flys are fun!
-bool monsterMultiply(int y, int x, int creature_id, int monster_id) {
+bool monsterMultiply(Coord_t coord, int creature_id, int monster_id) {
+    Coord_t position = Coord_t{0, 0};
+
     for (int i = 0; i <= 18; i++) {
-        int pos_y = y - 2 + randomNumber(3);
-        int pos_x = x - 2 + randomNumber(3);
+        position.y = coord.y - 2 + randomNumber(3);
+        position.x = coord.x - 2 + randomNumber(3);
 
         // don't create a new creature on top of the old one, that
         // causes invincible/invisible creatures to appear.
-        if (coordInBounds(Coord_t{pos_y, pos_x}) && (pos_y != y || pos_x != x)) {
-            Tile_t const &tile = dg.floor[pos_y][pos_x];
+        if (coordInBounds(position) && (position.y != coord.y || position.x != coord.x)) {
+            Tile_t const &tile = dg.floor[position.y][position.x];
 
             if (tile.feature_id <= MAX_OPEN_SPACE && tile.treasure_id == 0 && tile.creature_id != 1) {
                 // Creature there already?
@@ -947,14 +954,14 @@ bool monsterMultiply(int y, int x, int creature_id, int monster_id) {
                         // in case compact_monster() is called, it needs monster_id.
                         hack_monptr = monster_id;
                         // Place_monster() may fail if monster list full.
-                        bool result = monsterPlaceNew(pos_y, pos_x, creature_id, false);
+                        bool result = monsterPlaceNew(position, creature_id, false);
                         hack_monptr = -1;
                         if (!result) {
                             return false;
                         }
 
                         monster_multiply_total++;
-                        return monsterMakeVisible(pos_y, pos_x);
+                        return monsterMakeVisible(position);
                     }
                 } else {
                     // All clear,  place a monster
@@ -962,14 +969,14 @@ bool monsterMultiply(int y, int x, int creature_id, int monster_id) {
                     // in case compact_monster() is called,it needs monster_id
                     hack_monptr = monster_id;
                     // Place_monster() may fail if monster list full.
-                    bool result = monsterPlaceNew(pos_y, pos_x, creature_id, false);
+                    bool result = monsterPlaceNew(position, creature_id, false);
                     hack_monptr = -1;
                     if (!result) {
                         return false;
                     }
 
                     monster_multiply_total++;
-                    return monsterMakeVisible(pos_y, pos_x);
+                    return monsterMakeVisible(position);
                 }
             }
         }
@@ -981,9 +988,11 @@ bool monsterMultiply(int y, int x, int creature_id, int monster_id) {
 static void monsterMultiplyCritter(Monster_t const &monster, int monster_id, uint32_t &rcmove) {
     int counter = 0;
 
-    for (int y = monster.y - 1; y <= monster.y + 1; y++) {
-        for (int x = monster.x - 1; x <= monster.x + 1; x++) {
-            if (coordInBounds(Coord_t{y, x}) && (dg.floor[y][x].creature_id > 1)) {
+    Coord_t coord = Coord_t{0, 0};
+
+    for (coord.y = monster.pos.y - 1; coord.y <= monster.pos.y + 1; coord.y++) {
+        for (coord.x = monster.pos.x - 1; coord.x <= monster.pos.x + 1; coord.x++) {
+            if (coordInBounds(coord) && (dg.floor[coord.y][coord.x].creature_id > 1)) {
                 counter++;
             }
         }
@@ -996,7 +1005,7 @@ static void monsterMultiplyCritter(Monster_t const &monster, int monster_id, uin
     }
 
     if (counter < 4 && randomNumber(counter * config::monsters::MON_MULTIPLY_ADJUST) == 1) {
-        if (monsterMultiply(monster.y, monster.x, monster.creature_id, monster_id)) {
+        if (monsterMultiply(Coord_t{monster.pos.y, monster.pos.x}, monster.creature_id, monster_id)) {
             rcmove |= config::monsters::move::CM_MULTIPLY;
         }
     }
@@ -1019,10 +1028,11 @@ static void monsterMoveOutOfWall(Monster_t const &monster, int monster_id, uint3
     // Do not allow attack against the player.
     // Must cast y-1 to signed int, so that a negative value
     // of i will fail the comparison.
-    for (int y = monster.y + 1; y >= (monster.y - 1); y--) {
-        for (int x = monster.x - 1; x <= monster.x + 1; x++) {
+    for (int y = monster.pos.y + 1; y >= (monster.pos.y - 1); y--) {
+        for (int x = monster.pos.x - 1; x <= monster.pos.x + 1; x++) {
             if (dir != 5 && dg.floor[y][x].feature_id <= MAX_OPEN_SPACE && dg.floor[y][x].creature_id != 1) {
-                directions[id++] = dir;
+                directions[id] = dir;
+                id++;
             }
             dir++;
         }
@@ -1042,7 +1052,7 @@ static void monsterMoveOutOfWall(Monster_t const &monster, int monster_id, uint3
     }
 
     // if still in a wall, let it dig itself out, but also apply some more damage
-    if (dg.floor[monster.y][monster.x].feature_id >= MIN_CAVE_WALL) {
+    if (dg.floor[monster.pos.y][monster.pos.x].feature_id >= MIN_CAVE_WALL) {
         // in case the monster dies, may need to callfix1_delete_monster()
         // instead of delete_monsters()
         hack_monptr = monster_id;
@@ -1054,7 +1064,7 @@ static void monsterMoveOutOfWall(Monster_t const &monster, int monster_id, uint3
             displayCharacterExperience();
         } else {
             printMessage("A creature digs itself out from the rock!");
-            (void) playerTunnelWall((int) monster.y, (int) monster.x, 1, 0);
+            (void) playerTunnelWall(Coord_t{monster.pos.y, monster.pos.x}, 1, 0);
         }
     }
 }
@@ -1164,13 +1174,14 @@ static void monsterMove(int monster_id, uint32_t &rcmove) {
     // Does the critter multiply?
     // rest could be negative, to be safe, only use mod with positive values.
     auto abs_rest_period = (int) std::abs((std::intmax_t) py.flags.rest);
-    if (((creature.movement & config::monsters::move::CM_MULTIPLY) != 0u) && config::monsters::MON_MAX_MULTIPLY_PER_LEVEL >= monster_multiply_total && (abs_rest_period % config::monsters::MON_MULTIPLY_ADJUST) == 0) {
+    if (((creature.movement & config::monsters::move::CM_MULTIPLY) != 0u) && config::monsters::MON_MAX_MULTIPLY_PER_LEVEL >= monster_multiply_total &&
+        (abs_rest_period % config::monsters::MON_MULTIPLY_ADJUST) == 0) {
         monsterMultiplyCritter(monster, monster_id, rcmove);
     }
 
     // if in wall, must immediately escape to a clear area
     // then monster movement finished
-    if (((creature.movement & config::monsters::move::CM_PHASE) == 0u) && dg.floor[monster.y][monster.x].feature_id >= MIN_CAVE_WALL) {
+    if (((creature.movement & config::monsters::move::CM_PHASE) == 0u) && dg.floor[monster.pos.y][monster.pos.x].feature_id >= MIN_CAVE_WALL) {
         monsterMoveOutOfWall(monster, monster_id, rcmove);
         return;
     }
@@ -1212,7 +1223,7 @@ static void monsterMove(int monster_id, uint32_t &rcmove) {
     if (((creature.movement & config::monsters::move::CM_ONLY_MAGIC) != 0u) && monster.distance_from_player < 2) {
         // A little hack for Quylthulgs, so that one will eventually
         // notice that they have no physical attacks.
-        if (creature_recall[monster.creature_id].attacks[0] < MAX_UCHAR) {
+        if (creature_recall[monster.creature_id].attacks[0] < UCHAR_MAX) {
             creature_recall[monster.creature_id].attacks[0]++;
         }
 
@@ -1224,7 +1235,7 @@ static void monsterMove(int monster_id, uint32_t &rcmove) {
     }
 }
 
-static void memoryUpdateRecall(Monster_t const &monster, bool wake, bool ignore, int rcmove) {
+static void memoryUpdateRecall(Monster_t const &monster, bool wake, bool ignore, uint32_t rcmove) {
     if (!monster.lit) {
         return;
     }
@@ -1232,11 +1243,11 @@ static void memoryUpdateRecall(Monster_t const &monster, bool wake, bool ignore,
     Recall_t &memory = creature_recall[monster.creature_id];
 
     if (wake) {
-        if (memory.wake < MAX_UCHAR) {
+        if (memory.wake < UCHAR_MAX) {
             memory.wake++;
         }
     } else if (ignore) {
-        if (memory.ignore < MAX_UCHAR) {
+        if (memory.ignore < UCHAR_MAX) {
             memory.ignore++;
         }
     }
@@ -1253,7 +1264,8 @@ static void monsterAttackingUpdate(Monster_t &monster, int monster_id, int moves
 
         // Monsters trapped in rock must be given a turn also,
         // so that they will die/dig out immediately.
-        if (monster.lit || monster.distance_from_player <= creatures_list[monster.creature_id].area_affect_radius || (((creatures_list[monster.creature_id].movement & config::monsters::move::CM_PHASE) == 0u) && dg.floor[monster.y][monster.x].feature_id >= MIN_CAVE_WALL)) {
+        if (monster.lit || monster.distance_from_player <= creatures_list[monster.creature_id].area_affect_radius ||
+            (((creatures_list[monster.creature_id].movement & config::monsters::move::CM_PHASE) == 0u) && dg.floor[monster.pos.y][monster.pos.x].feature_id >= MIN_CAVE_WALL)) {
             if (monster.sleep_count > 0) {
                 if (py.flags.aggravate) {
                     monster.sleep_count = 0;
@@ -1314,7 +1326,7 @@ void updateMonsters(bool attack) {
             continue;
         }
 
-        monster.distance_from_player = (uint8_t) coordDistanceBetween(Coord_t{py.row, py.col}, Coord_t{monster.y, monster.x});
+        monster.distance_from_player = (uint8_t) coordDistanceBetween(py.pos, Coord_t{monster.pos.y, monster.pos.x});
 
         // Attack is argument passed to CREATURE
         if (attack) {
@@ -1352,20 +1364,20 @@ int monsterTakeHit(int monster_id, int damage) {
         return -1;
     }
 
-    uint32_t treasure_flags = monsterDeath((int) monster.y, (int) monster.x, creature.movement);
+    uint32_t treasure_flags = monsterDeath(Coord_t{monster.pos.y, monster.pos.x}, creature.movement);
 
     Recall_t &memory = creature_recall[monster.creature_id];
 
     if ((py.flags.blind < 1 && monster.lit) || ((creature.movement & config::monsters::move::CM_WIN) != 0u)) {
-        auto tmp = (uint32_t) ((memory.movement & config::monsters::move::CM_TREASURE) >> config::monsters::move::CM_TR_SHIFT);
+        auto tmp = (uint32_t)((memory.movement & config::monsters::move::CM_TREASURE) >> config::monsters::move::CM_TR_SHIFT);
 
         if (tmp > ((treasure_flags & config::monsters::move::CM_TREASURE) >> config::monsters::move::CM_TR_SHIFT)) {
-            treasure_flags = (uint32_t) ((treasure_flags & ~config::monsters::move::CM_TREASURE) | (tmp << config::monsters::move::CM_TR_SHIFT));
+            treasure_flags = (uint32_t)((treasure_flags & ~config::monsters::move::CM_TREASURE) | (tmp << config::monsters::move::CM_TR_SHIFT));
         }
 
-        memory.movement = (uint32_t) ((memory.movement & ~config::monsters::move::CM_TREASURE) | treasure_flags);
+        memory.movement = (uint32_t)((memory.movement & ~config::monsters::move::CM_TREASURE) | treasure_flags);
 
-        if (memory.kills < MAX_SHORT) {
+        if (memory.kills < SHRT_MAX) {
             memory.kills++;
         }
     }
@@ -1439,14 +1451,14 @@ static int monsterDeathItemDropCount(uint32_t flags) {
 //
 // Returns a mask of bits from the given flags which indicates what the
 // monster is seen to have dropped.  This may be added to monster memory.
-uint32_t monsterDeath(int y, int x, uint32_t flags) {
+uint32_t monsterDeath(Coord_t coord, uint32_t flags) {
     int item_type = monsterDeathItemDropType(flags);
     int item_count = monsterDeathItemDropCount(flags);
 
     uint32_t dropped_item_id = 0;
 
     if (item_count > 0) {
-        dropped_item_id = (uint32_t) dungeonSummonObject(Coord_t{y, x}, item_count, item_type);
+        dropped_item_id = (uint32_t) dungeonSummonObject(coord, item_count, item_type);
     }
 
     // maybe the player died in mid-turn
@@ -1495,12 +1507,12 @@ std::string monsterNameDescription(const std::string &real_name, bool is_lit) {
 }
 
 // Sleep creatures adjacent to player -RAK-
-bool monsterSleep(int y, int x) {
+bool monsterSleep(Coord_t coord) {
     bool asleep = false;
 
-    for (int row = y - 1; row <= y + 1 && row < MAX_HEIGHT; row++) {
-        for (int col = x - 1; col <= x + 1 && col < MAX_WIDTH; col++) {
-            uint8_t monster_id = dg.floor[row][col].creature_id;
+    for (int y = coord.y - 1; y <= coord.y + 1 && y < MAX_HEIGHT; y++) {
+        for (int x = coord.x - 1; x <= coord.x + 1 && x < MAX_WIDTH; x++) {
+            uint8_t monster_id = dg.floor[y][x].creature_id;
 
             if (monster_id <= 1) {
                 continue;
@@ -1546,7 +1558,7 @@ static bool executeAttackOnPlayer(uint8_t creature_level, int16_t &monster_hp, i
                 printMessage("You feel weaker for a moment, but it passes.");
             } else if (randomNumber(2) == 1) {
                 printMessage("You feel weaker.");
-                (void) playerStatRandomDecrease(py_attrs::A_STR);
+                (void) playerStatRandomDecrease(PlayerAttr::A_STR);
             } else {
                 noticed = false;
             }
@@ -1616,7 +1628,7 @@ static bool executeAttackOnPlayer(uint8_t creature_level, int16_t &monster_hp, i
                 if (py.flags.free_action) {
                     printMessage("You are unaffected.");
                 } else {
-                    py.flags.paralysis = (int16_t) (randomNumber((int) creature_level) + 3);
+                    py.flags.paralysis = (int16_t)(randomNumber((int) creature_level) + 3);
                     printMessage("You are paralyzed.");
                 }
             } else {
@@ -1624,7 +1636,7 @@ static bool executeAttackOnPlayer(uint8_t creature_level, int16_t &monster_hp, i
             }
             break;
         case 12: // Steal Money
-            if (py.flags.paralysis < 1 && randomNumber(124) < py.stats.used[py_attrs::A_DEX]) {
+            if (py.flags.paralysis < 1 && randomNumber(124) < py.stats.used[PlayerAttr::A_DEX]) {
                 printMessage("You quickly protect your money pouch!");
             } else {
                 gold = (py.misc.au / 10) + randomNumber(25);
@@ -1642,10 +1654,10 @@ static bool executeAttackOnPlayer(uint8_t creature_level, int16_t &monster_hp, i
             }
             break;
         case 13: // Steal Object
-            if (py.flags.paralysis < 1 && randomNumber(124) < py.stats.used[py_attrs::A_DEX]) {
+            if (py.flags.paralysis < 1 && randomNumber(124) < py.stats.used[PlayerAttr::A_DEX]) {
                 printMessage("You grab hold of your backpack!");
             } else {
-                inventoryDestroyItem(randomNumber(py.unique_inventory_items) - 1);
+                inventoryDestroyItem(randomNumber(py.pack.unique_items) - 1);
                 printMessage("Your backpack feels lighter.");
             }
             if (randomNumber(2) == 1) {
@@ -1664,7 +1676,7 @@ static bool executeAttackOnPlayer(uint8_t creature_level, int16_t &monster_hp, i
                 printMessage("You feel clumsy for a moment, but it passes.");
             } else {
                 printMessage("You feel more clumsy.");
-                (void) playerStatRandomDecrease(py_attrs::A_DEX);
+                (void) playerStatRandomDecrease(PlayerAttr::A_DEX);
             }
             break;
         case 16: // Lose constitution
@@ -1673,7 +1685,7 @@ static bool executeAttackOnPlayer(uint8_t creature_level, int16_t &monster_hp, i
                 printMessage("Your body resists the effects of the disease.");
             } else {
                 printMessage("Your health is damaged!");
-                (void) playerStatRandomDecrease(py_attrs::A_CON);
+                (void) playerStatRandomDecrease(PlayerAttr::A_CON);
             }
             break;
         case 17: // Lose intelligence
@@ -1682,7 +1694,7 @@ static bool executeAttackOnPlayer(uint8_t creature_level, int16_t &monster_hp, i
             if (py.flags.sustain_int) {
                 printMessage("But your mind quickly clears.");
             } else {
-                (void) playerStatRandomDecrease(py_attrs::A_INT);
+                (void) playerStatRandomDecrease(PlayerAttr::A_INT);
             }
             break;
         case 18: // Lose wisdom
@@ -1691,7 +1703,7 @@ static bool executeAttackOnPlayer(uint8_t creature_level, int16_t &monster_hp, i
                 printMessage("Your wisdom is sustained.");
             } else {
                 printMessage("Your wisdom is drained.");
-                (void) playerStatRandomDecrease(py_attrs::A_WIS);
+                (void) playerStatRandomDecrease(PlayerAttr::A_WIS);
             }
             break;
         case 19: // Lose experience
@@ -1723,9 +1735,10 @@ static bool executeAttackOnPlayer(uint8_t creature_level, int16_t &monster_hp, i
         case 24: // Eat charges
             noticed = inventoryDiminishChargesAttack(creature_level, monster_hp, noticed);
             break;
-        case 99:
-            noticed = false;
-            break;
+            // NOTE: default handles this case
+            // case 99:
+            //     noticed = false;
+            //     break;
         default:
             noticed = false;
             break;
