@@ -13,9 +13,6 @@
 // Player record for most player related info
 Player_t py = Player_t{};
 
-// Handle teleport traps
-bool teleport_player;
-
 static void playerResetFlags() {
     py.flags.see_invisible = false;
     py.flags.teleport = false;
@@ -52,58 +49,56 @@ const char *playerGetGenderLabel() {
 }
 
 // Given direction "dir", returns new row, column location -RAK-
-bool playerMovePosition(int dir, int &new_y, int &new_x) {
-    int new_row;
-    int new_col;
+bool playerMovePosition(int dir, Coord_t &coord) {
+    Coord_t new_coord = Coord_t{0, 0};
 
     switch (dir) {
         case 1:
-            new_row = new_y + 1;
-            new_col = new_x - 1;
+            new_coord.y = coord.y + 1;
+            new_coord.x = coord.x - 1;
             break;
         case 2:
-            new_row = new_y + 1;
-            new_col = new_x;
+            new_coord.y = coord.y + 1;
+            new_coord.x = coord.x;
             break;
         case 3:
-            new_row = new_y + 1;
-            new_col = new_x + 1;
+            new_coord.y = coord.y + 1;
+            new_coord.x = coord.x + 1;
             break;
         case 4:
-            new_row = new_y;
-            new_col = new_x - 1;
+            new_coord.y = coord.y;
+            new_coord.x = coord.x - 1;
             break;
         case 5:
-            new_row = new_y;
-            new_col = new_x;
+            new_coord.y = coord.y;
+            new_coord.x = coord.x;
             break;
         case 6:
-            new_row = new_y;
-            new_col = new_x + 1;
+            new_coord.y = coord.y;
+            new_coord.x = coord.x + 1;
             break;
         case 7:
-            new_row = new_y - 1;
-            new_col = new_x - 1;
+            new_coord.y = coord.y - 1;
+            new_coord.x = coord.x - 1;
             break;
         case 8:
-            new_row = new_y - 1;
-            new_col = new_x;
+            new_coord.y = coord.y - 1;
+            new_coord.x = coord.x;
             break;
         case 9:
-            new_row = new_y - 1;
-            new_col = new_x + 1;
+            new_coord.y = coord.y - 1;
+            new_coord.x = coord.x + 1;
             break;
         default:
-            new_row = 0;
-            new_col = 0;
+            new_coord.y = 0;
+            new_coord.x = 0;
             break;
     }
 
     bool can_move = false;
 
-    if (new_row >= 0 && new_row < dg.height && new_col >= 0 && new_col < dg.width) {
-        new_y = new_row;
-        new_x = new_col;
+    if (new_coord.y >= 0 && new_coord.y < dg.height && new_coord.x >= 0 && new_coord.x < dg.width) {
+        coord = new_coord;
         can_move = true;
     }
 
@@ -112,41 +107,42 @@ bool playerMovePosition(int dir, int &new_y, int &new_x) {
 
 // Teleport the player to a new location -RAK-
 void playerTeleport(int new_distance) {
-    int new_y, new_x;
+    Coord_t location = Coord_t{0, 0};
 
     do {
-        new_y = randomNumber(dg.height) - 1;
-        new_x = randomNumber(dg.width) - 1;
+        location.y = randomNumber(dg.height) - 1;
+        location.x = randomNumber(dg.width) - 1;
 
-        while (coordDistanceBetween(Coord_t{new_y, new_x}, Coord_t{py.row, py.col}) > new_distance) {
-            new_y += (py.row - new_y) / 2;
-            new_x += (py.col - new_x) / 2;
+        while (coordDistanceBetween(location, py.pos) > new_distance) {
+            location.y += (py.pos.y - location.y) / 2;
+            location.x += (py.pos.x - location.x) / 2;
         }
-    } while (dg.floor[new_y][new_x].feature_id >= MIN_CLOSED_SPACE || dg.floor[new_y][new_x].creature_id >= 2);
+    } while (dg.floor[location.y][location.x].feature_id >= MIN_CLOSED_SPACE || dg.floor[location.y][location.x].creature_id >= 2);
 
-    dungeonMoveCreatureRecord(Coord_t{py.row, py.col}, Coord_t{new_y, new_x});
+    dungeonMoveCreatureRecord(py.pos, location);
 
-    for (int y = py.row - 1; y <= py.row + 1; y++) {
-        for (int x = py.col - 1; x <= py.col + 1; x++) {
-            dg.floor[y][x].temporary_light = false;
-            dungeonLiteSpot(Coord_t{y, x});
+    Coord_t spot = Coord_t{0, 0};
+    for (spot.y = py.pos.y - 1; spot.y <= py.pos.y + 1; spot.y++) {
+        for (spot.x = py.pos.x - 1; spot.x <= py.pos.x + 1; spot.x++) {
+            dg.floor[spot.y][spot.x].temporary_light = false;
+            dungeonLiteSpot(spot);
         }
     }
 
-    dungeonLiteSpot(Coord_t{py.row, py.col});
+    dungeonLiteSpot(py.pos);
 
-    py.row = (int16_t) new_y;
-    py.col = (int16_t) new_x;
+    py.pos.y = location.y;
+    py.pos.x = location.x;
 
     dungeonResetView();
     updateMonsters(false);
 
-    teleport_player = false;
+    game.teleport_player = false;
 }
 
 // Returns true if player has no light -RAK-
 bool playerNoLight() {
-    return !dg.floor[py.row][py.col].temporary_light && !dg.floor[py.row][py.col].permanent_light;
+    return !dg.floor[py.pos.y][py.pos.x].temporary_light && !dg.floor[py.pos.y][py.pos.x].permanent_light;
 }
 
 // Something happens to disturb the player. -CJS-
@@ -209,7 +205,7 @@ void playerRestOn() {
 
         if (getStringInput(rest_str, Coord_t{0, 19}, 5)) {
             if (rest_str[0] == '*') {
-                rest_num = -MAX_SHORT;
+                rest_num = -SHRT_MAX;
             } else {
                 (void) stringToNumber(rest_str, rest_num);
             }
@@ -218,7 +214,7 @@ void playerRestOn() {
 
     // check for reasonable value, must be positive number
     // in range of a short, or must be -MAX_SHORT
-    if (rest_num == -MAX_SHORT || (rest_num > 0 && rest_num <= MAX_SHORT)) {
+    if (rest_num == -SHRT_MAX || (rest_num > 0 && rest_num <= SHRT_MAX)) {
         if ((py.flags.status & config::player::status::PY_SEARCH) != 0u) {
             playerSearchOff();
         }
@@ -281,15 +277,7 @@ bool playerTestAttackHits(int attack_id, uint8_t level) {
             }
             break;
         case 3: // Confusion attack
-            if (playerTestBeingHit(10, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
-                success = true;
-            }
-            break;
         case 4: // Fear attack
-            if (playerTestBeingHit(10, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
-                success = true;
-            }
-            break;
         case 5: // Fire attack
             if (playerTestBeingHit(10, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
                 success = true;
@@ -301,10 +289,6 @@ bool playerTestAttackHits(int attack_id, uint8_t level) {
             }
             break;
         case 7: // Cold attack
-            if (playerTestBeingHit(10, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
-                success = true;
-            }
-            break;
         case 8: // Lightning attack
             if (playerTestBeingHit(10, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
                 success = true;
@@ -316,10 +300,6 @@ bool playerTestAttackHits(int attack_id, uint8_t level) {
             }
             break;
         case 10: // Blindness attack
-            if (playerTestBeingHit(2, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
-                success = true;
-            }
-            break;
         case 11: // Paralysis attack
             if (playerTestBeingHit(2, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
                 success = true;
@@ -331,7 +311,7 @@ bool playerTestAttackHits(int attack_id, uint8_t level) {
             }
             break;
         case 13: // Steal Object
-            if (playerTestBeingHit(2, (int) level, 0, (int) py.misc.level, CLASS_MISC_HIT) && py.unique_inventory_items > 0) {
+            if (playerTestBeingHit(2, (int) level, 0, (int) py.misc.level, CLASS_MISC_HIT) && py.pack.unique_items > 0) {
                 success = true;
             }
             break;
@@ -341,20 +321,12 @@ bool playerTestAttackHits(int attack_id, uint8_t level) {
             }
             break;
         case 15: // Lose dexterity
-            if (playerTestBeingHit(0, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
-                success = true;
-            }
-            break;
         case 16: // Lose constitution
             if (playerTestBeingHit(0, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
                 success = true;
             }
             break;
         case 17: // Lose intelligence
-            if (playerTestBeingHit(2, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
-                success = true;
-            }
-            break;
         case 18: // Lose wisdom
             if (playerTestBeingHit(2, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
                 success = true;
@@ -374,10 +346,6 @@ bool playerTestAttackHits(int attack_id, uint8_t level) {
             }
             break;
         case 22: // Eat food
-            if (playerTestBeingHit(5, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
-                success = true;
-            }
-            break;
         case 23: // Eat light
             if (playerTestBeingHit(5, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT)) {
                 success = true;
@@ -385,7 +353,7 @@ bool playerTestAttackHits(int attack_id, uint8_t level) {
             break;
         case 24: // Eat charges
             // check to make sure an object exists
-            if (playerTestBeingHit(15, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT) && py.unique_inventory_items > 0) {
+            if (playerTestBeingHit(15, (int) level, 0, py.misc.ac + py.misc.magical_ac, CLASS_MISC_HIT) && py.pack.unique_items > 0) {
                 success = true;
             }
             break;
@@ -457,8 +425,8 @@ void playerAdjustBonusesForItem(Inventory_t const &item, int factor) {
 }
 
 static void playerRecalculateBonusesFromInventory() {
-    for (int i = player_equipment::EQUIPMENT_WIELD; i < player_equipment::EQUIPMENT_LIGHT; i++) {
-        Inventory_t const &item = inventory[i];
+    for (int i = PlayerEquipment::Wield; i < PlayerEquipment::Light; i++) {
+        Inventory_t const &item = py.inventory[i];
 
         if (item.category_id != TV_NOTHING) {
             py.misc.plusses_to_hit += item.to_hit;
@@ -491,12 +459,12 @@ static void playerRecalculateBonusesFromInventory() {
 }
 
 static void playerRecalculateSustainStatsFromInventory() {
-    for (int i = player_equipment::EQUIPMENT_WIELD; i < player_equipment::EQUIPMENT_LIGHT; i++) {
-        if ((inventory[i].flags & config::treasure::flags::TR_SUST_STAT) == 0u) {
+    for (int i = PlayerEquipment::Wield; i < PlayerEquipment::Light; i++) {
+        if ((py.inventory[i].flags & config::treasure::flags::TR_SUST_STAT) == 0u) {
             continue;
         }
 
-        switch (inventory[i].misc_use) {
+        switch (py.inventory[i].misc_use) {
             case 1:
                 py.flags.sustain_str = true;
                 break;
@@ -531,14 +499,14 @@ void playerRecalculateBonuses() {
         py.flags.food_digested -= 3;
     }
 
-    int savedDisplayAC = py.misc.display_ac;
+    int saved_display_ac = py.misc.display_ac;
 
     playerResetFlags();
 
     // Real values
-    py.misc.plusses_to_hit = (int16_t) playerToHitAdjustment();
-    py.misc.plusses_to_damage = (int16_t) playerDamageAdjustment();
-    py.misc.magical_ac = (int16_t) playerArmorClassAdjustment();
+    py.misc.plusses_to_hit = playerToHitAdjustment();
+    py.misc.plusses_to_damage = playerDamageAdjustment();
+    py.misc.magical_ac = playerArmorClassAdjustment();
     py.misc.ac = 0;
 
     // Display values
@@ -552,7 +520,7 @@ void playerRecalculateBonuses() {
     py.misc.display_ac += py.misc.display_to_ac;
 
     if (py.weapon_is_heavy) {
-        py.misc.display_to_hit += (py.stats.used[py_attrs::A_STR] * 15 - inventory[player_equipment::EQUIPMENT_WIELD].weight);
+        py.misc.display_to_hit += (py.stats.used[PlayerAttr::A_STR] * 15 - py.inventory[PlayerEquipment::Wield].weight);
     }
 
     // Add in temporary spell increases
@@ -571,7 +539,7 @@ void playerRecalculateBonuses() {
     }
 
     // can't print AC here because might be in a store
-    if (savedDisplayAC != py.misc.display_ac) {
+    if (saved_display_ac != py.misc.display_ac) {
         py.flags.status |= config::player::status::PY_ARMOR;
     }
 
@@ -626,15 +594,15 @@ void playerRecalculateBonuses() {
 void playerTakeOff(int item_id, int pack_position_id) {
     py.flags.status |= config::player::status::PY_STR_WGT;
 
-    Inventory_t &item = inventory[item_id];
+    Inventory_t &item = py.inventory[item_id];
 
-    py.inventory_weight -= item.weight * item.items_count;
+    py.pack.weight -= item.weight * item.items_count;
     py.equipment_count--;
 
     const char *p = nullptr;
-    if (item_id == player_equipment::EQUIPMENT_WIELD || item_id == player_equipment::EQUIPMENT_AUX) {
+    if (item_id == PlayerEquipment::Wield || item_id == PlayerEquipment::Auxiliary) {
         p = "Was wielding ";
-    } else if (item_id == player_equipment::EQUIPMENT_LIGHT) {
+    } else if (item_id == PlayerEquipment::Light) {
         p = "Light source was ";
     } else {
         p = "Was wearing ";
@@ -652,7 +620,7 @@ void playerTakeOff(int item_id, int pack_position_id) {
     printMessage(msg);
 
     // For secondary weapon
-    if (item_id != player_equipment::EQUIPMENT_AUX) {
+    if (item_id != PlayerEquipment::Auxiliary) {
         playerAdjustBonusesForItem(item, -1);
     }
 
@@ -697,7 +665,7 @@ void playerTakesHit(int damage, const char *creature_name_label) {
 }
 
 // Searches for hidden things. -RAK-
-void playerSearch(int y, int x, int chance) {
+void playerSearch(Coord_t coord, int chance) {
     if (py.flags.confused > 0) {
         chance = chance / 10;
     }
@@ -710,20 +678,21 @@ void playerSearch(int y, int x, int chance) {
         chance = chance / 10;
     }
 
-    for (int i = y - 1; i <= y + 1; i++) {
-        for (int j = x - 1; j <= x + 1; j++) {
+    Coord_t spot = Coord_t{0, 0};
+    for (spot.y = coord.y - 1; spot.y <= coord.y + 1; spot.y++) {
+        for (spot.x = coord.x - 1; spot.x <= coord.x + 1; spot.x++) {
             // always coordInBounds() here
             if (randomNumber(100) >= chance) {
                 continue;
             }
 
-            if (dg.floor[i][j].treasure_id == 0) {
+            if (dg.floor[spot.y][spot.x].treasure_id == 0) {
                 continue;
             }
 
             // Search for hidden objects
 
-            Inventory_t &item = treasure_list[dg.floor[i][j].treasure_id];
+            Inventory_t &item = game.treasure.list[dg.floor[spot.y][spot.x].treasure_id];
 
             if (item.category_id == TV_INVIS_TRAP) {
                 // Trap on floor?
@@ -735,14 +704,14 @@ void playerSearch(int y, int x, int chance) {
                 (void) sprintf(msg, "You have found %s", description);
                 printMessage(msg);
 
-                trapChangeVisibility(Coord_t{i, j});
+                trapChangeVisibility(spot);
                 playerEndRunning();
             } else if (item.category_id == TV_SECRET_DOOR) {
                 // Secret door?
 
                 printMessage("You have found a secret door.");
 
-                trapChangeVisibility(Coord_t{i, j});
+                trapChangeVisibility(spot);
                 playerEndRunning();
             } else if (item.category_id == TV_CHEST) {
                 // Chest is trapped?
@@ -763,7 +732,7 @@ void playerSearch(int y, int x, int chance) {
 
 // Computes current weight limit -RAK-
 int playerCarryingLoadLimit() {
-    int weight_cap = py.stats.used[py_attrs::A_STR] * config::player::PLAYER_WEIGHT_CAP + py.misc.weight;
+    int weight_cap = py.stats.used[PlayerAttr::A_STR] * config::player::PLAYER_WEIGHT_CAP + py.misc.weight;
 
     if (weight_cap > 3000) {
         weight_cap = 3000;
@@ -774,9 +743,9 @@ int playerCarryingLoadLimit() {
 
 // Are we strong enough for the current pack and weapon? -CJS-
 void playerStrength() {
-    Inventory_t const &item = inventory[player_equipment::EQUIPMENT_WIELD];
+    Inventory_t const &item = py.inventory[PlayerEquipment::Wield];
 
-    if (item.category_id != TV_NOTHING && py.stats.used[py_attrs::A_STR] * 15 < item.weight) {
+    if (item.category_id != TV_NOTHING && py.stats.used[PlayerAttr::A_STR] * 15 < item.weight) {
         if (!py.weapon_is_heavy) {
             printMessage("You have trouble wielding such a heavy weapon.");
             py.weapon_is_heavy = true;
@@ -792,20 +761,20 @@ void playerStrength() {
 
     int limit = playerCarryingLoadLimit();
 
-    if (limit < py.inventory_weight) {
-        limit = py.inventory_weight / (limit + 1);
+    if (limit < py.pack.weight) {
+        limit = py.pack.weight / (limit + 1);
     } else {
         limit = 0;
     }
 
-    if (py.pack_heaviness != limit) {
-        if (py.pack_heaviness < limit) {
+    if (py.pack.heaviness != limit) {
+        if (py.pack.heaviness < limit) {
             printMessage("Your pack is so heavy that it slows you down.");
         } else {
             printMessage("You move more easily under the weight of your pack.");
         }
-        playerChangeSpeed(limit - py.pack_heaviness);
-        py.pack_heaviness = (int16_t) limit;
+        playerChangeSpeed(limit - py.pack.heaviness);
+        py.pack.heaviness = (int16_t) limit;
     }
 
     py.flags.status &= ~config::player::status::PY_STR_WGT;
@@ -839,9 +808,9 @@ static int lastKnownSpell() {
 static uint32_t playerDetermineLearnableSpells() {
     uint32_t spell_flag = 0;
 
-    for (int i = 0; i < py.unique_inventory_items; i++) {
-        if (inventory[i].category_id == TV_MAGIC_BOOK) {
-            spell_flag |= inventory[i].flags;
+    for (int i = 0; i < py.pack.unique_items; i++) {
+        if (py.inventory[i].category_id == TV_MAGIC_BOOK) {
+            spell_flag |= py.inventory[i].flags;
         }
     }
 
@@ -850,8 +819,6 @@ static uint32_t playerDetermineLearnableSpells() {
 
 // gain spells when player wants to -JW-
 void playerGainSpells() {
-    // Priests don't need light because they get spells from their god, so only
-    // fail when can't see if player has config::spells::SPELL_TYPE_MAGE spells. This check is done below.
     if (py.flags.confused > 0) {
         printMessage("You are too confused.");
         return;
@@ -865,15 +832,17 @@ void playerGainSpells() {
 
     int stat, offset;
 
+    // Priests don't need light because they get spells from their god, so only
+    // fail when can't see if player has SPELL_TYPE_MAGE spells. This check is done below.
     if (classes[py.misc.class_id].class_to_use_mage_spells == config::spells::SPELL_TYPE_MAGE) {
-        // People with config::spells::SPELL_TYPE_MAGE spells can't learn spell_bank if they can't read their books.
+        // People with SPELL_TYPE_MAGE spells can't learn spell_bank if they can't read their books.
         if (!playerCanRead()) {
             return;
         }
-        stat = py_attrs::A_INT;
+        stat = PlayerAttr::A_INT;
         offset = config::spells::NAME_OFFSET_SPELLS;
     } else {
-        stat = py_attrs::A_WIS;
+        stat = PlayerAttr::A_WIS;
         offset = config::spells::NAME_OFFSET_PRAYERS;
     }
 
@@ -881,7 +850,7 @@ void playerGainSpells() {
 
     if (new_spells == 0) {
         vtype_t tmp_str = {'\0'};
-        (void) sprintf(tmp_str, "You can't learn any new %ss!", (stat == py_attrs::A_INT ? "spell" : "prayer"));
+        (void) sprintf(tmp_str, "You can't learn any new %ss!", (stat == PlayerAttr::A_INT ? "spell" : "prayer"));
         printMessage(tmp_str);
 
         game.player_free_turn = true;
@@ -892,7 +861,7 @@ void playerGainSpells() {
 
     // determine which spells player can learn
     // mages need the book to learn a spell, priests do not need the book
-    if (stat == py_attrs::A_INT) {
+    if (stat == PlayerAttr::A_INT) {
         spell_flag = playerDetermineLearnableSpells();
     } else {
         spell_flag = 0x7FFFFFFF;
@@ -924,7 +893,7 @@ void playerGainSpells() {
 
     if (new_spells == 0) {
         // do nothing
-    } else if (stat == py_attrs::A_INT) {
+    } else if (stat == PlayerAttr::A_INT) {
         // get to choose which mage spells will be learned
         terminalSaveScreen();
         displaySpellsList(spell_bank, spell_id, false, -1);
@@ -939,7 +908,8 @@ void playerGainSpells() {
                 new_spells--;
 
                 py.flags.spells_learnt |= 1L << spell_bank[c];
-                py.flags.spells_learned_order[last_known++] = (uint8_t) spell_bank[c];
+                py.flags.spells_learned_order[last_known] = (uint8_t) spell_bank[c];
+                last_known++;
 
                 for (; c <= spell_id - 1; c++) {
                     spell_bank[c] = spell_bank[c + 1];
@@ -960,7 +930,8 @@ void playerGainSpells() {
         while (new_spells != 0) {
             int id = randomNumber(spell_id) - 1;
             py.flags.spells_learnt |= 1L << spell_bank[id];
-            py.flags.spells_learned_order[last_known++] = (uint8_t) spell_bank[id];
+            py.flags.spells_learned_order[last_known] = (uint8_t) spell_bank[id];
+            last_known++;
 
             vtype_t tmp_str = {'\0'};
             (void) sprintf(tmp_str, "You have learned the prayer of %s.", spell_names[spell_bank[id] + offset]);
@@ -975,7 +946,7 @@ void playerGainSpells() {
         }
     }
 
-    py.flags.new_spells_to_learn = (uint8_t) (new_spells + diff_spells);
+    py.flags.new_spells_to_learn = (uint8_t)(new_spells + diff_spells);
 
     if (py.flags.new_spells_to_learn == 0) {
         py.flags.status |= config::player::status::PY_STUDY;
@@ -1025,8 +996,8 @@ void playerGainMana(int stat) {
                 // change current mana proportionately to change of max mana,
                 // divide first to avoid overflow, little loss of accuracy
                 int32_t value = (((int32_t) py.misc.current_mana << 16) + py.misc.current_mana_fraction) / py.misc.mana * new_mana;
-                py.misc.current_mana = (int16_t) (value >> 16);
-                py.misc.current_mana_fraction = (uint16_t) (value & 0xFFFF);
+                py.misc.current_mana = (int16_t)(value >> 16);
+                py.misc.current_mana_fraction = (uint16_t)(value & 0xFFFF);
             } else {
                 py.misc.current_mana = (int16_t) new_mana;
                 py.misc.current_mana_fraction = 0;
@@ -1075,9 +1046,9 @@ int playerWeaponCriticalBlow(int weapon_weight, int plus_to_hit, int damage, int
 
 // Saving throws for player character. -RAK-
 bool playerSavingThrow() {
-    int class_level_adjustment = class_level_adj[py.misc.class_id][py_class_level_adj::CLASS_SAVE] * py.misc.level / 3;
+    int class_level_adjustment = class_level_adj[py.misc.class_id][PlayerClassLevelAdj::SAVE] * py.misc.level / 3;
 
-    int saving = py.misc.saving_throw + playerStatAdjustmentWisdomIntelligence(py_attrs::A_WIS) + class_level_adjustment;
+    int saving = py.misc.saving_throw + playerStatAdjustmentWisdomIntelligence(PlayerAttr::A_WIS) + class_level_adjustment;
 
     return randomNumber(100) <= saving;
 }
@@ -1094,7 +1065,7 @@ void playerGainKillExperience(Creature_t const &creature) {
 
     if (remainder >= 0x10000L) {
         quotient++;
-        py.misc.exp_fraction = (uint16_t) (remainder - 0x10000L);
+        py.misc.exp_fraction = (uint16_t)(remainder - 0x10000L);
     } else {
         py.misc.exp_fraction = (uint16_t) remainder;
     }
@@ -1120,8 +1091,8 @@ static void playerCalculateToHitBlows(int weapon_id, int weapon_weight, int &blo
     total_to_hit += py.misc.plusses_to_hit;
 }
 
-static int playerCalculateBaseToHit(bool creatureLit, int tot_tohit) {
-    if (creatureLit) {
+static int playerCalculateBaseToHit(bool creature_lit, int tot_tohit) {
+    if (creature_lit) {
         return py.misc.bth;
     }
 
@@ -1130,18 +1101,18 @@ static int playerCalculateBaseToHit(bool creatureLit, int tot_tohit) {
 
     bth = py.misc.bth / 2;
     bth -= tot_tohit * (BTH_PER_PLUS_TO_HIT_ADJUST - 1);
-    bth -= py.misc.level * class_level_adj[py.misc.class_id][py_class_level_adj::CLASS_BTH] / 2;
+    bth -= py.misc.level * class_level_adj[py.misc.class_id][PlayerClassLevelAdj::BTH] / 2;
 
     return bth;
 }
 
 // Player attacks a (poor, defenseless) creature -RAK-
-static void playerAttackMonster(int y, int x) {
-    int creature_id = dg.floor[y][x].creature_id;
+static void playerAttackMonster(Coord_t coord) {
+    int creature_id = dg.floor[coord.y][coord.x].creature_id;
 
     Monster_t &monster = monsters[creature_id];
     Creature_t const &creature = creatures_list[monster.creature_id];
-    Inventory_t &item = inventory[player_equipment::EQUIPMENT_WIELD];
+    Inventory_t &item = py.inventory[PlayerEquipment::Wield];
 
     monster.sleep_count = 0;
 
@@ -1164,7 +1135,7 @@ static void playerAttackMonster(int y, int x) {
     // Loop for number of blows, trying to hit the critter.
     // Note: blows will always be greater than 0 at the start of the loop -MRC-
     for (int i = blows; i > 0; i--) {
-        if (!playerTestBeingHit(base_to_hit, (int) py.misc.level, total_to_hit, (int) creature.ac, py_class_level_adj::CLASS_BTH)) {
+        if (!playerTestBeingHit(base_to_hit, (int) py.misc.level, total_to_hit, (int) creature.ac, PlayerClassLevelAdj::BTH)) {
             (void) sprintf(msg, "You miss %s.", name);
             printMessage(msg);
             continue;
@@ -1176,11 +1147,11 @@ static void playerAttackMonster(int y, int x) {
         if (item.category_id != TV_NOTHING) {
             damage = diceRoll(item.damage);
             damage = itemMagicAbilityDamage(item, damage, monster.creature_id);
-            damage = playerWeaponCriticalBlow((int) item.weight, total_to_hit, damage, py_class_level_adj::CLASS_BTH);
+            damage = playerWeaponCriticalBlow((int) item.weight, total_to_hit, damage, PlayerClassLevelAdj::BTH);
         } else {
             // Bare hands!?
             damage = diceRoll(Dice_t{1, 1});
-            damage = playerWeaponCriticalBlow(1, 0, damage, py_class_level_adj::CLASS_BTH);
+            damage = playerWeaponCriticalBlow(1, 0, damage, PlayerClassLevelAdj::BTH);
         }
 
         damage += py.misc.plusses_to_damage;
@@ -1200,7 +1171,7 @@ static void playerAttackMonster(int y, int x) {
                 if (monster.confused_amount != 0u) {
                     monster.confused_amount += 3;
                 } else {
-                    monster.confused_amount = (uint8_t) (2 + randomNumber(16));
+                    monster.confused_amount = (uint8_t)(2 + randomNumber(16));
                 }
             }
             printMessage(msg);
@@ -1222,7 +1193,7 @@ static void playerAttackMonster(int y, int x) {
         // Use missiles up
         if (item.category_id >= TV_SLING_AMMO && item.category_id <= TV_SPIKE) {
             item.items_count--;
-            py.inventory_weight -= item.weight;
+            py.pack.weight -= item.weight;
             py.flags.status |= config::player::status::PY_STR_WGT;
 
             if (item.items_count == 0) {
@@ -1240,15 +1211,15 @@ static int16_t playerLockPickingSkill() {
 
     skill += 2;
     skill *= playerDisarmAdjustment();
-    skill += playerStatAdjustmentWisdomIntelligence(py_attrs::A_INT);
-    skill += class_level_adj[py.misc.class_id][py_class_level_adj::CLASS_DISARM] * py.misc.level / 3;
+    skill += playerStatAdjustmentWisdomIntelligence(PlayerAttr::A_INT);
+    skill += class_level_adj[py.misc.class_id][PlayerClassLevelAdj::DISARM] * py.misc.level / 3;
 
     return skill;
 }
 
-static void openClosedDoor(int y, int x) {
-    Tile_t &tile = dg.floor[y][x];
-    Inventory_t &item = treasure_list[tile.treasure_id];
+static void openClosedDoor(Coord_t coord) {
+    Tile_t &tile = dg.floor[coord.y][coord.x];
+    Inventory_t &item = game.treasure.list[tile.treasure_id];
 
     if (item.misc_use > 0) {
         // It's locked.
@@ -1270,16 +1241,16 @@ static void openClosedDoor(int y, int x) {
     }
 
     if (item.misc_use == 0) {
-        inventoryItemCopyTo(config::dungeon::objects::OBJ_OPEN_DOOR, treasure_list[tile.treasure_id]);
+        inventoryItemCopyTo(config::dungeon::objects::OBJ_OPEN_DOOR, game.treasure.list[tile.treasure_id]);
         tile.feature_id = TILE_CORR_FLOOR;
-        dungeonLiteSpot(Coord_t{y, x});
+        dungeonLiteSpot(coord);
         game.command_count = 0;
     }
 }
 
-static void openClosedChest(int y, int x) {
-    Tile_t const &tile = dg.floor[y][x];
-    Inventory_t &item = treasure_list[tile.treasure_id];
+static void openClosedChest(Coord_t coord) {
+    Tile_t const &tile = dg.floor[coord.y][coord.x];
+    Inventory_t &item = game.treasure.list[tile.treasure_id];
 
     bool success = false;
 
@@ -1302,7 +1273,7 @@ static void openClosedChest(int y, int x) {
 
     if (success) {
         item.flags &= ~config::treasure::chests::CH_LOCKED;
-        item.special_name_id = special_name_ids::SN_EMPTY;
+        item.special_name_id = SpecialNameIds::SN_EMPTY;
         spellItemIdentifyAndRemoveRandomInscription(item);
         item.cost = 0;
     }
@@ -1313,44 +1284,42 @@ static void openClosedChest(int y, int x) {
     }
 
     // Oh, yes it was...   (Snicker)
-    chestTrap(y, x);
+    chestTrap(coord);
 
     if (tile.treasure_id != 0) {
         // Chest treasure is allocated as if a creature had been killed.
         // clear the cursed chest/monster win flag, so that people
         // can not win by opening a cursed chest
-        treasure_list[tile.treasure_id].flags &= ~config::treasure::flags::TR_CURSED;
+        game.treasure.list[tile.treasure_id].flags &= ~config::treasure::flags::TR_CURSED;
 
-        (void) monsterDeath(y, x, treasure_list[tile.treasure_id].flags);
+        (void) monsterDeath(coord, game.treasure.list[tile.treasure_id].flags);
 
-        treasure_list[tile.treasure_id].flags = 0;
+        game.treasure.list[tile.treasure_id].flags = 0;
     }
 }
 
 // Opens a closed door or closed chest. -RAK-
 void playerOpenClosedObject() {
     int dir;
-
     if (!getDirectionWithMemory(CNIL, dir)) {
         return;
     }
 
-    int y = py.row;
-    int x = py.col;
-    (void) playerMovePosition(dir, y, x);
+    Coord_t coord = py.pos;
+    (void) playerMovePosition(dir, coord);
 
     bool no_object = false;
 
-    Tile_t const &tile = dg.floor[y][x];
-    Inventory_t const &item = treasure_list[tile.treasure_id];
+    Tile_t const &tile = dg.floor[coord.y][coord.x];
+    Inventory_t const &item = game.treasure.list[tile.treasure_id];
 
     if (tile.creature_id > 1 && tile.treasure_id != 0 && (item.category_id == TV_CLOSED_DOOR || item.category_id == TV_CHEST)) {
         objectBlockedByMonster(tile.creature_id);
     } else if (tile.treasure_id != 0) {
         if (item.category_id == TV_CLOSED_DOOR) {
-            openClosedDoor(y, x);
+            openClosedDoor(coord);
         } else if (item.category_id == TV_CHEST) {
-            openClosedChest(y, x);
+            openClosedChest(coord);
         } else {
             no_object = true;
         }
@@ -1372,12 +1341,11 @@ void playerCloseDoor() {
         return;
     }
 
-    int y = py.row;
-    int x = py.col;
-    (void) playerMovePosition(dir, y, x);
+    Coord_t coord = py.pos;
+    (void) playerMovePosition(dir, coord);
 
-    Tile_t &tile = dg.floor[y][x];
-    Inventory_t &item = treasure_list[tile.treasure_id];
+    Tile_t &tile = dg.floor[coord.y][coord.x];
+    Inventory_t &item = game.treasure.list[tile.treasure_id];
 
     bool no_object = false;
 
@@ -1387,7 +1355,7 @@ void playerCloseDoor() {
                 if (item.misc_use == 0) {
                     inventoryItemCopyTo(config::dungeon::objects::OBJ_CLOSED_DOOR, item);
                     tile.feature_id = TILE_BLOCKED_FLOOR;
-                    dungeonLiteSpot(Coord_t{y, x});
+                    dungeonLiteSpot(coord);
                 } else {
                     printMessage("The door appears to be broken.");
                 }
@@ -1409,23 +1377,23 @@ void playerCloseDoor() {
 
 // Tunneling through real wall: 10, 11, 12 -RAK-
 // Used by TUNNEL and WALL_TO_MUD
-bool playerTunnelWall(int y, int x, int digging_ability, int digging_chance) {
+bool playerTunnelWall(Coord_t coord, int digging_ability, int digging_chance) {
     if (digging_ability <= digging_chance) {
         return false;
     }
 
-    Tile_t &tile = dg.floor[y][x];
+    Tile_t &tile = dg.floor[coord.y][coord.x];
 
     if (tile.perma_lit_room) {
         // Should become a room space, check to see whether
         // it should be TILE_LIGHT_FLOOR or TILE_DARK_FLOOR.
         bool found = false;
 
-        for (int yy = y - 1; yy <= y + 1 && yy < MAX_HEIGHT; yy++) {
-            for (int xx = x - 1; xx <= x + 1 && xx < MAX_WIDTH; xx++) {
-                if (dg.floor[yy][xx].feature_id <= MAX_CAVE_ROOM) {
-                    tile.feature_id = dg.floor[yy][xx].feature_id;
-                    tile.permanent_light = dg.floor[yy][xx].permanent_light;
+        for (int y = coord.y - 1; y <= coord.y + 1 && y < MAX_HEIGHT; y++) {
+            for (int x = coord.x - 1; x <= coord.x + 1 && x < MAX_WIDTH; x++) {
+                if (dg.floor[y][x].feature_id <= MAX_CAVE_ROOM) {
+                    tile.feature_id = dg.floor[y][x].feature_id;
+                    tile.permanent_light = dg.floor[y][x].permanent_light;
                     found = true;
                     break;
                 }
@@ -1444,27 +1412,26 @@ bool playerTunnelWall(int y, int x, int digging_ability, int digging_chance) {
 
     tile.field_mark = false;
 
-    if (coordInsidePanel(Coord_t{y, x}) && (tile.temporary_light || tile.permanent_light) && tile.treasure_id != 0) {
+    if (coordInsidePanel(coord) && (tile.temporary_light || tile.permanent_light) && tile.treasure_id != 0) {
         printMessage("You have found something!");
     }
 
-    dungeonLiteSpot(Coord_t{y, x});
+    dungeonLiteSpot(coord);
 
     return true;
 }
 
 // let the player attack the creature
-void playerAttackPosition(int y, int x) {
+void playerAttackPosition(Coord_t coord) {
     // Is a Coward?
     if (py.flags.afraid > 0) {
         printMessage("You are too afraid!");
         return;
     }
 
-    playerAttackMonster(y, x);
+    playerAttackMonster(coord);
 }
 
-
 // check to see if know any spells greater than level, eliminate them
 static void eliminateKnownSpellsGreaterThanLevel(Spell_t *msp_ptr, const char *p, int offset) {
     uint32_t mask = 0x80000000L;
@@ -1528,43 +1495,43 @@ static int numberOfSpellsKnown() {
 
 // remember forgotten spells while forgotten spells exist of new_spells_to_learn positive,
 // remember the spells in the order that they were learned
-static int rememberForgottenSpells(Spell_t *msp_ptr, int allowedSpells, int newSpells, const char *p, int offset) {
+static int rememberForgottenSpells(Spell_t *msp_ptr, int allowed_spells, int new_spells, const char *p, int offset) {
     uint32_t mask;
 
-    for (int n = 0; ((py.flags.spells_forgotten != 0u) && (newSpells != 0) && (n < allowedSpells) && (n < 32)); n++) {
-        // orderID is (i+1)th spell learned
-        int orderID = py.flags.spells_learned_order[n];
+    for (int n = 0; ((py.flags.spells_forgotten != 0u) && (new_spells != 0) && (n < allowed_spells) && (n < 32)); n++) {
+        // order ID is (i+1)th spell learned
+        int order_id = py.flags.spells_learned_order[n];
 
         // shifting by amounts greater than number of bits in long gives
         // an undefined result, so don't shift for unknown spells
-        if (orderID == 99) {
+        if (order_id == 99) {
             mask = 0x0;
         } else {
-            mask = (uint32_t) (1L << orderID);
+            mask = (uint32_t)(1L << order_id);
         }
 
         if ((mask & py.flags.spells_forgotten) != 0u) {
-            if (msp_ptr[orderID].level_required <= py.misc.level) {
-                newSpells--;
+            if (msp_ptr[order_id].level_required <= py.misc.level) {
+                new_spells--;
                 py.flags.spells_forgotten &= ~mask;
                 py.flags.spells_learnt |= mask;
 
                 vtype_t msg = {'\0'};
-                (void) sprintf(msg, "You have remembered the %s of %s.", p, spell_names[orderID + offset]);
+                (void) sprintf(msg, "You have remembered the %s of %s.", p, spell_names[order_id + offset]);
                 printMessage(msg);
             } else {
-                allowedSpells++;
+                allowed_spells++;
             }
         }
     }
 
-    return newSpells;
+    return new_spells;
 }
 
 // determine which spells player can learn must check all spells here,
 // in gain_spell() we actually check if the books are present
-static int learnableSpells(Spell_t *msp_ptr, int newSpells) {
-    auto spell_flag = (uint32_t) (0x7FFFFFFFL & ~py.flags.spells_learnt);
+static int learnableSpells(Spell_t *msp_ptr, int new_spells) {
+    auto spell_flag = (uint32_t)(0x7FFFFFFFL & ~py.flags.spells_learnt);
 
     int id = 0;
     uint32_t mask = 0x1;
@@ -1578,38 +1545,38 @@ static int learnableSpells(Spell_t *msp_ptr, int newSpells) {
         }
     }
 
-    if (newSpells > id) {
-        newSpells = id;
+    if (new_spells > id) {
+        new_spells = id;
     }
 
-    return newSpells;
+    return new_spells;
 }
 
 // forget spells until new_spells_to_learn zero or no more spells know,
 // spells are forgotten in the opposite order that they were learned
 // NOTE: newSpells is always a negative value
-static void forgetSpells(int newSpells, const char *p, int offset) {
+static void forgetSpells(int new_spells, const char *p, int offset) {
     uint32_t mask;
 
-    for (int i = 31; (newSpells != 0) && (py.flags.spells_learnt != 0u); i--) {
+    for (int i = 31; (new_spells != 0) && (py.flags.spells_learnt != 0u); i--) {
         // orderID is the (i+1)th spell learned
-        int orderID = py.flags.spells_learned_order[i];
+        int order_id = py.flags.spells_learned_order[i];
 
         // shifting by amounts greater than number of bits in long gives
         // an undefined result, so don't shift for unknown spells
-        if (orderID == 99) {
+        if (order_id == 99) {
             mask = 0x0;
         } else {
-            mask = (uint32_t) (1L << orderID);
+            mask = (uint32_t)(1L << order_id);
         }
 
         if ((mask & py.flags.spells_learnt) != 0u) {
             py.flags.spells_learnt &= ~mask;
             py.flags.spells_forgotten |= mask;
-            newSpells++;
+            new_spells++;
 
             vtype_t msg = {'\0'};
-            (void) sprintf(msg, "You have forgotten the %s of %s.", p, spell_names[orderID + offset]);
+            (void) sprintf(msg, "You have forgotten the %s of %s.", p, spell_names[order_id + offset]);
             printMessage(msg);
         }
     }
@@ -1623,7 +1590,7 @@ void playerCalculateAllowedSpellsCount(int stat) {
     const char *magic_type_str = nullptr;
     int offset;
 
-    if (stat == py_attrs::A_INT) {
+    if (stat == PlayerAttr::A_INT) {
         magic_type_str = "spell";
         offset = config::spells::NAME_OFFSET_SPELLS;
     } else {
