@@ -26,7 +26,7 @@ static bool playerCanReadScroll(int &item_pos_start, int &item_pos_end) {
         return false;
     }
 
-    if (py.unique_inventory_items == 0) {
+    if (py.pack.unique_items == 0) {
         printMessage("You are not carrying anything!");
         return false;
     }
@@ -43,24 +43,30 @@ static int inventoryItemIdOfCursedEquipment() {
     int item_count = 0;
     int items[6];
 
-    if (inventory[player_equipment::EQUIPMENT_BODY].category_id != TV_NOTHING) {
-        items[item_count++] = player_equipment::EQUIPMENT_BODY;
+    if (py.inventory[PlayerEquipment::Body].category_id != TV_NOTHING) {
+        items[item_count] = PlayerEquipment::Body;
+        item_count++;
     }
-    if (inventory[player_equipment::EQUIPMENT_ARM].category_id != TV_NOTHING) {
-        items[item_count++] = player_equipment::EQUIPMENT_ARM;
+    if (py.inventory[PlayerEquipment::Arm].category_id != TV_NOTHING) {
+        items[item_count] = PlayerEquipment::Arm;
+        item_count++;
     }
-    if (inventory[player_equipment::EQUIPMENT_OUTER].category_id != TV_NOTHING) {
-        items[item_count++] = player_equipment::EQUIPMENT_OUTER;
+    if (py.inventory[PlayerEquipment::Outer].category_id != TV_NOTHING) {
+        items[item_count] = PlayerEquipment::Outer;
+        item_count++;
     }
-    if (inventory[player_equipment::EQUIPMENT_HANDS].category_id != TV_NOTHING) {
-        items[item_count++] = player_equipment::EQUIPMENT_HANDS;
+    if (py.inventory[PlayerEquipment::Hands].category_id != TV_NOTHING) {
+        items[item_count] = PlayerEquipment::Hands;
+        item_count++;
     }
-    if (inventory[player_equipment::EQUIPMENT_HEAD].category_id != TV_NOTHING) {
-        items[item_count++] = player_equipment::EQUIPMENT_HEAD;
+    if (py.inventory[PlayerEquipment::Head].category_id != TV_NOTHING) {
+        items[item_count] = PlayerEquipment::Head;
+        item_count++;
     }
     // also enchant boots
-    if (inventory[player_equipment::EQUIPMENT_FEET].category_id != TV_NOTHING) {
-        items[item_count++] = player_equipment::EQUIPMENT_FEET;
+    if (py.inventory[PlayerEquipment::Feet].category_id != TV_NOTHING) {
+        items[item_count] = PlayerEquipment::Feet;
+        item_count++;
     }
 
     int item_id = 0;
@@ -69,25 +75,25 @@ static int inventoryItemIdOfCursedEquipment() {
         item_id = items[randomNumber(item_count) - 1];
     }
 
-    if ((inventory[player_equipment::EQUIPMENT_BODY].flags & config::treasure::flags::TR_CURSED) != 0u) {
-        item_id = player_equipment::EQUIPMENT_BODY;
-    } else if ((inventory[player_equipment::EQUIPMENT_ARM].flags & config::treasure::flags::TR_CURSED) != 0u) {
-        item_id = player_equipment::EQUIPMENT_ARM;
-    } else if ((inventory[player_equipment::EQUIPMENT_OUTER].flags & config::treasure::flags::TR_CURSED) != 0u) {
-        item_id = player_equipment::EQUIPMENT_OUTER;
-    } else if ((inventory[player_equipment::EQUIPMENT_HEAD].flags & config::treasure::flags::TR_CURSED) != 0u) {
-        item_id = player_equipment::EQUIPMENT_HEAD;
-    } else if ((inventory[player_equipment::EQUIPMENT_HANDS].flags & config::treasure::flags::TR_CURSED) != 0u) {
-        item_id = player_equipment::EQUIPMENT_HANDS;
-    } else if ((inventory[player_equipment::EQUIPMENT_FEET].flags & config::treasure::flags::TR_CURSED) != 0u) {
-        item_id = player_equipment::EQUIPMENT_FEET;
+    if ((py.inventory[PlayerEquipment::Body].flags & config::treasure::flags::TR_CURSED) != 0u) {
+        item_id = PlayerEquipment::Body;
+    } else if ((py.inventory[PlayerEquipment::Arm].flags & config::treasure::flags::TR_CURSED) != 0u) {
+        item_id = PlayerEquipment::Arm;
+    } else if ((py.inventory[PlayerEquipment::Outer].flags & config::treasure::flags::TR_CURSED) != 0u) {
+        item_id = PlayerEquipment::Outer;
+    } else if ((py.inventory[PlayerEquipment::Head].flags & config::treasure::flags::TR_CURSED) != 0u) {
+        item_id = PlayerEquipment::Head;
+    } else if ((py.inventory[PlayerEquipment::Hands].flags & config::treasure::flags::TR_CURSED) != 0u) {
+        item_id = PlayerEquipment::Hands;
+    } else if ((py.inventory[PlayerEquipment::Feet].flags & config::treasure::flags::TR_CURSED) != 0u) {
+        item_id = PlayerEquipment::Feet;
     }
 
     return item_id;
 }
 
 static bool scrollEnchantWeaponToHit() {
-    Inventory_t &item = inventory[player_equipment::EQUIPMENT_WIELD];
+    Inventory_t &item = py.inventory[PlayerEquipment::Wield];
 
     if (item.category_id == TV_NOTHING) {
         return false;
@@ -111,7 +117,7 @@ static bool scrollEnchantWeaponToHit() {
 }
 
 static bool scrollEnchantWeaponToDamage() {
-    Inventory_t &item = inventory[player_equipment::EQUIPMENT_WIELD];
+    Inventory_t &item = py.inventory[PlayerEquipment::Wield];
 
     if (item.category_id == TV_NOTHING) {
         return false;
@@ -151,7 +157,7 @@ static bool scrollEnchantItemToAC() {
         return false;
     }
 
-    Inventory_t &item = inventory[item_id];
+    Inventory_t &item = py.inventory[item_id];
 
     obj_desc_t msg = {'\0'};
     obj_desc_t desc = {'\0'};
@@ -179,10 +185,10 @@ static int scrollIdentifyItem(int item_id, bool &is_used_up) {
     // to move to a different place.  Check for that here.  It can
     // move arbitrarily far if an identify scroll was used on
     // another identify scroll, but it always moves down.
-    Inventory_t *item = &inventory[item_id];
+    Inventory_t *item = &py.inventory[item_id];
     while (item_id > 0 && (item->category_id != TV_SCROLL1 || item->flags != 0x00000008)) {
         item_id--;
-        item = &inventory[item_id];
+        item = &py.inventory[item_id];
     }
 
     return item_id;
@@ -198,11 +204,12 @@ static bool scrollRemoveCurse() {
 
 static bool scrollSummonMonster() {
     bool identified = false;
+    Coord_t coord = Coord_t{0, 0};
 
     for (int i = 0; i < randomNumber(3); i++) {
-        auto y = (int) py.row;
-        auto x = (int) py.col;
-        identified |= monsterSummon(y, x, false);
+        coord.y = py.pos.y;
+        coord.x = py.pos.x;
+        identified |= monsterSummon(coord, false);
     }
 
     return identified;
@@ -226,7 +233,7 @@ static bool scrollConfuseMonster() {
 }
 
 static bool scrollEnchantWeapon() {
-    Inventory_t &item = inventory[player_equipment::EQUIPMENT_WIELD];
+    Inventory_t &item = py.inventory[PlayerEquipment::Wield];
 
     if (item.category_id == TV_NOTHING) {
         return false;
@@ -274,7 +281,7 @@ static bool scrollEnchantWeapon() {
 }
 
 static bool scrollCurseWeapon() {
-    Inventory_t &item = inventory[player_equipment::EQUIPMENT_WIELD];
+    Inventory_t &item = py.inventory[PlayerEquipment::Wield];
 
     if (item.category_id == TV_NOTHING) {
         return false;
@@ -289,8 +296,8 @@ static bool scrollCurseWeapon() {
 
     itemRemoveMagicNaming(item);
 
-    item.to_hit = (int16_t) (-randomNumber(5) - randomNumber(5));
-    item.to_damage = (int16_t) (-randomNumber(5) - randomNumber(5));
+    item.to_hit = (int16_t)(-randomNumber(5) - randomNumber(5));
+    item.to_damage = (int16_t)(-randomNumber(5) - randomNumber(5));
     item.to_ac = 0;
 
     // Must call playerAdjustBonusesForItem() before set (clear) flags, and
@@ -310,7 +317,7 @@ static bool scrollEnchantArmor() {
         return false;
     }
 
-    Inventory_t &item = inventory[item_id];
+    Inventory_t &item = py.inventory[item_id];
 
     obj_desc_t msg = {'\0'};
     obj_desc_t desc = {'\0'};
@@ -340,30 +347,30 @@ static bool scrollEnchantArmor() {
 static bool scrollCurseArmor() {
     int item_id;
 
-    if (inventory[player_equipment::EQUIPMENT_BODY].category_id != TV_NOTHING && randomNumber(4) == 1) {
-        item_id = player_equipment::EQUIPMENT_BODY;
-    } else if (inventory[player_equipment::EQUIPMENT_ARM].category_id != TV_NOTHING && randomNumber(3) == 1) {
-        item_id = player_equipment::EQUIPMENT_ARM;
-    } else if (inventory[player_equipment::EQUIPMENT_OUTER].category_id != TV_NOTHING && randomNumber(3) == 1) {
-        item_id = player_equipment::EQUIPMENT_OUTER;
-    } else if (inventory[player_equipment::EQUIPMENT_HEAD].category_id != TV_NOTHING && randomNumber(3) == 1) {
-        item_id = player_equipment::EQUIPMENT_HEAD;
-    } else if (inventory[player_equipment::EQUIPMENT_HANDS].category_id != TV_NOTHING && randomNumber(3) == 1) {
-        item_id = player_equipment::EQUIPMENT_HANDS;
-    } else if (inventory[player_equipment::EQUIPMENT_FEET].category_id != TV_NOTHING && randomNumber(3) == 1) {
-        item_id = player_equipment::EQUIPMENT_FEET;
-    } else if (inventory[player_equipment::EQUIPMENT_BODY].category_id != TV_NOTHING) {
-        item_id = player_equipment::EQUIPMENT_BODY;
-    } else if (inventory[player_equipment::EQUIPMENT_ARM].category_id != TV_NOTHING) {
-        item_id = player_equipment::EQUIPMENT_ARM;
-    } else if (inventory[player_equipment::EQUIPMENT_OUTER].category_id != TV_NOTHING) {
-        item_id = player_equipment::EQUIPMENT_OUTER;
-    } else if (inventory[player_equipment::EQUIPMENT_HEAD].category_id != TV_NOTHING) {
-        item_id = player_equipment::EQUIPMENT_HEAD;
-    } else if (inventory[player_equipment::EQUIPMENT_HANDS].category_id != TV_NOTHING) {
-        item_id = player_equipment::EQUIPMENT_HANDS;
-    } else if (inventory[player_equipment::EQUIPMENT_FEET].category_id != TV_NOTHING) {
-        item_id = player_equipment::EQUIPMENT_FEET;
+    if (py.inventory[PlayerEquipment::Body].category_id != TV_NOTHING && randomNumber(4) == 1) {
+        item_id = PlayerEquipment::Body;
+    } else if (py.inventory[PlayerEquipment::Arm].category_id != TV_NOTHING && randomNumber(3) == 1) {
+        item_id = PlayerEquipment::Arm;
+    } else if (py.inventory[PlayerEquipment::Outer].category_id != TV_NOTHING && randomNumber(3) == 1) {
+        item_id = PlayerEquipment::Outer;
+    } else if (py.inventory[PlayerEquipment::Head].category_id != TV_NOTHING && randomNumber(3) == 1) {
+        item_id = PlayerEquipment::Head;
+    } else if (py.inventory[PlayerEquipment::Hands].category_id != TV_NOTHING && randomNumber(3) == 1) {
+        item_id = PlayerEquipment::Hands;
+    } else if (py.inventory[PlayerEquipment::Feet].category_id != TV_NOTHING && randomNumber(3) == 1) {
+        item_id = PlayerEquipment::Feet;
+    } else if (py.inventory[PlayerEquipment::Body].category_id != TV_NOTHING) {
+        item_id = PlayerEquipment::Body;
+    } else if (py.inventory[PlayerEquipment::Arm].category_id != TV_NOTHING) {
+        item_id = PlayerEquipment::Arm;
+    } else if (py.inventory[PlayerEquipment::Outer].category_id != TV_NOTHING) {
+        item_id = PlayerEquipment::Outer;
+    } else if (py.inventory[PlayerEquipment::Head].category_id != TV_NOTHING) {
+        item_id = PlayerEquipment::Head;
+    } else if (py.inventory[PlayerEquipment::Hands].category_id != TV_NOTHING) {
+        item_id = PlayerEquipment::Hands;
+    } else if (py.inventory[PlayerEquipment::Feet].category_id != TV_NOTHING) {
+        item_id = PlayerEquipment::Feet;
     } else {
         item_id = 0;
     }
@@ -372,7 +379,7 @@ static bool scrollCurseArmor() {
         return false;
     }
 
-    Inventory_t &item = inventory[item_id];
+    Inventory_t &item = py.inventory[item_id];
 
     obj_desc_t msg = {'\0'};
     obj_desc_t desc = {'\0'};
@@ -386,7 +393,7 @@ static bool scrollCurseArmor() {
     item.flags = config::treasure::flags::TR_CURSED;
     item.to_hit = 0;
     item.to_damage = 0;
-    item.to_ac = (int16_t) (-randomNumber(5) - randomNumber(5));
+    item.to_ac = (int16_t)(-randomNumber(5) - randomNumber(5));
 
     playerRecalculateBonuses();
 
@@ -395,11 +402,12 @@ static bool scrollCurseArmor() {
 
 static bool scrollSummonUndead() {
     bool identified = false;
+    Coord_t coord = Coord_t{0, 0};
 
     for (int i = 0; i < randomNumber(3); i++) {
-        int y = py.row;
-        int x = py.col;
-        identified |= monsterSummonUndead(y, x);
+        coord.y = py.pos.y;
+        coord.x = py.pos.x;
+        identified |= monsterSummonUndead(coord);
     }
 
     return identified;
@@ -407,7 +415,7 @@ static bool scrollSummonUndead() {
 
 static void scrollWordOfRecall() {
     if (py.flags.word_of_recall == 0) {
-        py.flags.word_of_recall = (int16_t) (25 + randomNumber(30));
+        py.flags.word_of_recall = (int16_t)(25 + randomNumber(30));
     }
     printMessage("The air about you becomes charged.");
 }
@@ -432,7 +440,7 @@ void scrollRead() {
     bool used_up = true;
     bool identified = false;
 
-    Inventory_t *item = &inventory[item_id];
+    Inventory_t *item = &py.inventory[item_id];
     uint32_t item_flags = item->flags;
 
     while (item_flags != 0) {
@@ -460,7 +468,7 @@ void scrollRead() {
                 identified = scrollRemoveCurse();
                 break;
             case 6:
-                identified = spellLightArea(py.row, py.col);
+                identified = spellLightArea(py.pos);
                 break;
             case 7:
                 identified = scrollSummonMonster();
@@ -485,7 +493,7 @@ void scrollRead() {
                 identified = true;
                 break;
             case 13:
-                identified = monsterSleep(py.row, py.col);
+                identified = monsterSleep(py.pos);
                 break;
             case 14:
                 spellWardingGlyph();
@@ -536,7 +544,7 @@ void scrollRead() {
                 identified = true;
                 break;
             case 27:
-                identified = spellDarkenArea(py.row, py.col);
+                identified = spellDarkenArea(py.pos);
                 break;
             case 28:
                 identified = playerProtectEvil();
@@ -580,7 +588,7 @@ void scrollRead() {
                 identified = true;
                 break;
             case 42:
-                spellDestroyArea(py.row, py.col);
+                spellDestroyArea(py.pos);
                 identified = true;
                 break;
             default:
@@ -589,7 +597,7 @@ void scrollRead() {
         }
     }
 
-    item = &inventory[item_id];
+    item = &py.inventory[item_id];
 
     if (identified) {
         if (!itemSetColorlessAsIdentified(item->category_id, item->sub_category_id, item->identification)) {
@@ -597,7 +605,7 @@ void scrollRead() {
             py.misc.exp += (item->depth_first_found + (py.misc.level >> 1)) / py.misc.level;
             displayCharacterExperience();
 
-            itemIdentify(inventory[item_id], item_id);
+            itemIdentify(py.inventory[item_id], item_id);
         }
     } else if (!itemSetColorlessAsIdentified(item->category_id, item->sub_category_id, item->identification)) {
         itemSetAsTried(*item);
