@@ -8,7 +8,9 @@
 
 #include "headers.h"
 
-static const char *stat_names[] = {"STR : ", "INT : ", "WIS : ", "DEX : ", "CON : ", "CHR : ",};
+static const char *stat_names[] = {
+    "STR : ", "INT : ", "WIS : ", "DEX : ", "CON : ", "CHR : ",
+};
 #define BLANK_LENGTH 24
 static char blank_string[] = "                        ";
 
@@ -33,31 +35,30 @@ static void panelBounds() {
 // when a move off the screen has occurred and figures new borders.
 // `force` forces the panel bounds to be recalculated, useful for 'W'here.
 bool coordOutsidePanel(Coord_t coord, bool force) {
-    int row = dg.panel.row;
-    int col = dg.panel.col;
+    Coord_t panel = Coord_t{dg.panel.row, dg.panel.col};
 
     if (force || coord.y < dg.panel.top + 2 || coord.y > dg.panel.bottom - 2) {
-        row = (coord.y - SCREEN_HEIGHT / 4) / (SCREEN_HEIGHT / 2);
+        panel.y = (coord.y - SCREEN_HEIGHT / 4) / (SCREEN_HEIGHT / 2);
 
-        if (row > dg.panel.max_rows) {
-            row = dg.panel.max_rows;
-        } else if (row < 0) {
-            row = 0;
+        if (panel.y > dg.panel.max_rows) {
+            panel.y = dg.panel.max_rows;
+        } else if (panel.y < 0) {
+            panel.y = 0;
         }
     }
 
     if (force || coord.x < dg.panel.left + 3 || coord.x > dg.panel.right - 3) {
-        col = ((coord.x - SCREEN_WIDTH / 4) / (SCREEN_WIDTH / 2));
-        if (col > dg.panel.max_cols) {
-            col = dg.panel.max_cols;
-        } else if (col < 0) {
-            col = 0;
+        panel.x = ((coord.x - SCREEN_WIDTH / 4) / (SCREEN_WIDTH / 2));
+        if (panel.x > dg.panel.max_cols) {
+            panel.x = dg.panel.max_cols;
+        } else if (panel.x < 0) {
+            panel.x = 0;
         }
     }
 
-    if (row != dg.panel.row || col != dg.panel.col) {
-        dg.panel.row = row;
-        dg.panel.col = col;
+    if (panel.y != dg.panel.row || panel.x != dg.panel.col) {
+        dg.panel.row = panel.y;
+        dg.panel.col = panel.x;
         panelBounds();
 
         // stop movement if any
@@ -84,15 +85,18 @@ bool coordInsidePanel(Coord_t coord) {
 void drawDungeonPanel() {
     int line = 1;
 
+    Coord_t coord = Coord_t{0, 0};
+
     // Top to bottom
-    for (int y = dg.panel.top; y <= dg.panel.bottom; y++) {
-        eraseLine(Coord_t{line++, 13});
+    for (coord.y = dg.panel.top; coord.y <= dg.panel.bottom; coord.y++) {
+        eraseLine(Coord_t{line, 13});
+        line++;
 
         // Left to right
-        for (int x = dg.panel.left; x <= dg.panel.right; x++) {
-            char ch = caveGetTileSymbol(Coord_t{y, x});
+        for (coord.x = dg.panel.left; coord.x <= dg.panel.right; coord.x++) {
+            char ch = caveGetTileSymbol(coord);
             if (ch != ' ') {
-                panelPutTile(ch, Coord_t{y, x});
+                panelPutTile(ch, coord);
             }
         }
     }
@@ -108,28 +112,28 @@ void drawCavePanel() {
 
 // We need to reset the view of things. -CJS-
 void dungeonResetView() {
-    Tile_t const &tile = dg.floor[py.row][py.col];
+    Tile_t const &tile = dg.floor[py.pos.y][py.pos.x];
 
     // Check for new panel
-    if (coordOutsidePanel(Coord_t{py.row, py.col}, false)) {
+    if (coordOutsidePanel(py.pos, false)) {
         drawDungeonPanel();
     }
 
     // Move the light source
-    dungeonMoveCharacterLight(Coord_t{py.row, py.col}, Coord_t{py.row, py.col});
+    dungeonMoveCharacterLight(py.pos, py.pos);
 
     // A room of light should be lit.
     if (tile.feature_id == TILE_LIGHT_FLOOR) {
         if (py.flags.blind < 1 && !tile.permanent_light) {
-            dungeonLightRoom(Coord_t{py.row, py.col});
+            dungeonLightRoom(py.pos);
         }
         return;
     }
 
     // In doorway of light-room?
     if (tile.perma_lit_room && py.flags.blind < 1) {
-        for (int i = py.row - 1; i <= py.row + 1; i++) {
-            for (int j = py.col - 1; j <= py.col + 1; j++) {
+        for (int i = py.pos.y - 1; i <= py.pos.y + 1; i++) {
+            for (int j = py.pos.x - 1; j <= py.pos.x + 1; j++) {
                 if (dg.floor[i][j].feature_id == TILE_LIGHT_FLOOR && !dg.floor[i][j].permanent_light) {
                     dungeonLightRoom(Coord_t{i, j});
                 }
@@ -138,22 +142,17 @@ void dungeonResetView() {
     }
 }
 
-// Converts stat num into string -RAK-
+// Converts stat num into string
 void statsAsString(uint8_t stat, char *stat_string) {
+    int percentile = stat - 18;
+
     if (stat <= 18) {
         (void) sprintf(stat_string, "%6d", stat);
-        return;
-    }
-
-    int part1 = 18;
-    int part2 = stat - 18;
-
-    if (part2 == 100) {
+    } else if (percentile == 100) {
         (void) strcpy(stat_string, "18/100");
-        return;
+    } else {
+        (void) sprintf(stat_string, " 18/%02d", percentile);
     }
-
-    (void) sprintf(stat_string, " %2d/%02d", part1, part2);
 }
 
 // Print character stat in given row, column -RAK-
@@ -166,81 +165,81 @@ void displayCharacterStats(int stat) {
 
 // Print character info in given row, column -RAK-
 // The longest title is 13 characters, so only pad to 13
-static void printCharacterInfoInField(const char *info, int row, int column) {
+static void printCharacterInfoInField(const char *info, Coord_t coord) {
     // blank out the current field space
-    putString(&blank_string[BLANK_LENGTH - 13], Coord_t{row, column});
+    putString(&blank_string[BLANK_LENGTH - 13], coord);
 
-    putString(info, Coord_t{row, column});
+    putString(info, coord);
 }
 
 // Print long number with header at given row, column
-static void printHeaderLongNumber(const char *header, int32_t num, int row, int column) {
+static void printHeaderLongNumber(const char *header, int32_t num, Coord_t coord) {
     vtype_t str = {'\0'};
     (void) sprintf(str, "%s: %6d", header, num);
-    putString(str, Coord_t{row, column});
+    putString(str, coord);
 }
 
 // Print long number (7 digits of space) with header at given row, column
-static void printHeaderLongNumber7Spaces(const char *header, int32_t num, int row, int column) {
+static void printHeaderLongNumber7Spaces(const char *header, int32_t num, Coord_t coord) {
     vtype_t str = {'\0'};
     (void) sprintf(str, "%s: %7d", header, num);
-    putString(str, Coord_t{row, column});
+    putString(str, coord);
 }
 
 // Print number with header at given row, column -RAK-
-static void printHeaderNumber(const char *header, int num, int row, int column) {
+static void printHeaderNumber(const char *header, int num, Coord_t coord) {
     vtype_t str = {'\0'};
     (void) sprintf(str, "%s: %6d", header, num);
-    putString(str, Coord_t{row, column});
+    putString(str, coord);
 }
 
 // Print long number at given row, column
-static void printLongNumber(int32_t num, int row, int column) {
+static void printLongNumber(int32_t num, Coord_t coord) {
     vtype_t str = {'\0'};
     (void) sprintf(str, "%6d", num);
-    putString(str, Coord_t{row, column});
+    putString(str, coord);
 }
 
 // Print number at given row, column -RAK-
-static void printNumber(int num, int row, int column) {
+static void printNumber(int num, Coord_t coord) {
     vtype_t str = {'\0'};
     (void) sprintf(str, "%6d", num);
-    putString(str, Coord_t{row, column});
+    putString(str, coord);
 }
 
 // Prints title of character -RAK-
 void printCharacterTitle() {
-    printCharacterInfoInField(playerRankTitle(), 4, STAT_COLUMN);
+    printCharacterInfoInField(playerRankTitle(), Coord_t{4, STAT_COLUMN});
 }
 
 // Prints level -RAK-
 void printCharacterLevel() {
-    printNumber((int) py.misc.level, 13, STAT_COLUMN + 6);
+    printNumber((int) py.misc.level, Coord_t{13, STAT_COLUMN + 6});
 }
 
 // Prints players current mana points. -RAK-
 void printCharacterCurrentMana() {
-    printNumber(py.misc.current_mana, 15, STAT_COLUMN + 6);
+    printNumber(py.misc.current_mana, Coord_t{15, STAT_COLUMN + 6});
 }
 
 // Prints Max hit points -RAK-
 void printCharacterMaxHitPoints() {
-    printNumber(py.misc.max_hp, 16, STAT_COLUMN + 6);
+    printNumber(py.misc.max_hp, Coord_t{16, STAT_COLUMN + 6});
 }
 
 // Prints players current hit points -RAK-
 void printCharacterCurrentHitPoints() {
-    printNumber(py.misc.current_hp, 17, STAT_COLUMN + 6);
+    printNumber(py.misc.current_hp, Coord_t{17, STAT_COLUMN + 6});
 }
 
 // prints current AC -RAK-
 void printCharacterCurrentArmorClass() {
-    printNumber(py.misc.display_ac, 19, STAT_COLUMN + 6);
+    printNumber(py.misc.display_ac, Coord_t{19, STAT_COLUMN + 6});
 }
 
 // Prints current gold -RAK-
 void printCharacterGoldValue() {
-    printLongNumber(py.misc.au, 20, STAT_COLUMN + 6);
+    printLongNumber(py.misc.au, Coord_t{20, STAT_COLUMN + 6});
 }
 
 // Prints depth in stat area -RAK-
@@ -315,33 +314,33 @@ void printCharacterMovementState() {
     }
 
     if ((py.flags.status & config::player::status::PY_REST) != 0u) {
-        char restString[16];
+        char rest_string[16];
 
         if (py.flags.rest < 0) {
-            (void) strcpy(restString, "Rest *");
+            (void) strcpy(rest_string, "Rest *");
         } else if (config::options::display_counts) {
-            (void) sprintf(restString, "Rest %-5d", py.flags.rest);
+            (void) sprintf(rest_string, "Rest %-5d", py.flags.rest);
         } else {
-            (void) strcpy(restString, "Rest");
+            (void) strcpy(rest_string, "Rest");
         }
 
-        putString(restString, Coord_t{23, 38});
+        putString(rest_string, Coord_t{23, 38});
 
         return;
     }
 
     if (game.command_count > 0) {
-        char repeatString[16];
+        char repeat_string[16];
 
         if (config::options::display_counts) {
-            (void) sprintf(repeatString, "Repeat %-3d", game.command_count);
+            (void) sprintf(repeat_string, "Repeat %-3d", game.command_count);
         } else {
-            (void) strcpy(repeatString, "Repeat");
+            (void) strcpy(repeat_string, "Repeat");
         }
 
         py.flags.status |= config::player::status::PY_REPEAT;
 
-        putString(repeatString, Coord_t{23, 38});
+        putString(repeat_string, Coord_t{23, 38});
 
         if ((py.flags.status & config::player::status::PY_SEARCH) != 0u) {
             putString("Search", Coord_t{23, 38});
@@ -410,21 +409,21 @@ void printCharacterWinner() {
 
 // Prints character-screen info -RAK-
 void printCharacterStatsBlock() {
-    printCharacterInfoInField(character_races[py.misc.race_id].name, 2, STAT_COLUMN);
-    printCharacterInfoInField(classes[py.misc.class_id].title, 3, STAT_COLUMN);
-    printCharacterInfoInField(playerRankTitle(), 4, STAT_COLUMN);
+    printCharacterInfoInField(character_races[py.misc.race_id].name, Coord_t{2, STAT_COLUMN});
+    printCharacterInfoInField(classes[py.misc.class_id].title, Coord_t{3, STAT_COLUMN});
+    printCharacterInfoInField(playerRankTitle(), Coord_t{4, STAT_COLUMN});
 
     for (int i = 0; i < 6; i++) {
         displayCharacterStats(i);
     }
 
-    printHeaderNumber("LEV ", (int) py.misc.level, 13, STAT_COLUMN);
-    printHeaderLongNumber("EXP ", py.misc.exp, 14, STAT_COLUMN);
-    printHeaderNumber("MANA", py.misc.current_mana, 15, STAT_COLUMN);
-    printHeaderNumber("MHP ", py.misc.max_hp, 16, STAT_COLUMN);
-    printHeaderNumber("CHP ", py.misc.current_hp, 17, STAT_COLUMN);
-    printHeaderNumber("AC  ", py.misc.display_ac, 19, STAT_COLUMN);
-    printHeaderLongNumber("GOLD", py.misc.au, 20, STAT_COLUMN);
+    printHeaderNumber("LEV ", (int) py.misc.level, Coord_t{13, STAT_COLUMN});
+    printHeaderLongNumber("EXP ", py.misc.exp, Coord_t{14, STAT_COLUMN});
+    printHeaderNumber("MANA", py.misc.current_mana, Coord_t{15, STAT_COLUMN});
+    printHeaderNumber("MHP ", py.misc.max_hp, Coord_t{16, STAT_COLUMN});
+    printHeaderNumber("CHP ", py.misc.current_hp, Coord_t{17, STAT_COLUMN});
+    printHeaderNumber("AC  ", py.misc.display_ac, Coord_t{19, STAT_COLUMN});
+    printHeaderLongNumber("GOLD", py.misc.au, Coord_t{20, STAT_COLUMN});
     printCharacterWinner();
 
     uint32_t status = py.flags.status;
@@ -454,7 +453,7 @@ void printCharacterStatsBlock() {
     }
 
     // if speed non zero, print it, modify speed if Searching
-    int16_t speed = py.flags.speed - (int16_t) ((status & config::player::status::PY_SEARCH) >> 8);
+    int16_t speed = py.flags.speed - (int16_t)((status & config::player::status::PY_SEARCH) >> 8);
     if (speed != 0) {
         printCharacterSpeed();
     }
@@ -497,15 +496,15 @@ void printCharacterStats() {
         }
     }
 
-    printHeaderNumber("+ To Hit    ", py.misc.display_to_hit, 9, 1);
-    printHeaderNumber("+ To Damage ", py.misc.display_to_damage, 10, 1);
-    printHeaderNumber("+ To AC     ", py.misc.display_to_ac, 11, 1);
-    printHeaderNumber("  Total AC  ", py.misc.display_ac, 12, 1);
+    printHeaderNumber("+ To Hit    ", py.misc.display_to_hit, Coord_t{9, 1});
+    printHeaderNumber("+ To Damage ", py.misc.display_to_damage, Coord_t{10, 1});
+    printHeaderNumber("+ To AC     ", py.misc.display_to_ac, Coord_t{11, 1});
+    printHeaderNumber("  Total AC  ", py.misc.display_ac, Coord_t{12, 1});
 }
 
 // Returns a rating of x depending on y -JWT-
-const char *statRating(int y, int x) {
-    switch (x / y) {
+const char *statRating(Coord_t coord) {
+    switch (coord.x / coord.y) {
         case -3:
         case -2:
         case -1:
@@ -532,37 +531,37 @@ const char *statRating(int y, int x) {
 
 // Prints age, height, weight, and SC -JWT-
 void printCharacterVitalStatistics() {
-    printHeaderNumber("Age          ", (int) py.misc.age, 2, 38);
-    printHeaderNumber("Height       ", (int) py.misc.height, 3, 38);
-    printHeaderNumber("Weight       ", (int) py.misc.weight, 4, 38);
-    printHeaderNumber("Social Class ", (int) py.misc.social_class, 5, 38);
+    printHeaderNumber("Age          ", (int) py.misc.age, Coord_t{2, 38});
+    printHeaderNumber("Height       ", (int) py.misc.height, Coord_t{3, 38});
+    printHeaderNumber("Weight       ", (int) py.misc.weight, Coord_t{4, 38});
+    printHeaderNumber("Social Class ", (int) py.misc.social_class, Coord_t{5, 38});
 }
 
 // Prints the following information on the screen. -JWT-
 void printCharacterLevelExperience() {
-    printHeaderLongNumber7Spaces("Level      ", (int32_t) py.misc.level, 9, 28);
-    printHeaderLongNumber7Spaces("Experience ", py.misc.exp, 10, 28);
-    printHeaderLongNumber7Spaces("Max Exp    ", py.misc.max_exp, 11, 28);
+    printHeaderLongNumber7Spaces("Level      ", (int32_t) py.misc.level, Coord_t{9, 28});
+    printHeaderLongNumber7Spaces("Experience ", py.misc.exp, Coord_t{10, 28});
+    printHeaderLongNumber7Spaces("Max Exp    ", py.misc.max_exp, Coord_t{11, 28});
 
     if (py.misc.level >= PLAYER_MAX_LEVEL) {
         putStringClearToEOL("Exp to Adv.: *******", Coord_t{12, 28});
     } else {
-        printHeaderLongNumber7Spaces("Exp to Adv.", (int32_t) (py.base_exp_levels[py.misc.level - 1] * py.misc.experience_factor / 100), 12, 28);
+        printHeaderLongNumber7Spaces("Exp to Adv.", (int32_t)(py.base_exp_levels[py.misc.level - 1] * py.misc.experience_factor / 100), Coord_t{12, 28});
     }
 
-    printHeaderLongNumber7Spaces("Gold       ", py.misc.au, 13, 28);
-    printHeaderNumber("Max Hit Points ", py.misc.max_hp, 9, 52);
-    printHeaderNumber("Cur Hit Points ", py.misc.current_hp, 10, 52);
-    printHeaderNumber("Max Mana       ", py.misc.mana, 11, 52);
-    printHeaderNumber("Cur Mana       ", py.misc.current_mana, 12, 52);
+    printHeaderLongNumber7Spaces("Gold       ", py.misc.au, Coord_t{13, 28});
+    printHeaderNumber("Max Hit Points ", py.misc.max_hp, Coord_t{9, 52});
+    printHeaderNumber("Cur Hit Points ", py.misc.current_hp, Coord_t{10, 52});
+    printHeaderNumber("Max Mana       ", py.misc.mana, Coord_t{11, 52});
+    printHeaderNumber("Cur Mana       ", py.misc.current_mana, Coord_t{12, 52});
 }
 
 // Prints ratings on certain abilities -RAK-
 void printCharacterAbilities() {
     clearToBottom(14);
 
-    int xbth = py.misc.bth + py.misc.plusses_to_hit * BTH_PER_PLUS_TO_HIT_ADJUST + (class_level_adj[py.misc.class_id][py_class_level_adj::CLASS_BTH] * py.misc.level);
-    int xbthb = py.misc.bth_with_bows + py.misc.plusses_to_hit * BTH_PER_PLUS_TO_HIT_ADJUST + (class_level_adj[py.misc.class_id][py_class_level_adj::CLASS_BTHB] * py.misc.level);
+    int xbth = py.misc.bth + py.misc.plusses_to_hit * BTH_PER_PLUS_TO_HIT_ADJUST + (class_level_adj[py.misc.class_id][PlayerClassLevelAdj::BTH] * py.misc.level);
+    int xbthb = py.misc.bth_with_bows + py.misc.plusses_to_hit * BTH_PER_PLUS_TO_HIT_ADJUST + (class_level_adj[py.misc.class_id][PlayerClassLevelAdj::BTHB] * py.misc.level);
 
     // this results in a range from 0 to 29
     int xfos = 40 - py.misc.fos;
@@ -574,32 +573,35 @@ void printCharacterAbilities() {
 
     // this results in a range from 0 to 9
     int xstl = py.misc.stealth_factor + 1;
-    int xdis = py.misc.disarm + 2 * playerDisarmAdjustment() + playerStatAdjustmentWisdomIntelligence(py_attrs::A_INT) + (class_level_adj[py.misc.class_id][py_class_level_adj::CLASS_DISARM] * py.misc.level / 3);
-    int xsave = py.misc.saving_throw + playerStatAdjustmentWisdomIntelligence(py_attrs::A_WIS) + (class_level_adj[py.misc.class_id][py_class_level_adj::CLASS_SAVE] * py.misc.level / 3);
-    int xdev = py.misc.saving_throw + playerStatAdjustmentWisdomIntelligence(py_attrs::A_INT) + (class_level_adj[py.misc.class_id][py_class_level_adj::CLASS_DEVICE] * py.misc.level / 3);
+    int xdis = py.misc.disarm + 2 * playerDisarmAdjustment() + playerStatAdjustmentWisdomIntelligence(PlayerAttr::A_INT) +
+               (class_level_adj[py.misc.class_id][PlayerClassLevelAdj::DISARM] * py.misc.level / 3);
+    int xsave =
+        py.misc.saving_throw + playerStatAdjustmentWisdomIntelligence(PlayerAttr::A_WIS) + (class_level_adj[py.misc.class_id][PlayerClassLevelAdj::SAVE] * py.misc.level / 3);
+    int xdev =
+        py.misc.saving_throw + playerStatAdjustmentWisdomIntelligence(PlayerAttr::A_INT) + (class_level_adj[py.misc.class_id][PlayerClassLevelAdj::DEVICE] * py.misc.level / 3);
 
     vtype_t xinfra = {'\0'};
     (void) sprintf(xinfra, "%d feet", py.flags.see_infra * 10);
 
     putString("(Miscellaneous Abilities)", Coord_t{15, 25});
     putString("Fighting    :", Coord_t{16, 1});
-    putString(statRating(12, xbth), Coord_t{16, 15});
+    putString(statRating(Coord_t{12, xbth}), Coord_t{16, 15});
     putString("Bows/Throw  :", Coord_t{17, 1});
-    putString(statRating(12, xbthb), Coord_t{17, 15});
+    putString(statRating(Coord_t{12, xbthb}), Coord_t{17, 15});
     putString("Saving Throw:", Coord_t{18, 1});
-    putString(statRating(6, xsave), Coord_t{18, 15});
+    putString(statRating(Coord_t{6, xsave}), Coord_t{18, 15});
 
     putString("Stealth     :", Coord_t{16, 28});
-    putString(statRating(1, xstl), Coord_t{16, 42});
+    putString(statRating(Coord_t{1, xstl}), Coord_t{16, 42});
     putString("Disarming   :", Coord_t{17, 28});
-    putString(statRating(8, xdis), Coord_t{17, 42});
+    putString(statRating(Coord_t{8, xdis}), Coord_t{17, 42});
     putString("Magic Device:", Coord_t{18, 28});
-    putString(statRating(6, xdev), Coord_t{18, 42});
+    putString(statRating(Coord_t{6, xdev}), Coord_t{18, 42});
 
     putString("Perception  :", Coord_t{16, 55});
-    putString(statRating(3, xfos), Coord_t{16, 69});
+    putString(statRating(Coord_t{3, xfos}), Coord_t{16, 69});
     putString("Searching   :", Coord_t{17, 55});
-    putString(statRating(6, xsrh), Coord_t{17, 69});
+    putString(statRating(Coord_t{6, xsrh}), Coord_t{17, 69});
     putString("Infra-Vision:", Coord_t{18, 55});
     putString(xinfra, Coord_t{18, 69});
 }
@@ -675,7 +677,12 @@ void displaySpellsList(const int *spell_ids, int number_of_choices, bool comment
         col = 31;
     }
 
-    int consecutive_offset = (classes[py.misc.class_id].class_to_use_mage_spells == config::spells::SPELL_TYPE_MAGE ? config::spells::NAME_OFFSET_SPELLS : config::spells::NAME_OFFSET_PRAYERS);
+    int consecutive_offset;
+    if (classes[py.misc.class_id].class_to_use_mage_spells == config::spells::SPELL_TYPE_MAGE) {
+        consecutive_offset = config::spells::NAME_OFFSET_SPELLS;
+    } else {
+        consecutive_offset = config::spells::NAME_OFFSET_PRAYERS;
+    }
 
     eraseLine(Coord_t{1, col});
     putString("Name", Coord_t{1, col + 5});
@@ -743,11 +750,11 @@ static void playerGainLevel() {
     Class_t const &player_class = classes[py.misc.class_id];
 
     if (player_class.class_to_use_mage_spells == config::spells::SPELL_TYPE_MAGE) {
-        playerCalculateAllowedSpellsCount(py_attrs::A_INT);
-        playerGainMana(py_attrs::A_INT);
+        playerCalculateAllowedSpellsCount(PlayerAttr::A_INT);
+        playerGainMana(PlayerAttr::A_INT);
     } else if (player_class.class_to_use_mage_spells == config::spells::SPELL_TYPE_PRIEST) {
-        playerCalculateAllowedSpellsCount(py_attrs::A_WIS);
-        playerGainMana(py_attrs::A_WIS);
+        playerCalculateAllowedSpellsCount(PlayerAttr::A_WIS);
+        playerGainMana(PlayerAttr::A_WIS);
     }
 }
 
@@ -765,5 +772,5 @@ void displayCharacterExperience() {
         py.misc.max_exp = py.misc.exp;
     }
 
-    printLongNumber(py.misc.exp, 14, STAT_COLUMN + 6);
+    printLongNumber(py.misc.exp, Coord_t{14, STAT_COLUMN + 6});
 }
